@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2010 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -9,8 +10,8 @@
  *								*
  ****************************************************************/
 
-#ifndef __AUTO_ZLINK_H__
-#define __AUTO_ZLINK_H__
+#ifndef AUTO_ZLINK_H_INCLUDED
+#define AUTO_ZLINK_H_INCLUDED
 
 rhdtyp *auto_zlink (unsigned char *pc, int4 **line);
 
