@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2007 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -9,8 +10,8 @@
  *								*
  ****************************************************************/
 
-#ifndef __BM_UPDATE_H__
-#define __BM_UPDATE_H__
+#ifndef BM_UPDATE_H_INCLUDED
+#define BM_UPDATE_H_INCLUDED
 
 void bm_update(cw_set_element *cs, sm_uc_ptr_t lclmap, boolean_t is_mm);
 
