@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Copyright (c) 2001-2019 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -12,6 +12,8 @@
 #ifndef BMM_FIND_FREE_H_INCLUDED
 #define BMM_FIND_FREE_H_INCLUDED
 
-int4 bmm_find_free(uint4 hint, uchar_ptr_t base_addr, uint4 total_bits);
+#include "gdsroot.h"
+
+block_id bmm_find_free(block_id hint, uchar_ptr_t base_addr, block_id total_bits);
 
 #endif
