@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2012 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2020 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -20,7 +21,7 @@
 #include "mdef.h"
 #include "caller_id.h"
 
-caddr_t caller_id(void)
+caddr_t caller_id(unsigned int extra_frames)
 {
 return (caddr_t)((INTPTR_T)-1);
 }
