@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Copyright (c) 2001-2021 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -13,6 +13,8 @@
 #ifndef CDB_SC
 #define CDB_SC
 
+#include "gdsroot.h"
+
 /*********************************  WARNING:  ***********************************
 *   Several of these codes are concurrently defined in GVCST_BLK_SEARCH.MAR,	*
 *   GVCST_SEARCH.MAR, MUTEX.MAR, and MUTEX_STOPREL.MAR.  If their positions	*
@@ -33,23 +35,48 @@ enum cdb_sc
 GBLREF	boolean_t	is_final_retry_code_num[];
 GBLREF	boolean_t	is_final_retry_code_uchar[];
 GBLREF	boolean_t	is_final_retry_code_lchar[];
+GBLREF	int		sizeof_is_final_retry_code_num;
+GBLREF	int		sizeof_is_final_retry_code_uchar;
+GBLREF	int		sizeof_is_final_retry_code_lchar;
 
-#define	IS_FINAL_RETRY_CODE(STATUS)								\
-	(DBG_ASSERT(STATUS <= 'z')								\
-	((STATUS < 'A')										\
-		? is_final_retry_code_num[STATUS]			/* numeric */		\
-		: ((STATUS <= 'Z')								\
-			? is_final_retry_code_uchar[STATUS - 'A']	/* upper case */	\
-			: is_final_retry_code_lchar[STATUS - 'a'])))	/* lower case */
+static inline boolean_t	is_final_retry_code(enum cdb_sc status)
+{
+	int idx;
+	boolean_t val;
+
+	assert(status <= 'z');
+
+	if (status < 'A')
+	{	/* numeric */
+		idx = status;
+		assert(0 <= idx);
+		assert((sizeof_is_final_retry_code_num / SIZEOF(boolean_t)) > idx);
+		val = is_final_retry_code_num[idx];
+	}
+	else if (status <= 'Z')
+	{	/* upper case */
+		idx = status - 'A';
+		assert(0 <= idx);
+		assert((sizeof_is_final_retry_code_uchar / SIZEOF(boolean_t)) > idx);
+		val = is_final_retry_code_uchar[idx];
+	} else
+	{	/* lower case */
+		idx = status - 'a';
+		assert(0 <= idx);
+		assert((sizeof_is_final_retry_code_lchar / SIZEOF(boolean_t)) > idx);
+		val = is_final_retry_code_lchar[idx];
+	}
+	return val;
+}
 
 /* This macro is used in places that don't rely on t_retry() to handle the possibility of a retry in the final try.
  * For example, database trigger handling code assumes that a structural issue with a trigger global is due to a
  * concurrent update and not a broken entry in the DB. Once the final retry has been exhausted, the trigger code
- * path issues a TRIGDEFBAD error. IS_FINAL_RETRY_CODE enhances that check against CDB_STAGNATE to ensure that the
+ * path issues a TRIGDEFBAD error. is_final_retry_code enhances that check against CDB_STAGNATE to ensure that the
  * final retry has truly been exhausted.
  */
 #define UPDATE_CAN_RETRY(TRIES, CURRSTATUS)							\
-	((CDB_STAGNATE > TRIES) || (IS_FINAL_RETRY_CODE(CURRSTATUS)))
+	((CDB_STAGNATE > TRIES) || (is_final_retry_code(CURRSTATUS)))
 
 #define TP_TRACE_HIST_MOD(BLK_NUM, BLK_TARGET, N, CSD, HISTTN, BTTN, LEVEL)							\
 MBSTART {															\
@@ -61,7 +88,7 @@ MBSTART {															\
 	{	/* next 4 lines of code are identical to TP_TRACE_HIST (below), but repetion saves an if when it matters */	\
 		assert(dollar_tlevel);												\
 		TAREF1(t_fail_hist_blk, t_tries) = ((block_id)BLK_NUM);								\
-		TAREF1(tp_fail_hist, t_tries) = (gv_namehead *)(((int)BLK_NUM & ~(-BLKS_PER_LMAP)) ? BLK_TARGET : NULL);	\
+		TAREF1(tp_fail_hist, t_tries) = (gv_namehead *)(((block_id)BLK_NUM & ~(-BLKS_PER_LMAP)) ? BLK_TARGET : NULL);	\
 		TAREF1(tp_fail_hist_reg, t_tries) = gv_cur_region;								\
 		(CSD)->tp_cdb_sc_blkmod[(N)]++;											\
 		TREF(blkmod_fail_level) = (LEVEL);										\
@@ -93,7 +120,7 @@ MBSTART {															\
 	{															\
 		assert(dollar_tlevel);												\
 		TAREF1(t_fail_hist_blk, t_tries) = ((block_id)BLK_NUM);								\
-		TAREF1(tp_fail_hist, t_tries) = (gv_namehead *)(((int)BLK_NUM & ~(-BLKS_PER_LMAP)) ? BLK_TARGET : NULL);	\
+		TAREF1(tp_fail_hist, t_tries) = (gv_namehead *)(((block_id)BLK_NUM & ~(-BLKS_PER_LMAP)) ? BLK_TARGET : NULL);	\
 		TAREF1(tp_fail_hist_reg, t_tries) = gv_cur_region;								\
 	}															\
 } MBEND
