@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2020 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -45,7 +45,7 @@
 GBLREF	uint4		dollar_tlevel;
 GBLREF	boolean_t	created_core;
 GBLREF	boolean_t	dse_running;
-GBLREF	boolean_t	mu_reorg_upgrd_dwngrd_in_prog;
+GBLREF	uint4		mu_upgrade_in_prog;
 GBLREF	uint4		mu_reorg_encrypt_in_prog;
 
 error_def(ERR_DBBLEVMX);
@@ -92,6 +92,16 @@ error_def(ERR_DBNONUMSUBS);
 #define TEXT3 " :              LVL=0x"
 #define TEXT4 ","
 
+#ifdef DEBUG_BLKS_TO_UPGRD
+#define DEBUG_BLKS_TO_UPGRD_FORK_N_CORE											\
+MBSTART	{														\
+		if (mu_upgrade_in_prog)											\
+			gtm_fork_n_core();										\
+} MBEND
+#else
+#define DEBUG_BLKS_TO_UPGRD_FORK_N_CORE
+#endif
+
 #define MAX_UTIL_LEN (STRLEN(TEXT0) + BLOCK_WINDOW + STRLEN(TEXT3) + LEVEL_WINDOW + STRLEN(TEXT4) + 1)
 #define	RTS_ERROR_FUNC(CSA, ERR, BUFF, ERROR_ACTION, REG)	/* for reg in a message, replace NULL in invocation */	\
 {															\
@@ -111,6 +121,7 @@ error_def(ERR_DBNONUMSUBS);
 				DB_LEN_STR((gd_region *)REG));								\
 		else													\
 			send_msg_csa(CSA_ARG(CSA) VARLSTCNT(4) MAKE_MSG_INFO(ERR), 2, LEN_AND_STR((char_ptr_t)BUFF));	\
+		DEBUG_BLKS_TO_UPGRD_FORK_N_CORE;									\
 		if ((ASSERTPRO_ON_CERT_FAIL != ERROR_ACTION) || (INFO == SEVMASK(ERR)))					\
 			break;												\
 		assertpro(0 == ERR);											\
@@ -121,7 +132,7 @@ error_def(ERR_DBNONUMSUBS);
 
 int cert_blk (gd_region *reg, block_id blk, blk_hdr_ptr_t bp, block_id root, int4 error_action, gv_namehead *gvt)
 {
-	block_id		child, prev_child;
+	block_ref		child, prev_child;
 	rec_hdr_ptr_t		rp, r_top;
 	int			num_subscripts, fmtd_key_len;
 	uint4			bplmap, mask1, offset, rec_offset, rec_size;
@@ -177,14 +188,15 @@ int cert_blk (gd_region *reg, block_id blk, blk_hdr_ptr_t bp, block_id root, int
 	MEMCPY_LIT(&util_buff[util_len], TEXT4);
 	util_len += STRLEN(TEXT4);
 	util_buff[util_len] = 0;
-	chain = *(off_chain *)&blk;
+	chain = ((block_ref *)&blk)->chain;
 	/* Assert that if at all chain.flag is non-zero (i.e. a created block), we are in TP and not yet in the commit logic.
 	 * The only exception to this rule is if we are in TP and inside phase1 of the commit logic and trying to certify a
 	 * block that was killed inside of the transaction (possible if cert_blk is called directly from tp_tend). In this case,
 	 * the block number passed is a special value GDS_CREATE_BLK_MAX so check that.
 	 */
-	assert(!chain.flag || dollar_tlevel && (!csa->t_commit_crit
-						|| ((T_COMMIT_CRIT_PHASE1 == csa->t_commit_crit) && (GDS_CREATE_BLK_MAX == blk))));
+	assert(!chain.flag || (dollar_tlevel
+				&& (!csa->t_commit_crit
+					|| ((T_COMMIT_CRIT_PHASE1 == csa->t_commit_crit) && (GDS_CREATE_BLK_MAX == blk)))));
 	if (!chain.flag && ((offset_mm * (block_id)bplmap) == blk))					/* it's a bitmap */
 	{
 		if ((unsigned char)blk_levl != LCL_MAP_LEVL)
@@ -285,8 +297,8 @@ int cert_blk (gd_region *reg, block_id blk, blk_hdr_ptr_t bp, block_id root, int
 		is_directory = TRUE;
 	if ((0 != root) && (DIR_ROOT != root))
 		is_gvt = TRUE;
-	/* MUPIP REORG -TRUNCATE has some special cases */
-	if (MUSWP_INCR_ROOT_CYCLE == TREF(in_mu_swap_root_state))
+	/* MUPIP REORG -TRUNCATE/-UPGRADE have some special cases */
+	if ((MUSWP_INCR_ROOT_CYCLE == TREF(in_mu_swap_root_state)) || mu_upgrade_in_prog)
 	{	/* We could be updating either a gvt root block or a directory leaf block. Don't know yet. */
 		is_directory = FALSE;
 		is_gvt = FALSE;
@@ -304,7 +316,7 @@ int cert_blk (gd_region *reg, block_id blk, blk_hdr_ptr_t bp, block_id root, int
 	comp_length = 2 * SIZEOF(char);		/* for double NUL to indicate no prior key */
 	prior_expkey[0] = prior_expkey[1] = 0;	/* double NUL also works for memvcmp test for key order */
 	next_tp_child_ptr = NULL;
-	prev_child = 0;
+	prev_child.id = 0;
 	rec_num = 0;
 	for (rp = (rec_hdr_ptr_t)((sm_uc_ptr_t)bp + SIZEOF(blk_hdr)) ;  rp < (rec_hdr_ptr_t)blk_top ;  rp = r_top)
 	{
@@ -507,31 +519,31 @@ int cert_blk (gd_region *reg, block_id blk, blk_hdr_ptr_t bp, block_id root, int
 		/* Check for proper child block numbers */
 		if ((0 != blk_levl) || (0 != is_directory))
 		{
-			READ_BLK_ID(long_blk_id, &child, blk_id_ptr);
-			chain = *(off_chain *)&child;
+			READ_BLK_ID(long_blk_id, &child.id, blk_id_ptr);
+			chain = child.chain;
 			/* In TP, child block number can be greater than the total_blks for blocks created within TP.
 			 * Dont do any checks on such blocks.
 			 */
 			if (!dollar_tlevel || !chain.flag)
 			{
-				if (child <= 0)
+				if (child.id <= 0)
 				{
 					RTS_ERROR_FUNC(csa, ERR_DBPTRNOTPOS, util_buff, error_action, NULL);
 					return FALSE;
 				}
-				if ((child > csa->ti->total_blks) && !mu_reorg_upgrd_dwngrd_in_prog && !mu_reorg_encrypt_in_prog)
+				if ((child.id > csa->ti->total_blks) && !mu_upgrade_in_prog && !mu_reorg_encrypt_in_prog)
 				{	/* REORG -UPGRADE/DOWNGRADE/ENCRYPT can update recycled blocks, which may contain children
 					 * beyond total_blks if a truncate happened sometime after the block was killed.
 					 */
 					RTS_ERROR_FUNC(csa, ERR_DBPTRMX, util_buff, error_action, NULL);
 					return FALSE;
 				}
-				if (!(child % bplmap))
-				{
+				if (!(child.id % bplmap) && !mu_upgrade_in_prog)
+				{	/* mu_upgrade_bmm creates 0 pointers in order to deal with KILL's globals */
 					RTS_ERROR_FUNC(csa, ERR_DBPTRMAP, util_buff, error_action, NULL);
 					return FALSE;
 				}
-				if (child == prev_child)
+				if ((child.id == prev_child.id) && !mu_upgrade_in_prog)
 				{
 					RTS_ERROR_FUNC(csa, ERR_DBBDBALLOC, util_buff, error_action, NULL);
 					return FALSE;
