@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2011 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -9,8 +10,8 @@
  *								*
  ****************************************************************/
 
-#ifndef __COMPILE_PATTERN_H__
-#define __COMPILE_PATTERN_H__
+#ifndef COMPILE_PATTERN_H_INCLUDED
+#define COMPILE_PATTERN_H_INCLUDED
 
 int compile_pattern(oprtype *z, boolean_t is_indirect);
 
