@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2003-2017 Fidelity National Information	*
+ * Copyright (c) 2003-2021 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -27,6 +27,25 @@
 #include "send_msg.h"
 #include "gtmimagename.h"
 
+#define EXT_NEW_TIME 30
+
+/* GTM-9443 - A process that detects a temporary journal file, waits for a short
+ * period of time, in order to check if its presence persists before deleting/renaming it.
+ */
+#define WAIT_FOR_EXT_NEW(FILESTR, USTATUS)                                                              \
+{                                                                                                       \
+	int		lcnt;                                                                           \
+                                                                                                        \
+	for (lcnt = EXT_NEW_TIME; lcnt; lcnt--)                                                         \
+	{                                                                                               \
+		SHORT_SLEEP(lcnt);                                                                      \
+		if (FILE_PRESENT != gtm_file_stat(FILESTR, NULL, NULL, FALSE, USTATUS))                 \
+		{	/* Leave cre_jnl_file_intrpt_rename() when the EXT_NEW file doesn't persist */  \
+			return;                                                                         \
+		}                                                                                       \
+	}                                                                                               \
+}
+
 GBLREF	gd_region	*gv_cur_region;
 
 error_def(ERR_FILEPARSE);
@@ -82,6 +101,7 @@ void cre_jnl_file_intrpt_rename(sgmnt_addrs *csa)
 	{
 		if (FILE_PRESENT == status2)
 		{
+			WAIT_FOR_EXT_NEW(&filestr, &ustatus);
 			status = gtm_rename(filestr.addr, (int)filestr.len, (char *)fn, fn_len, &ustatus);
 			if (SYSCALL_ERROR(status))
 			{
@@ -103,6 +123,7 @@ void cre_jnl_file_intrpt_rename(sgmnt_addrs *csa)
 	{
 		if (FILE_PRESENT == status2)
 		{
+			WAIT_FOR_EXT_NEW(&filestr, &ustatus);
 			status = gtm_file_remove(filestr.addr, (int)filestr.len, &ustatus);
 			if (SYSCALL_ERROR(status))
 			{
