@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -84,7 +84,7 @@ void dse_chng_fhead(void)
 #	ifndef BLK_NUM_64BIT
 	block_id_64	blkcnt2;
 #	endif
-	boolean_t	was_crit, was_hold_onto_crit, corrupt_file_present;
+	boolean_t	was_crit, was_hold_onto_crit = FALSE, corrupt_file_present;
 	boolean_t	override = FALSE, max_tn_present, max_tn_warn_present, curr_tn_present, change_tn;
 	char		temp_str[OUT_LINE], temp_str1[OUT_LINE], buf[MAX_LINE], *fname_ptr, hash_buff[GTMCRYPT_HASH_LEN];
 	const char	*freeze_msg[] = { "UNFROZEN", "FROZEN" };
@@ -309,6 +309,13 @@ void dse_chng_fhead(void)
 	if ((CLI_PRESENT == cli_present("REFERENCE_COUNT")) && (cli_get_int("REFERENCE_COUNT", &x)))
 		cs_addrs->nl->ref_cnt = x;
 	if ((CLI_PRESENT == cli_present("RESERVED_BYTES")) && (cli_get_int("RESERVED_BYTES", &x)))
+	{
+		cs_data->reserved_bytes = x;
+		cs_data->i_reserved_bytes = x;
+	}
+	if ((CLI_PRESENT == cli_present("INDEX_RESERVED_BYTES")) && (cli_get_int("INDEX_RESERVED_BYTES", &x)))
+		cs_data->i_reserved_bytes = x;
+	if ((CLI_PRESENT == cli_present("DATA_RESERVED_BYTES")) && (cli_get_int("DATA_RESERVED_BYTES", &x)))
 		cs_data->reserved_bytes = x;
 	if ((CLI_PRESENT == cli_present("DEF_COLLATION")) && (cli_get_int("DEF_COLLATION", &x)))
 		cs_data->def_coll = x;
@@ -323,7 +330,8 @@ void dse_chng_fhead(void)
 		buf_len = SIZEOF(buf);
 		if (cli_get_str("CERT_DB_VER", buf, &buf_len))
 		{
-			lower_to_upper((uchar_ptr_t)buf, (uchar_ptr_t)buf, buf_len);
+			if ('v' == buf[0])	/* Uppercase the 'v' but not the trailing 'p' or 'm' */
+				buf[0] = 'V';
 			for (index_x=0; index_x < GDSVLAST ; index_x++)
 				if (0 == STRCMP(buf, gtm_dbversion_table[index_x]))
 				{
@@ -452,8 +460,12 @@ void dse_chng_fhead(void)
 	)
 	if (CLI_PRESENT == cli_present("STDNULLCOLL"))
 	{
-		if ( -1 != (x = cli_t_f_n("STDNULLCOLL")))
-			gv_cur_region->std_null_coll = cs_data->std_null_coll = x;
+		x = cli_t_f_n("STDNULLCOLL");
+		if (-1 != x)
+		{
+			gv_cur_region->std_null_coll = x;
+			cs_data->std_null_coll = x;
+		}
 	}
 	corrupt_file_present = (CLI_PRESENT == cli_present("CORRUPT_FILE"));
 	if (corrupt_file_present)
@@ -528,9 +540,9 @@ void dse_chng_fhead(void)
 	)
 	if ((CLI_PRESENT == cli_present("B_RECORD")) && (cli_get_hex64("B_RECORD", &tn)))
 		cs_data->last_rec_backup = tn;
-	if ((CLI_PRESENT == cli_present("BLKS_TO_UPGRADE")) && (cli_get_hex("BLKS_TO_UPGRADE", (uint4 *)&x)))
+	if ((CLI_PRESENT == cli_present("BLKS_TO_UPGRADE")) && (cli_get_hex64("BLKS_TO_UPGRADE", (gtm_uint64_t *)&blkcnt)))
 	{
-		cs_data->blks_to_upgrd = x;
+		cs_data->blks_to_upgrd = blkcnt;
 		cs_data->fully_upgraded = FALSE;
 	}
 	if ((CLI_PRESENT == cli_present("MBM_SIZE")) && (cli_get_int("MBM_SIZE", &x)))
@@ -538,7 +550,7 @@ void dse_chng_fhead(void)
 		if (x < DIVIDE_ROUND_UP(BLK_ZERO_OFF(cs_data->start_vbn) - SGMNT_HDR_LEN, DISK_BLOCK_SIZE))
 		{	/* if the start_vbn needs fixing, do that first */
 			cs_data->master_map_len = x * DISK_BLOCK_SIZE;
-			cs_data->free_space = BLK_ZERO_OFF(cs_data->start_vbn) - (SGMNT_HDR_LEN + x);
+			cs_data->free_space = BLK_ZERO_OFF(cs_data->start_vbn) - SIZEOF_FILE_HDR(cs_data);
 		} else
 		{
 			x = DIVIDE_ROUND_UP(BLK_ZERO_OFF(cs_data->start_vbn) - SGMNT_HDR_LEN, DISK_BLOCK_SIZE);
