@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -9,8 +10,8 @@
  *								*
  ****************************************************************/
 
-#ifndef __DST_PUTTIME_H__
-#define __DST_PUTTIME_H__
+#ifndef DST_PUTTIME_H_INCLUDED
+#define DST_PUTTIME_H_INCLUDED
 
 void dse_puttime(int_ptr_t time, char *c, bool flush);
 
