@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2011 Fidelity Information Services, Inc	*
+ *	Copyright 2001, 2014 Fidelity Information Services, Inc	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -17,21 +17,24 @@
 
 int f_zsearch(oprtype *a, opctype op)
 {
-	triple *r;
+	triple *r, *rop;
 	DCL_THREADGBL_ACCESS;
 
 	SETUP_THREADGBL_ACCESS;
 	r = maketriple(op);
 	if (EXPR_FAIL == expr(&(r->operand[0]), MUMPS_STR))
 		return FALSE;
+	rop = newtriple(OC_PARAMETER);
+	r->operand[1] = put_tref(rop);
 	if (TK_COMMA != TREF(window_token))
-		r->operand[1] = put_ilit(0);
+		rop->operand[0] = put_ilit(0);
 	else
 	{
 		advancewindow();
-		if (EXPR_FAIL == expr(&(r->operand[1]), MUMPS_INT))
+		if (EXPR_FAIL == expr(&(rop->operand[0]), MUMPS_INT))
 			return FALSE;
 	}
+	rop->operand[1] = put_ilit(1);		/* This is an M-function call */
 	ins_triple(r);
 	*a = put_tref(r);
 	return TRUE;
