@@ -1,6 +1,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;								;
-;	Copyright 2001 Sanchez Computer Associates, Inc.	;
+; Copyright (c) 2001-2021 Fidelity National Information		;
+; Services, Inc. and/or its subsidiaries. All rights reserved.	;
 ;								;
 ;	This source code contains the intellectual property	;
 ;	of its copyright holder(s), and is made available	;
@@ -16,8 +17,12 @@ GDESETGD
 	q
 GDFIND	s file=$zparse(tfile,"",defgldext)
 	i file="" s file=$ztrnlnm(tfile) s:file="" file=tfile zm gdeerr("INVGBLDIR"):file:defgld s tfile=defgld
-	s file=$zsearch($zparse(tfile,"",defgldext))
-	i file="" s file=$zsearch($zparse(tfile,"",defgldext))
-	i file="" s file=$zparse(tfile,"",defgldext),create=1 zm gdeerr("GDUSEDEFS"):file
-	e  s create=0 zm gdeerr("LOADGD"):file
+	; 30 millisec is an arbitrarily chosen value yielding a wait that seems sufficient, but not too annoying
+	for i=.03:-.001:.0 do  q:'create  h i	; look long enough to ensure not in window of delete/rename from a concurrent edit
+	. i $zsearch("qfb")
+	. s file=$zsearch($zparse(tfile,"",defgldext))
+	. i file="" s file=$zsearch($zparse(tfile,"",defgldext))
+	. i file="" s file=$zparse(tfile,"",defgldext),create=1
+	. e  s create=0 zm gdeerr("LOADGD"):file
+	zm:create gdeerr("GDUSEDEFS"):file
 	q
