@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Copyright (c) 2001-2019 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -14,16 +14,7 @@
 #include "gtm_string.h"
 #include "cmd_qlf.h"
 #include "cli.h"
-
-#define INIT_QUALIF_STR(QUALIF, CQCODE, FIELD)										\
-{															\
-	if ((glb_cmd_qlf.qlf & CQCODE) && (MV_STR == glb_cmd_qlf.FIELD.mvtype) && (0 < glb_cmd_qlf.FIELD.str.len))	\
-	{														\
-		QUALIF->FIELD.mvtype = MV_STR;										\
-		QUALIF->FIELD.str.len = glb_cmd_qlf.FIELD.str.len;							\
-		memcpy(QUALIF->FIELD.str.addr, glb_cmd_qlf.FIELD.str.addr, glb_cmd_qlf.FIELD.str.len);			\
-	}														\
-}
+#include "min_max.h"
 
 GBLDEF list_params 		lst_param;
 
@@ -41,27 +32,17 @@ void get_cmd_qlf(command_qualifier *qualif)
 
 	qualif->qlf = glb_cmd_qlf.qlf;
 	qualif->object_file.mvtype = qualif->list_file.mvtype = qualif->ceprep_file.mvtype = 0;
-	INIT_QUALIF_STR(qualif, CQ_OBJECT, object_file);
-	INIT_QUALIF_STR(qualif, CQ_LIST, list_file);
-	INIT_QUALIF_STR(qualif, CQ_CE_PREPROCESS, ceprep_file);
 	if (gtm_utf8_mode)
 		qualif->qlf |= CQ_UTF8;		/* Mark as being compiled in UTF8 mode */
 	if (CLI_PRESENT == cli_present("OBJECT"))
 	{
 		qualif->qlf |= CQ_OBJECT;
 		qualif->object_file.mvtype = MV_STR;
-		s = &qualif->object_file.str;
+		s = &qualif->object_file.str;	/* 4SCA: object_file is allocated MAX_FN_LEN bytes */
 		len = s->len;
 		if (FALSE == cli_get_str("OBJECT", s->addr, &len))
-		{
 			s->len = 0;
-			if (glb_cmd_qlf.object_file.mvtype == MV_STR  &&  glb_cmd_qlf.object_file.str.len > 0)
-			{
-				s->len = glb_cmd_qlf.object_file.str.len;
-				memcpy(s->addr, glb_cmd_qlf.object_file.str.addr,
-					s->len);
-			}
-		} else
+		else
 			s->len = len;
 	} else if (TRUE == cli_negated("OBJECT"))
 		qualif->qlf &= ~CQ_OBJECT;
@@ -101,18 +82,11 @@ void get_cmd_qlf(command_qualifier *qualif)
 	{
 		qualif->qlf |= CQ_LIST;
 		qualif->list_file.mvtype = MV_STR;
-		s = &qualif->list_file.str;
+		s = &qualif->list_file.str;	/* 4SCA: list_file is allocated MAX_FN_LEN bytes */
 		len = s->len;
 		if (FALSE == cli_get_str("LIST", s->addr, &len))
-		{
 			s->len = 0;
-			if (glb_cmd_qlf.list_file.mvtype == MV_STR  &&  glb_cmd_qlf.list_file.str.len > 0)
-			{
-				s->len = glb_cmd_qlf.list_file.str.len;
-				memcpy(s->addr, glb_cmd_qlf.list_file.str.addr,
-					s->len);
-			}
-		} else
+		else
 			s->len = len;
 	} else if (!(qualif->qlf & CQ_LIST))
 		qualif->qlf &= ~CQ_MACHINE_CODE;
@@ -142,17 +116,11 @@ void get_cmd_qlf(command_qualifier *qualif)
         {
 		qualif->qlf |= CQ_CE_PREPROCESS;
 		qualif->ceprep_file.mvtype = MV_STR;
-		s = &qualif->ceprep_file.str;
+		s = &qualif->ceprep_file.str;	/* 4SCA: ceprep_file is allocated MAX_FN_LEN bytes */
 		len = s->len;
 		if (FALSE == cli_get_str("CE_PREPROCESS", s->addr, &len))
-		{
 			s->len = 0;
-			if (glb_cmd_qlf.ceprep_file.mvtype == MV_STR  &&  glb_cmd_qlf.ceprep_file.str.len > 0)
-			{
-				s->len = glb_cmd_qlf.ceprep_file.str.len;
-				memcpy(s->addr, glb_cmd_qlf.ceprep_file.str.addr, s->len);
-			}
-		} else
+		else
 			s->len = len;
 	} else if (TRUE == cli_negated("CE_PREPROCESS"))
 		qualif->qlf &= ~CQ_CE_PREPROCESS;
