@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2011 Fidelity Information Services, Inc	*
+ * Copyright (c) 2011-2023 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -25,11 +26,11 @@ LITREF int4	gtm_release_name_len;
 
 error_def(ERR_GTMASSERT2);
 
-int gtm_assert2(int condlen, char *condtext, int file_name_len, char file_name[], int line_no)
+void gtm_assert2(int condlen, char *condtext, int file_name_len, char file_name[], int line_no)
 {
 	send_msg(VARLSTCNT(9) ERR_GTMASSERT2, 7, gtm_release_name_len, gtm_release_name, file_name_len, file_name, line_no,
 		 condlen, condtext);
 	rts_error(VARLSTCNT(9) ERR_GTMASSERT2, 7, gtm_release_name_len, gtm_release_name, file_name_len, file_name, line_no,
 		  condlen, condtext);
-	return 0;	/* Required for assertpro() macro which assumes (syntactically) this rtn returns a result */
+	GTM_UNREACHABLE();
 }
