@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2003 Sanchez Computer Associates, Inc.	*
+ * Copyright (c) 2003-2018 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -9,8 +10,8 @@
  *								*
  ****************************************************************/
 
-#ifndef __GTM_FILE_REMOVE_
-#define __GTM_FILE_REMOVE_
+#ifndef GTM_FILE_REMOVE_H_INCLUDED
+#define GTM_FILE_REMOVE_H_INCLUDED
 int4 gtm_file_remove(char *fn, int fn_len, uint4 *ustatus);
 
 #endif
