@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2013-2021 Fidelity National Information	*
+ * Copyright (c) 2013-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -42,7 +42,10 @@ error_def(ERR_TLSCLOSE);
 #define CLEAR_REPL_TLS_REQUESTED	repl_tls.id[0] = '\0'
 #define REPL_TLS_ENABLED		(repl_tls.enabled)
 #define CLEAR_REPL_TLS_ENABLED		repl_tls.enabled = FALSE
-#define PLAINTEXT_FALLBACK		(repl_tls.plaintext_fallback)
+#define CFG_PLAINTEXT_FALLBACK		((NULL != repl_tls.sock) && (repl_tls.sock->flags & GTMTLS_OP_PLAINTEXT_FALLBACK))
+#define PLAINTEXT_FALLBACK		(repl_tls.plaintext_fallback || CFG_PLAINTEXT_FALLBACK)
+#define RCVR_SIDE_STR			"Receiver side"
+#define SRC_SIDE_STR			"Source side"
 
 #define DEFAULT_RENEGOTIATE_TIMEOUT	(2 * 60) /* About 2 hours between renegotiation. */
 #define MIN_RENEGOTIATE_TIMEOUT		1
@@ -56,6 +59,7 @@ error_def(ERR_TLSCLOSE);
 
 void	repl_log_tls_info(FILE *logfp, gtm_tls_socket_t *socket);
 int 	repl_do_tls_handshake(FILE *logfp, int sock_fd, boolean_t do_accept, int *poll_direction);
+int	repl_do_tls_post_handshake(FILE *logfp, int sock_fd);
 void	repl_do_tls_init(FILE *logfp);
 
 #endif	/* GTM_TLS */
