@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -107,7 +107,7 @@ void	gvcst_expand_free_subtree(kill_set *ks_head)
 					assert(ksb->block < (1LL << CW_INDEX_MAX_BITS));
 					chain.cw_index = ksb->block;
 					assert(SIZEOF(chain) == SIZEOF(blk));
-					blk = *(block_id *)&chain;
+					blk = ((block_ref *)&chain)->id;
 				} else
 					blk = ksb->block;
 				if (!(bp = (blk_hdr_ptr_t)t_qread(blk, (sm_int_ptr_t)&cycle, &cr)))
@@ -131,11 +131,11 @@ void	gvcst_expand_free_subtree(kill_set *ks_head)
 					assert(!cr->twin || cr->bt_index);
 					assert((NULL == (bt = bt_get(blk)))
 						|| (CR_NOTVALID == bt->cache_index)
-						|| (cr == (cache_rec_ptr_t)GDS_REL2ABS(bt->cache_index)) && (0 == cr->in_tend));
+						|| ((cr == (cache_rec_ptr_t)GDS_REL2ABS(bt->cache_index)) && (0 == cr->in_tend)));
 				}
 				assert(MAX_DB_BLK_SIZE >= bp->bsiz);
 				bsiz = MIN(bp->bsiz, MAX_DB_BLK_SIZE);	/* avoid buffer overflows */
-				memcpy(temp_buff, bp, bsiz);
+				memcpy((void *)temp_buff, bp, bsiz);
 				if (!was_crit)
 					rel_crit(gv_cur_region);
 				for (rp = (rec_hdr_ptr_t)(temp_buff + SIZEOF(blk_hdr)), rtop = (rec_hdr_ptr_t)(temp_buff + bsiz);
@@ -153,7 +153,7 @@ void	gvcst_expand_free_subtree(kill_set *ks_head)
 					if (dollar_tlevel)
 					{
 						assert(sgm_info_ptr->tp_csa == cs_addrs);
-						chain = *(off_chain *)&temp_blk;
+						chain = ((block_ref *)&temp_blk)->chain;
 						assert((SIZEOF(int) * 8) >= CW_INDEX_MAX_BITS);
 						assertpro(!((1 == chain.flag) &&
 							((int)chain.cw_index >= sgm_info_ptr->cw_set_depth)));
