@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2020 Fidelity National Information	*
+ * Copyright (c) 2001-2025 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -199,7 +199,7 @@ boolean_t	gvcst_query2(void)
 					continue;
 			} else
 			{
-				status = tp_hist(!two_histories ? NULL : rt_history);
+				status = tp_hist(!two_histories ? NULL : rt_history, ERR_GVQUERYFAIL);
 				if (cdb_sc_normal != status)
 				{
 					t_retry(status);
