@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2011 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2020 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -17,25 +18,24 @@
 #include "gdsbt.h"
 #include "gdsfhead.h"
 #include "dpgbldir.h"
+#include "gvt_inline.h"
 
 GBLREF	gd_addr		*gd_header;
 
 void gvinit(void)
 {
 	mval	v;
-	DCL_THREADGBL_ACCESS;
 
-	SETUP_THREADGBL_ACCESS;
-	/* if gd_header is null then get the current one, and update the gd_map */
+	/* if gd_header is null then get the current one */
 	if (!gd_header)
 	{
-		SET_GD_HEADER(v);
-		SET_GD_MAP;
+		v.mvtype = MV_STR;
+		v.str.len = 0;
+		gd_header = zgbldir(&v);
 	}
-	DEBUG_ONLY(else GD_HEADER_ASSERT);
 	/* May get in here after an extended ref call OR in mupip journal recover forward processing (with
 	 * function call graph "mur_output_record/gvcst_put/gvtr_init/gvtr_db_tpwrap/op_tstart").
 	 * In either case it is possible that gv_currkey has already been set up, so dont lose any preexisting keys.
 	 */
-	GVKEYSIZE_INCREASE_IF_NEEDED(DBKEYSIZE(gd_header->regions->max_key_size));
+	GVKEYSIZE_INIT_IF_NEEDED;	/* sets "gv_keysize", "gv_currkey" and "gv_altkey" (if not already done) */
 }
