@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -38,7 +38,7 @@ int gvn(void)
 	int		hash_code;
 	opctype		ox;
 	oprtype		*sb1, *sb2, subscripts[MAX_GVSUBSCRIPTS + 1];
-	triple		*oldchain, *ref, *s, tmpchain, *triptr;
+	triple		*oldchain = NULL, *ref, *s, tmpchain, *triptr;
 	DCL_THREADGBL_ACCESS;
 
 	SETUP_THREADGBL_ACCESS;
@@ -46,10 +46,12 @@ int gvn(void)
 	advancewindow();
 	sb1 = sb2 = subscripts;
 	ox = 0;
-	if (shifting = (TREF(shift_side_effects) && (!TREF(saw_side_effect) || (GTM_BOOL == TREF(gtm_fullbool)
-		&& (OLD_SE == TREF(side_effect_handling))))))
+	if ((shifting = ((EXT_BOOL != TREF(gtm_fullbool)) && TREF(shift_side_effects)
+				&& (!TREF(saw_side_effect)
+					|| (GTM_BOOL == TREF(gtm_fullbool)
+						&& (OLD_SE == TREF(side_effect_handling)))))))
 	{	/* NOTE assignment above */
-		dqinit(&tmpchain, exorder);
+		exorder_init(&tmpchain);
 		oldchain = setcurtchain(&tmpchain);
 	}
 	if ((TK_LBRACKET == TREF(window_token)) || (TK_VBAR == TREF(window_token)))
@@ -63,7 +65,10 @@ int gvn(void)
 		{
 			stx_error(ERR_EXPR);
 			if (shifting)
+			{
+				assert(oldchain);
 				setcurtchain(oldchain);
+			}
 			return FALSE;
 		}
 		if (!vbar)
@@ -71,7 +76,7 @@ int gvn(void)
 			 * Correct the tree and sb1->opcode.tref and prevent an assert failure in emit_code.c
 			 */
 			coerce(sb1, OCT_MVAL);
-			ex_tail(sb1++);
+			ex_tail(sb1++, FALSE, FALSE);
 		}
 		if (TK_COMMA == TREF(window_token))
 		{
@@ -80,13 +85,16 @@ int gvn(void)
 			{
 				stx_error(ERR_EXPR);
 				if (shifting)
+				{
+					assert(oldchain);
 					setcurtchain(oldchain);
+				}
 				return FALSE;
 			}
 			if (!vbar)
 			{
 				coerce(sb1, OCT_MVAL);
-				ex_tail(sb1++);
+				ex_tail(sb1++, FALSE, FALSE);
 			}
 		} else
 			*sb1++ = put_str(0,0);
@@ -94,7 +102,10 @@ int gvn(void)
 		{
 			stx_error(ERR_EXTGBLDEL);
 			if (shifting)
+			{
+				assert(oldchain);
 				setcurtchain(oldchain);
+			}
 			return FALSE;
 		}
 		advancewindow();
@@ -116,14 +127,20 @@ int gvn(void)
 		{
 			stx_error(ERR_GVNAKEDEXTNM);
 			if (shifting)
+			{
+				assert(oldchain);
 				setcurtchain(oldchain);
+			}
 			return FALSE;
 		}
 		if (TK_LPAREN != TREF(window_token))
 		{
 			stx_error(ERR_GBLNAME);
 			if (shifting)
+			{
+				assert(oldchain);
 				setcurtchain(oldchain);
+			}
 			return FALSE;
 		}
 		ox = OC_GVNAKED;
@@ -141,14 +158,20 @@ int gvn(void)
 			{
 				stx_error(ERR_MAXNRSUBSCRIPTS);
 				if (shifting)
+				{
+					assert(oldchain);
 					setcurtchain(oldchain);
+				}
 				return FALSE;
 			}
 			advancewindow();
 			if (EXPR_FAIL == expr(sb1, MUMPS_EXPR))
 			{
 				if (shifting)
+				{
+					assert(oldchain);
 					setcurtchain(oldchain);
+				}
 				return FALSE;
 			}
 			assert(TRIP_REF == sb1->oprclass);
@@ -165,7 +188,10 @@ int gvn(void)
 			{
 				stx_error(ERR_RPARENMISSING);
 				if (shifting)
+				{
+					assert(oldchain);
 					setcurtchain(oldchain);
+				}
 				return FALSE;
 			}
 		}
@@ -175,6 +201,7 @@ int gvn(void)
 	SUBS_ARRAY_2_TRIPLES(ref, sb1, sb2, subscripts, 0);
 	if (shifting)
 	{
+		assert(oldchain);
 		if (TREF(saw_side_effect) && ((GTM_BOOL != TREF(gtm_fullbool)) || (OLD_SE != TREF(side_effect_handling))))
 		{	/* saw a side effect in a subscript - our reference has been superceded so no targ game on the name */
 			setcurtchain(oldchain);
@@ -192,6 +219,13 @@ int gvn(void)
 			triptr = newtriple(OC_GVRECTARG);
 			triptr->operand[0] = put_tref(TREF(expr_start));
 		}
-	}
+	} else if (TREF(saw_side_effect) && TREF(shift_side_effects)
+			&& (GTM_BOOL != TREF(gtm_fullbool) || (OLD_SE != TREF(side_effect_handling))))
+		TREF(saw_side_effect) = TRUE;
+	/* The conditional above is a temporary solution to a quirk discovered in the process of reworking the handling of nested
+	 * boolean expressions: in some cases GT.M resets $REFERENCE in nested booleans without side effects. Communicating to
+	 * ex_tail that it's not worth short-circuiting this expression is helpful; otherwise the $REFERENCE issue spreads to
+	 * side-effect expressions. But this line of code should be removed when the handling is addressed.
+	 */
 	return TRUE;
 }
