@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2017 Fidelity National Information	*
+ * Copyright (c) 2001-2020 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -25,10 +25,10 @@
 #include "copy.h"
 #include "jnl.h"
 #include "buddy_list.h"
-#include "hashtab_int4.h"	/* needed for tp.h */
 #include "tp.h"
 #include "gtm_string.h"
 #include "gvname_info.h"
+#include "gvt_inline.h"
 
 GBLREF gv_key           *gv_currkey;
 GBLREF gd_region        *gv_cur_region;
