@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2008-2021 Fidelity National Information	*
+ * Copyright (c) 2008-2025 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -12,6 +12,7 @@
 
 #ifndef GVSTATS_REC_H_INCLUDED
 #define GVSTATS_REC_H_INCLUDED
+#include "gtm_atomic.h"
 
 /* Note gvstats_rec exists in both sgmnt_data (file header) and in node_local. The reason
  * for this is so that gvstats can be updated by read-only processes which would not be
@@ -30,14 +31,14 @@ n_gvstats_rec_types
 
 typedef struct gvstats_rec_struct
 {
-#define	TAB_GVSTATS_REC(A,B,C)	gtm_uint64_t	A;
+#define	TAB_GVSTATS_REC(A,B,C)	gtm_atomic_uint_least64_t	A;
 #include "tab_gvstats_rec.h"
 } gvstats_rec_t;
 #undef TAB_GVSTATS_REC
 
 typedef struct gvstats_rec_csd_struct
 {
-#define	TAB_GVSTATS_REC(A,B,C)	gtm_uint64_t	A;
+#define	TAB_GVSTATS_REC(A,B,C)	gtm_atomic_uint_least64_t	A;
 #include "tab_gvstats_rec.h"
 } gvstats_rec_csd_t;
 #undef TAB_GVSTATS_REC
