@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -37,6 +37,7 @@ GBLREF  gv_namehead     *gv_target;
 LITREF	unsigned short	dpos[], dneg[];
 
 error_def(ERR_GVSUBOFLOW);
+error_def(ERR_DBNOREGION);
 /*
  * -----------------------------------------------------
  * Convert a string subscript to MUMPS string
@@ -89,7 +90,7 @@ unsigned char *gvsub2str(unsigned char *sub, mstr *opstr, boolean_t xlat_flg)
 				 * library allocated an external buffer greater than opstr->len
 				 */
 				assert(mstr_targ.addr != (char *)buf1);
-				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_GVSUBOFLOW);
+				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_GVSUBOFLOW, 2, targ_len, opstr->len, ERR_DBNOREGION, 0);
 			}
 			if (!xlat_flg)
 			{
