@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ *	Copyright 2001, 2013 Fidelity Information Services, Inc	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -16,7 +16,7 @@
 
 CONDITION_HANDLER(gvzwrite_ch)
 {
-	START_CH;
+	START_CH(TRUE);
 	gvzwrite_clnup();	/* this routine is called by gvzwr_fini() too */
 	NEXTCH;
 }
