@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2009 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -18,7 +19,7 @@ void i2hex_blkfill(int num, uchar_ptr_t addr, int len)
 	unsigned char	buff[8];
 	int		i;
 
-	assert(SIZEOF(buff) >= len);
+	assert((SIZEOF(buff) >= len) && (0 < len));
 	i2hex(num, buff, len);
 	for ( i = 0; i < len - 1 ; i++)
 	{
@@ -34,7 +35,7 @@ void i2hexl_blkfill(qw_num num, uchar_ptr_t addr, int len)
 	unsigned char	buff[16];
 	int		i;
 
-	assert(SIZEOF(buff) >= len);
+	assert((SIZEOF(buff) >= len) && (0 < len));
 	i2hexl(num, buff, len);
 	for ( i = 0; i < len - 1 ; i++)
 	{
