@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2009 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2020 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -20,12 +21,12 @@ int i2hex_nofill(int num, uchar_ptr_t addr, int len)
 
 	assert(SIZEOF(buff) >= len);
 	i2hex(num, buff, len);
-	for (i = 0; i < len - 1 ; i++)
+	for (i = 0; i < (len - 1); i++)
 	{	if (buff[i] != '0')
 			break;
 	}
 	memcpy(addr, &buff[i], len - i);
-	return len - i;
+	return (len - i);
 }
 
 int i2hexl_nofill(qw_num num, uchar_ptr_t addr, int len)
@@ -35,10 +36,10 @@ int i2hexl_nofill(qw_num num, uchar_ptr_t addr, int len)
 
 	assert(SIZEOF(buff) >= len);
 	i2hexl(num, buff, len);
-	for (i = 0; i < len - 1 ; i++)
+	for (i = 0; i < (len - 1); i++)
 	{	if (buff[i] != '0')
 			break;
 	}
 	memcpy(addr, &buff[i], len - i);
-	return len - i;
+	return (len - i);
 }
