@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2024 Fidelity National Information	*
+ * Copyright (c) 2001-2025 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -30,5 +30,5 @@ void ind_cg_var(mtreenode *node, void *var_tabent_arg)
 	COMPUTE_HASH_MNAME(&((*p)[node->var.mvidx]));
 	(*p)[node->var.mvidx].var_name.addr = (char *)((node->var.mvname.addr - (char *)indr_stringpool.base) +
 						ROUND_UP2(SIZEOF(ihdtyp), NATIVE_WSIZE));
-	(*p)[node->var.mvidx].marked = FALSE;
+	(*p)[node->var.mvidx].marked = NOT_MARKED;
 }
