@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -15,8 +16,8 @@
 
 #include "io.h"
 #include "iottdef.h"
+#include "iott_setterm.h"
 #include "error.h"
-#include "setterm.h"
 #include "util.h"
 
 GBLREF io_log_name	*io_root_log_name;
@@ -25,16 +26,18 @@ CONDITION_HANDLER(io_init_ch)
 {
 	io_log_name	*iol;
 
-	START_CH;
+	START_CH(TRUE);
+#	ifdef VMS
 	if (INFO == SEVERITY)
 	{
 		PRN_ERROR;
 		CONTINUE;
 	}
+#	endif
 	for (iol = io_root_log_name;  0 != iol;  iol = iol->next)
 	{
 		if (iol->iod && (iol->iod->type == tt) && iol->iod->dev_sp)
-			resetterm(iol->iod);
+			iott_resetterm(iol->iod);
 	}
 	NEXTCH;
 }
