@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2006 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -14,10 +15,11 @@
 
 GBLREF io_pair io_curr_device;
 
+error_def(ERR_IOEOF);
+
 int ionl_readfl(mval *val, int4 width, int4 timeout)
 {
 	io_desc *dv;
-	error_def(ERR_IOEOF);
 
 	val->str.len = 0;
 	dv = io_curr_device.in;
@@ -26,8 +28,8 @@ int ionl_readfl(mval *val, int4 width, int4 timeout)
 	if (dv->dollar.zeof || (dv->error_handler.len > 0))
 	{
 		dv->dollar.zeof = TRUE;
-		dv->dollar.za = 9;
-		rts_error(VARLSTCNT(1) ERR_IOEOF);
+		dv->dollar.za = ZA_IO_ERR;
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_IOEOF);
 	}
 	dv->dollar.za = 0;
 	dv->dollar.zeof = TRUE;
