@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -43,7 +43,7 @@ error_def(ERR_TEXT);
 boolean_t iosocket_bind(socket_struct *socketptr, int4 msec_timeout, boolean_t update_bufsiz, boolean_t newversion)
 {
 	int			temp_1 = 1;
-	char			*errptr, *charptr;
+	char			*errptr, *charptr = NULL;
 	int4			errlen, real_errno;
 	short			len;
 	in_port_t		actual_port;
@@ -323,6 +323,7 @@ boolean_t iosocket_bind(socket_struct *socketptr, int4 msec_timeout, boolean_t u
 		}
 		if (((gid_t)-1 != socketptr->uic.grp) || ((uid_t)-1 != socketptr->uic.mem))
 		{
+			assert(charptr);
 			CHG_OWNER(charptr, socketptr->uic.mem, socketptr->uic.grp, temp_1);
 			if (temp_1)
 			{
