@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -84,7 +84,6 @@ void iosocket_close(io_desc *iod, mval *pp)
 			break;
 		case iop_socket:
 			handle_len = (int)(unsigned char)*(pp->str.addr + p_offset);
-			assert(handle_len > 0);
 			memcpy(sock_handle, (char *)(pp->str.addr + p_offset + 1), handle_len);
 			socket_specified = TRUE;
 			break;
@@ -161,7 +160,7 @@ void iosocket_close(io_desc *iod, mval *pp)
 void iosocket_close_range(d_socket_struct *dsocketptr, int start, int end, boolean_t socket_delete, boolean_t socket_specified)
 {
 	int4		ii,jj;
-	int		rc, save_fd, save_rc = 0, save_errno;
+	int		rc, save_fd = FD_INVALID, save_rc = 0, save_errno = 0;
 	int		local_process_exiting;
 	ssize_t		status;
 	intrpt_state_t	prev_intrpt_state;
