@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2012-2019 Fidelity National Information	*
+ * Copyright (c) 2012-2022 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -19,6 +19,7 @@
 #include "gtm_stat.h"
 #include "gtm_socket.h"
 #include "gtm_inet.h"
+#include "gtm_limits.h"
 #include "gtm_time.h"
 #include "gtm_caseconv.h"
 #include "gtm_conv.h"
@@ -39,12 +40,12 @@
 #include "indir_enum.h"
 #include "min_max.h"
 
-GBLREF	d_socket_struct		*socket_pool, *newdsocket;
-GBLREF	io_pair			io_std_device;	/* standard device */
 GBLREF	boolean_t		gtm_utf8_mode;
+GBLREF	d_socket_struct		*socket_pool, *newdsocket;
 GBLREF	int4			gtm_max_sockets;
-GBLREF	boolean_t		dollar_zininterrupt;
+GBLREF	io_pair			io_std_device;	/* standard device */
 GBLREF	UConverter		*chset_desc[];
+GBLREF	volatile boolean_t	dollar_zininterrupt;
 
 LITREF 	unsigned char		io_params_size[];
 LITREF	mstr			chset_names[];
@@ -57,12 +58,10 @@ error_def(ERR_DELIMSIZNA);
 error_def(ERR_DELIMWIDTH);
 error_def(ERR_DEVPARINAP);
 error_def(ERR_DEVPARMNEG);
-error_def(ERR_GETNAMEINFO);
 error_def(ERR_ILLESOCKBFSIZE);
 error_def(ERR_MRTMAXEXCEEDED);
 error_def(ERR_SOCKETEXIST);
 error_def(ERR_SOCKMAX);
-error_def(ERR_TEXT);
 error_def(ERR_ZFF2MANY);
 error_def(ERR_ZINTRECURSEIO);
 
@@ -77,6 +76,7 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 	int			new_ozff_len, conv_len, handle_len, moreread_timeout, len;
 	unsigned short		port;
 	int4			errlen, msec_timeout, real_errno, p_offset = 0, zff_len, delimiter_len;
+	int4			options_len = 0;
 	int			d_socket_struct_len, soc_cnt;
 	ABS_TIME		cur_time, end_time;
 	io_desc			*ioptr;
@@ -87,7 +87,7 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 	mv_stent		*mv_zintdev;
 	boolean_t		zint_conn_restart = FALSE;
 	socket_interrupt	*sockintr;
-	mstr			chset_mstr;
+	mstr			chset_mstr, optionstr;
 	gtm_chset_t		default_chset, temp_ichset, temp_ochset;
 	boolean_t		attach_specified = FALSE,
 				listen_specified = FALSE,
@@ -102,6 +102,7 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 				ichset_specified,
 				ochset_specified;
 	unsigned char 		delimiter_buffer[MAX_N_DELIMITER * (MAX_DELIM_LEN + 1)], zff_buffer[MAX_ZFF_LEN];
+	unsigned char		options_buffer[UCHAR_MAX + 1];
 	char			ioerror,
 				sock_handle[MAX_HANDLE_LEN], delimiter[MAX_DELIM_LEN + 1];
 	int			socketptr_delim_len;
@@ -160,7 +161,7 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 		{
 			dsocketptr->mupintr = FALSE;
 			sockintr->who_saved = sockwhich_invalid;
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_ZINTRECURSEIO);
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_ZINTRECURSEIO);
 		}
 		assertpro(sockwhich_connect == sockintr->who_saved);	/* ZINTRECURSEIO should have caught */
 		mv_zintdev = io_find_mvstent(dsocketptr->iod, FALSE);
@@ -207,7 +208,7 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 					if (((MAX_DELIM_LEN + 1) * MAX_N_DELIMITER) >= delimiter_len)
 						memcpy(delimiter_buffer, (pp->str.addr + p_offset + 1), delimiter_len);
 					else
-						rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_DELIMSIZNA);
+						RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_DELIMSIZNA);
 					break;
 				case iop_ipchset:
 					UTF8_ONLY(
@@ -289,35 +290,37 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 				case iop_zbfsize:
 					GET_ULONG(bfsize, pp->str.addr + p_offset);
 					if ((0 == bfsize) || (MAX_SOCKET_BUFFER_SIZE < bfsize))
-						rts_error_csa(CSA_ARG(NULL) VARLSTCNT(3) ERR_ILLESOCKBFSIZE, 1, bfsize);
+						RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(3) ERR_ILLESOCKBFSIZE, 1, bfsize);
 					break;
 				case iop_zibfsize:
 					ibfsize_specified = TRUE;
 					GET_ULONG(ibfsize, pp->str.addr + p_offset);
-					if ((0 == ibfsize) || (MAX_INTERNAL_SOCBUF_SIZE < ibfsize))
-						rts_error_csa(CSA_ARG(NULL) VARLSTCNT(3) ERR_ILLESOCKBFSIZE, 1, bfsize);
+					if (0 == ibfsize)
+						RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(3) ERR_ILLESOCKBFSIZE, 1, bfsize);
 					break;
 				case iop_zlisten:
 					listen_specified = TRUE;
-					len = (int)(*(pp->str.addr + p_offset));
+					len = (int)(unsigned char)*(pp->str.addr + p_offset);
 					if (len < SA_MAXLITLEN)
 					{
 						memset(sockaddr, 0, SIZEOF(sockaddr));
+						assert((0 < len) && (SIZEOF(sockaddr) >= len));
 						memcpy(sockaddr, pp->str.addr + p_offset + 1, len);
 					} else
-						rts_error_csa(CSA_ARG(NULL) VARLSTCNT(6) ERR_ADDRTOOLONG, 4, len,
-								 pp->str.addr + p_offset + 1, len, SA_MAXLITLEN);
+						RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_ADDRTOOLONG, 4, len,
+							pp->str.addr + p_offset + 1, len, SA_MAXLITLEN);
 					break;
 				case iop_connect:
 					connect_specified = TRUE;
-					len = (int)(*(pp->str.addr + p_offset));
+					len = (int)(unsigned char)*(pp->str.addr + p_offset);
 					if (len < SA_MAXLITLEN)
 					{
 						memset(sockaddr, 0, SIZEOF(sockaddr));
+						assert((0 < len) && (SIZEOF(sockaddr) >= len));
 						memcpy(sockaddr, pp->str.addr + p_offset + 1, len);
 					} else
-						rts_error_csa(CSA_ARG(NULL) VARLSTCNT(6) ERR_ADDRTOOLONG, 4,
-								 len, pp->str.addr + p_offset + 1, len, SA_MAXLITLEN);
+						RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_ADDRTOOLONG, 4,
+							len, pp->str.addr + p_offset + 1, len, SA_MAXLITLEN);
 					break;
 				case iop_ioerror:
 					ioerror_specified = TRUE;
@@ -328,19 +331,20 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 					break;
 				case iop_attach:
 					attach_specified = TRUE;
-					handle_len = (int)(*(pp->str.addr + p_offset));
+					handle_len = (int)(unsigned char)*(pp->str.addr + p_offset);
 					if (handle_len > MAX_HANDLE_LEN)
 						handle_len = MAX_HANDLE_LEN;
+					assert((0 < handle_len) && (SIZEOF(sock_handle) >= handle_len));
 					memcpy(sock_handle, pp->str.addr + p_offset + 1, handle_len);
 					break;
 				case iop_socket:
-					rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_DEVPARINAP);
+					RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_DEVPARINAP);
 					break;
 				case iop_zff:
 					if (MAX_ZFF_LEN >= (zff_len = (int4)(unsigned char)*(pp->str.addr + p_offset)))
 						memcpy(zff_buffer, (char *)(pp->str.addr + p_offset + 1), zff_len);
 					else
-						rts_error_csa(CSA_ARG(NULL) VARLSTCNT(4) ERR_ZFF2MANY, 2, zff_len, MAX_ZFF_LEN);
+						RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(4) ERR_ZFF2MANY, 2, zff_len, MAX_ZFF_LEN);
 					break;
 				case iop_znoff:
 					zff_len = 0;
@@ -357,10 +361,10 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 					if (-1 == moreread_timeout)
 						moreread_timeout = DEFAULT_MOREREAD_TIMEOUT;
 					else if (-1 > moreread_timeout)
-						rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_DEVPARMNEG);
+						RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_DEVPARMNEG);
 					else if (MAX_MOREREAD_TIMEOUT < moreread_timeout)
-						rts_error_csa(CSA_ARG(NULL) VARLSTCNT(3) ERR_MRTMAXEXCEEDED, 1,
-								 MAX_MOREREAD_TIMEOUT);
+						RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(3) ERR_MRTMAXEXCEEDED, 1,
+							MAX_MOREREAD_TIMEOUT);
 					moreread_specified = TRUE;
 					break;
 				case iop_newversion:
@@ -387,16 +391,24 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 					break;
 				case iop_w_protection:
 					filemode_mask |= S_IRWXO;
-					filemode |= *(pp->str.addr + p_offset);
+					filemode |= (uint)(unsigned char)*(pp->str.addr + p_offset);
 					break;
 				case iop_g_protection:
 					filemode_mask |= S_IRWXG;
-					filemode |= *(pp->str.addr + p_offset) << 3;
+					filemode |= (uint)(unsigned char)*(pp->str.addr + p_offset) << 3;
 					break;
 				case iop_s_protection:
 				case iop_o_protection:
 					filemode_mask |= S_IRWXU;
-					filemode |= *(pp->str.addr + p_offset) << 6;
+					filemode |= (uint)(unsigned char)*(pp->str.addr + p_offset) << 6;
+					break;
+				case iop_options:
+					options_len = (int4)(unsigned char)*(pp->str.addr + p_offset);
+					if (UCHAR_MAX >= options_len)
+					{
+						memcpy(options_buffer, (unsigned char *)(pp->str.addr + p_offset + 1), options_len);
+						options_buffer[options_len] = '\0';
+					}
 					break;
 				default:
 					break;
@@ -468,17 +480,18 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 			if (MAX_HANDLE_LEN < handle_len)
 				handle_len = MAX_HANDLE_LEN;
 			socketptr->handle_len = handle_len;
+			assert((0 < handle_len) && (SIZEOF(socketptr->handle) >= handle_len));
 			memcpy(socketptr->handle, sock_handle, handle_len);
 			/* connects newdsocket and socketptr (the new socket) */
 			if (gtm_max_sockets <= newdsocket->n_socket)
 			{
 				assert(ioptr->newly_created == FALSE);
 				if (FD_INVALID != socketptr->temp_sd)
-						close(socketptr->temp_sd);
-					SOCKET_FREE(socketptr);
-					rts_error_csa(CSA_ARG(NULL) VARLSTCNT(3) ERR_SOCKMAX, 1, gtm_max_sockets);
-					return FALSE;
-				}
+					close(socketptr->temp_sd);
+				SOCKET_FREE(socketptr);
+				rts_error_csa(CSA_ARG(NULL) VARLSTCNT(3) ERR_SOCKMAX, 1, gtm_max_sockets);
+				return FALSE;
+			}
 			socketptr->dev = newdsocket;
 			newdsocket->socket[newdsocket->n_socket++] = socketptr;
 			newdsocket->current_socket = newdsocket->n_socket - 1;
@@ -488,7 +501,7 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 		if (!socketptr)
 		{	/* If new socket not created, then use the existing (current) socket from the socket device */
 			if (dsocketptr->n_socket <= dsocketptr->current_socket)
-	 		{
+			{
 				assert(FALSE);
 				rts_error_csa(CSA_ARG(NULL) VARLSTCNT(4) ERR_CURRSOCKOFR, 2, dsocketptr->current_socket,
 						dsocketptr->n_socket);
@@ -498,6 +511,12 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 				curr_socketptr = dsocketptr->socket[dsocketptr->current_socket];
 		} else	/* Set to the newly created socket */
 			curr_socketptr = socketptr;
+		if (curr_socketptr && (0 < options_len))
+		{	/* parse and store options in socket struct */
+			optionstr.addr = (char *)options_buffer;
+			optionstr.len = options_len;
+			devoptions(NULL, curr_socketptr, &optionstr, "OPEN", IOP_OPEN_OK);
+		}
 		/* parse the delimiter: delimiter_buffer ==> socketptr->delimiter[...] */
 		if ((0 <= delimiter_len) && (curr_socketptr))
 				iosocket_delimiter(delimiter_buffer, delimiter_len, curr_socketptr, (0 == delimiter_len));
@@ -526,6 +545,7 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 				assert(NULL != curr_socketptr->ozff.addr);
 				free(curr_socketptr->ozff.addr);	/* prevent leak of prior converted form */
 			}
+			assert((0 < zff_len) && (MAX_ZFF_LEN >= zff_len));
 			memcpy(curr_socketptr->zff.addr, zff_buffer, zff_len);
 			curr_socketptr->ozff = curr_socketptr->zff;	/* will contain converted UTF-16 form if needed */
 		} else if (curr_socketptr && (0 == zff_len))
@@ -541,9 +561,6 @@ short	iosocket_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4
 			|| (!iosocket_listen_sock(socketptr, DEFAULT_LISTEN_DEPTH))))
 		|| (connect_specified && (!iosocket_connect(socketptr, timepar, ibfsize_specified))))
 	{
-		if (socketptr->sd > 0)
-			(void)close(socketptr->sd);
-		SOCKET_FREE(socketptr);
 		REVERT_GTMIO_CH(&ioptr->pair, ch_set);
 		return FALSE;
 	} else if (is_principal)
