@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -18,7 +18,7 @@
  * 		-- buffer		pointer to the buffer where to return stuff
  * 		-- maxlength		maximum number of bytes to get
  * 		-- flags		flags to be passed to recv()
- * 		-- time_for_read	pointer to the timeout structure used by select()
+ * 		-- time_for_read	pointer to the timeout structure used by poll()
  * 		-- extra_status		reports either a timeout or a lost-of-connection
  * 	return:
  * 		-- got some stuff to return 		return number of bytes received
@@ -49,11 +49,8 @@ static int fcntl_res;
 #ifdef DEBUG
 #include <sys/time.h>		/* for gettimeofday */
 #endif
-#ifdef GTM_USE_POLL_FOR_SUBSECOND_SELECT
-#include <sys/poll.h>
 #endif
-#endif
-#include "gtm_select.h"
+#include "gtm_poll.h"
 #include "eintr_wrappers.h"
 #include "gt_timer.h"
 #include "io.h"
@@ -121,7 +118,6 @@ ssize_t iosocket_snr(socket_struct *socketptr, void *buffer, size_t maxlength, i
 		recvbuff = buffer;
 		recvsize = maxlength;
 	}
-	VMS_ONLY(recvsize = MIN(recvsize, VMS_MAX_TCP_IO_SIZE));
 	DBGSOCK2((stdout, "socsnr: recvsize set to %d\n", recvsize));
 
 	/* Select and recv */
@@ -156,14 +152,9 @@ ssize_t iosocket_snr_io(socket_struct *socketptr, void *buffer, size_t maxlength
 	int		status, real_errno;
 	ssize_t		bytesread;
 	boolean_t	pollread;
-#	ifdef GTM_USE_POLL_FOR_SUBSECOND_SELECT
-	long		poll_timeout;
-	unsigned long	poll_nfds;
+	int		poll_timeout;
+	nfds_t		poll_nfds;
 	struct pollfd	poll_fdlist[1];
-#	else
-	fd_set		tcp_fd, *readfds, *writefds;
-	struct timeval	lcl_time_for_read;
-#	endif
 #	ifdef GTM_TLS
 	int		tlspolldirection = 0;
 #	endif
@@ -172,10 +163,6 @@ ssize_t iosocket_snr_io(socket_struct *socketptr, void *buffer, size_t maxlength
 		  socketptr, buffer, maxlength, flags));
 	DBGSOCK2((stdout, "time_for_read->at_sec: %d  usec: %d\n", time_for_read->at_sec, time_for_read->at_usec));
 	DEBUG_ONLY(clock_gettime(CLOCK_REALTIME, &tsbefore);)
-#ifndef GTM_USE_POLL_FOR_SUBSECOND_SELECT
-	assertpro(FD_SETSIZE > socketptr->sd);
-	FD_ZERO(&tcp_fd);
-#endif
 	while (TRUE)
 	{
 		status = 0;
@@ -189,28 +176,12 @@ ssize_t iosocket_snr_io(socket_struct *socketptr, void *buffer, size_t maxlength
 			pollread = TRUE;
 		if (0 == status)
 		{	/* if TLS cachedbytes available no need to poll */
-#			ifndef GTM_USE_POLL_FOR_SUBSECOND_SELECT
-			FD_SET(socketptr->sd, &tcp_fd);
-			assert(0 != FD_ISSET(socketptr->sd, &tcp_fd));
-			lcl_time_for_read.tv_sec = time_for_read->at_sec;
-			lcl_time_for_read.tv_usec = (gtm_tv_usec_t)time_for_read->at_usec;
-			if (pollread)
-			{
-				readfds = &tcp_fd;
-				writefds = NULL;
-			} else
-			{
-				writefds = &tcp_fd;
-				readfds = NULL;
-			}
-			status = select(socketptr->sd + 1, readfds, writefds, NULL, &lcl_time_for_read);
-#			else
 			poll_fdlist[0].fd = socketptr->sd;
 			poll_fdlist[0].events = pollread ? POLLIN : POLLOUT;
 			poll_nfds = 1;
+			assert(time_for_read->at_sec == 0);
 			poll_timeout = DIVIDE_ROUND_UP(time_for_read->at_usec, MICROSECS_IN_MSEC);	/* convert to millisecs */
 			status = poll(&poll_fdlist[0], poll_nfds, poll_timeout);
-#			endif
 			real_errno = errno;
 			DEBUG_ONLY(clock_gettime(CLOCK_REALTIME, &tsafter);)
 			DBGSOCK2((stdout, "socsnrio: Select return code: %d :: errno: %d\n", status, real_errno));
@@ -389,10 +360,12 @@ ssize_t iosocket_snr_utf_prebuffer(io_desc *iod, socket_struct *socketptr, int f
 			if (0 > bytesread)
 			{	/* Some error occurred. Check for restartable condition. */
 				if (EINTR == errno)
+				{
 					if (!out_of_time)
 						continue;
 					else
 						return 0;	/* timeout indicator */
+				}
 				return bytesread;
 			}
 			if (out_of_time)
