@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2013-2022 Fidelity National Information	*
+ * Copyright (c) 2013-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -36,7 +36,7 @@
 #include "op.h"
 #include "indir_enum.h"
 
-GBLREF	boolean_t		gtm_utf8_mode;
+GBLREF	boolean_t		gtm_utf8_mode, hup_on;
 GBLREF	d_socket_struct		*newdsocket, *socket_pool;
 GBLREF	int4			gtm_max_sockets;
 GBLREF	io_desc			*active_device;
@@ -44,6 +44,7 @@ GBLREF	io_pair			io_curr_device, io_std_device;
 GBLREF	spdesc			stringpool;
 GBLREF	UConverter  		*chset_desc[];
 GBLREF	volatile boolean_t	dollar_zininterrupt;
+GBLREF	void			(*ctrlc_handler_ptr)();
 
 LITREF	nametabent		filter_names[];
 LITREF	unsigned char		filter_index[27];
@@ -75,14 +76,15 @@ void	iosocket_use(io_desc *iod, mval *pp)
 {
 	unsigned char	ch, len;
 	static char	*conv_buff = NULL;
-	int		new_ozff_len, conv_len, handled_len, handlea_len, handles_len, int_len, soc_cnt;
+	int		new_ozff_len, conv_len, handled_len = -1, handlea_len = -1, handles_len, int_len, soc_cnt;
 	int4		length, width, new_len;
 	d_socket_struct *dsocketptr;
-	socket_struct	*socketptr, *curr_socketptr = NULL, *localsocketptr;
+	socket_struct	*socketptr = NULL, *curr_socketptr = NULL, *localsocketptr;
+	struct sigaction	act;
 	mstr_len_t	delim_len;
 	char		handlea[MAX_HANDLE_LEN], handles[MAX_HANDLE_LEN], handled[MAX_HANDLE_LEN];
 	char		addr[SA_MAXLITLEN], *errptr, sockaddr[SA_MAXLITLEN],
-			temp_addr[SA_MAXLITLEN], ioerror, *free_ozff = NULL;
+			temp_addr[SA_MAXLITLEN], ioerror = 0, *free_ozff = NULL;
 	unsigned char	delimiter_buffer[MAX_N_DELIMITER * (MAX_DELIM_LEN + 1)];
 	unsigned char	zff_buffer[MAX_ZFF_LEN], options_buffer[UCHAR_MAX + 1];
 	boolean_t	attach_specified = FALSE,
@@ -100,16 +102,16 @@ void	iosocket_use(io_desc *iod, mval *pp)
 			moreread_specified = FALSE,
 			flush_specified = FALSE,
 			create_new_socket;
-	int4 		index, n_specified, zff_len, delimiter_len, moreread_timeout, options_len;
+	int4 		index, n_specified, zff_len, delimiter_len, moreread_timeout = -1, options_len;
 	int4		n_specified_dev, n_specified_socket;
 	int4		n_incomplete_dev;	/* device level not done in iop loop */
 	int		fil_type, nodelay, p_offset = 0, newbufsiz;
 	GTM_SOCKLEN_TYPE	sockbuflen;
-	uint4		bfsize = DEFAULT_SOCKET_BUFFER_SIZE, ibfsize;
+	uint4		bfsize = DEFAULT_SOCKET_BUFFER_SIZE, ibfsize = MAXUINT4;
 	char		*tab;
 	int		save_errno;
 	mstr		chset_mstr, optionstr;
-	gtm_chset_t	temp_ochset, temp_ichset;
+	gtm_chset_t	temp_ochset = CHSET_MAX_IDX_ALL, temp_ichset = CHSET_MAX_IDX_ALL;
 	size_t		d_socket_struct_len;
 	boolean_t	ch_set;
 	DCL_THREADGBL_ACCESS;
@@ -376,6 +378,32 @@ void	iosocket_use(io_desc *iod, mval *pp)
 					options_buffer[options_len] = '\0';
 				}
 				break;
+			case iop_hupenable:
+				if (!hup_on)
+				{
+					if (dsocketptr == (d_socket_struct *)io_std_device.in->dev_sp)
+					{	/* socket is principal device */
+						sigemptyset(&act.sa_mask);
+						act.sa_flags = 0;
+						act.sa_handler = ctrlc_handler_ptr;
+						sigaction(SIGHUP, &act, 0);
+						hup_on = TRUE;
+					}
+				}
+				break;
+			case iop_nohupenable:
+				if (hup_on)
+				{
+					if (dsocketptr == (d_socket_struct *)io_std_device.in->dev_sp)
+					{	/* socket is principal device */
+						sigemptyset(&act.sa_mask);
+						act.sa_flags = 0;
+						act.sa_handler = SIG_IGN;
+						sigaction(SIGHUP, &act, 0);
+						hup_on = FALSE;
+					}
+				}
+				break;
 			default:
 				/* ignore deviceparm */
 				break;
@@ -404,6 +432,8 @@ void	iosocket_use(io_desc *iod, mval *pp)
 	}
 	if ((ichset_specified || ochset_specified) && (listen_specified || connect_specified))
 	{	/* CHSET cannot be specified when opening a new socket, if there already are open sockets. */
+		assert(CHSET_MAX_IDX_ALL != temp_ochset);
+		assert(CHSET_MAX_IDX_ALL != temp_ichset);
 		if (0 < dsocketptr->n_socket && ((temp_ochset != iod->ochset) || (temp_ichset != iod->ichset)))
 		{
 			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(10) ERR_CHSETALREADY, 8,
@@ -451,6 +481,7 @@ void	iosocket_use(io_desc *iod, mval *pp)
 		}
 		if (NULL == socket_pool)
 			iosocket_poolinit();
+		assert(0 <= handled_len);
 		iosocket_switch(handled, handled_len, dsocketptr, socket_pool);
 		if (0 > dsocketptr->current_socket)
 		{
@@ -471,6 +502,7 @@ void	iosocket_use(io_desc *iod, mval *pp)
 			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(6) ERR_ANCOMPTINC, 4, LEN_AND_LIT("ATTACH"), LEN_AND_LIT("USE"));
 			return;
 		}
+		assert(0 <= handlea_len);
 		if (NULL == socket_pool)
 		{
 			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(4) ERR_SOCKNOTFND, 2, handlea_len, handlea);
@@ -484,7 +516,7 @@ void	iosocket_use(io_desc *iod, mval *pp)
 	d_socket_struct_len = SIZEOF(d_socket_struct) + (SIZEOF(socket_struct) * (gtm_max_sockets - 1));
 	memcpy(newdsocket, dsocketptr, d_socket_struct_len);
 	/* ------------ create/identify the socket to work on and make a local copy ----------------- */
-	if (create_new_socket = (listen_specified || connect_specified))	/* real "=" */
+	if ((create_new_socket = (listen_specified || connect_specified)))	/* real "=" */
 	{
 		/* allocate the structure for a new socket */
 		if (NULL == (socketptr = iosocket_create(sockaddr, bfsize, -1, listen_specified)))
@@ -535,6 +567,7 @@ void	iosocket_use(io_desc *iod, mval *pp)
 		 * SOCKET_FREE should not be used on this copy since it frees other things such as buffers
 		 * DELIMITER is an exception due to how iosocket_delimiter manages storage.
 		 */
+		assert(socketptr);
 		curr_socketptr = (socket_struct *)malloc(sizeof(socket_struct));
 		memcpy(curr_socketptr, socketptr, sizeof(socket_struct));
 		socketptr->temp_sd = FD_INVALID;
@@ -569,6 +602,7 @@ void	iosocket_use(io_desc *iod, mval *pp)
 	/* Process the CHSET changes */
 	if (ichset_specified)
 	{
+		assert(CHSET_MAX_IDX_ALL != temp_ichset);
 		CHECK_UTF16_VARIANT_AND_SET_CHSET_SOCKET(dsocketptr->ichset_utf16_variant, iod->ichset, temp_ichset,
 								assert(!socketptr));
 		newdsocket->ichset_utf16_variant = dsocketptr->ichset_utf16_variant;
@@ -576,6 +610,7 @@ void	iosocket_use(io_desc *iod, mval *pp)
 	}
 	if (ochset_specified)
 	{
+		assert(CHSET_MAX_IDX_ALL != temp_ochset);
 		CHECK_UTF16_VARIANT_AND_SET_CHSET_SOCKET(dsocketptr->ochset_utf16_variant, iod->ochset, temp_ochset,
 								assert(!socketptr));
 		newdsocket->ochset_utf16_variant = dsocketptr->ochset_utf16_variant;
@@ -681,9 +716,13 @@ void	iosocket_use(io_desc *iod, mval *pp)
 	if (nodelay_specified || delay_specified)
 		curr_socketptr->nodelay = nodelay_specified;	/* defaults to DELAY */
 	if (ibfsize_specified)
+	{
+		assert(MAXUINT4 != ibfsize);
 		curr_socketptr->bufsiz = ibfsize;
+	}
 	if (moreread_specified)
 	{
+		assert(0 <= moreread_timeout);
 		curr_socketptr->moreread_timeout = moreread_timeout;
 		curr_socketptr->def_moreread_timeout = TRUE;	/* need to know this was user-defined in iosocket_readfl.c */
 	}
