@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -15,11 +15,7 @@
 #include "mdef.h"
 
 #include <errno.h>
-#ifdef USE_POLL
 #include "gtm_poll.h"
-#else
-#include "gtm_select.h"
-#endif
 #include "gtm_socket.h"
 #include "gtm_inet.h"
 #include "gtm_stdio.h"
@@ -48,13 +44,14 @@
 #include "gtm_tls.h"
 #endif
 
-GBLREF boolean_t		prin_in_dev_failure, prin_out_dev_failure;
+GBLREF boolean_t		hup_on, prin_dm_io, prin_in_dev_failure, prin_out_dev_failure;
 GBLREF io_pair			io_curr_device, io_std_device;
 GBLREF mstr			chset_names[];
 GBLREF mval			dollar_zstatus;
 GBLREF spdesc			stringpool;
 GBLREF UConverter		*chset_desc[];
 GBLREF volatile int4		outofband;
+GBLREF int4			exi_condition;
 #ifdef GTM_TLS
 GBLREF	gtm_tls_ctx_t		*tls_ctx;
 #endif
@@ -62,6 +59,7 @@ GBLREF	gtm_tls_ctx_t		*tls_ctx;
 error_def(ERR_CURRSOCKOFR);
 error_def(ERR_NOPRINCIO);
 error_def(ERR_NOSOCKETINDEV);
+error_def(ERR_SOCKHANGUP);
 error_def(ERR_SOCKPASSDATAMIX);
 error_def(ERR_SOCKWRITE);
 error_def(ERR_TEXT);
@@ -206,12 +204,7 @@ ssize_t iosocket_output(socket_struct *socketptr, char *buffer, size_t length, b
 #	ifdef GTM_TLS
 	int		tlspolldirection = 0, short_sends = 0, save_errno2 = 0;
 #	endif
-#	ifdef USE_POLL
 	struct pollfd	fds;
-#	else
-	fd_set		fds, *readfds, *writefds;
-	struct timeval	timeout_spec;
-#	endif
 
 	*written = local_written = 0;
 	if (!socketptr->obuffer_output_active)
@@ -226,40 +219,20 @@ ssize_t iosocket_output(socket_struct *socketptr, char *buffer, size_t length, b
 		assert(0 != socketptr->obuffer_wait_time);
 		timeout = socketptr->obuffer_wait_time;
 	}
-#	ifndef USE_POLL
-	FD_ZERO(&fds);
-	FD_SET(socketptr->sd, &fds);
-	timeout = timeout * 1000;	/* convert milli to micro seconds */
-	timeout_spec.tv_sec = 0;
-	timeout_spec.tv_usec = timeout;
-#	endif
 	llen = length;
 	output_retries = status = 0;
 	lbuffer = buffer;
 	while ((0 == status) && (0 < llen))
-	{	/* poll/select tlspolldirection - needed if noblocking */
+	{	/* poll tlspolldirection - needed if noblocking */
 #		ifdef GTM_TLS
 		if (socketptr->tlsenabled)
 			pollwrite = (tlspolldirection == GTMTLS_WANT_READ) ? FALSE : TRUE;
 		else
 #		endif
 			pollwrite = TRUE;
-#		ifdef USE_POLL
 		fds.fd = socketptr->sd;
 		fds.events = pollwrite ? POLLOUT : POLLIN;
 		istatus = poll(&fds, 1, timeout);
-#		else
-		if (pollwrite)
-		{
-			writefds = &fds;
-			readfds = NULL;
-		} else
-		{
-			readfds = &fds;
-			writefds = NULL;
-		}
-		istatus = select(socketptr->sd + 1, readfds, writefds, NULL, &timeout_spec);
-#		endif
 		if (-1 == istatus)
 		{
 			save_errno = errno;
@@ -290,13 +263,9 @@ ssize_t iosocket_output(socket_struct *socketptr, char *buffer, size_t length, b
 				status = -1;
 				break;
 			}
-#			ifndef USE_POLL
-			timeout_spec.tv_usec = timeout;
-			FD_SET(socketptr->sd, &fds);
-#			endif
 			continue;
 		} else if (0 == istatus)
-		{	/* poll/select timedout */
+		{	/* poll timedout */
 			if (socketptr->nonblocking && (++output_retries > socketptr->max_output_retries))
 			{
 				save_errno = socketptr->obuffer_errno = EAGAIN;
@@ -514,15 +483,23 @@ void	iosocket_write_real(mstr *v, boolean_t convert_output)
 
 	DBGSOCK2((stdout, "socwrite: ************************** Top of iosocket_write\n"));
 	iod = io_curr_device.out;
+	if (ERR_SOCKHANGUP == error_condition)
+	{
+		SOCKHUP_NOPRINCIO_CHECK(TRUE);
+		return;
+	}
 	ESTABLISH_GTMIO_CH(&iod->pair, ch_set);
 	assert(gtmsocket == iod->type);
 	dsocketptr = (d_socket_struct *)iod->dev_sp;
 	if (0 >= dsocketptr->n_socket)
 	{
-		if (iod == io_std_device.out)
+		if ((iod == io_std_device.out) && (!prin_dm_io))
 			ionl_write(v);
 		else
+		{
+			prin_out_dev_failure = TRUE;
 			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_NOSOCKETINDEV);
+		}
 		REVERT_GTMIO_CH(&iod->pair, ch_set);
 		return;
 	}
