@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2019 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -85,7 +85,7 @@ char	*jnl2extcvt(jnl_record *rec, int4 jnl_len, char **ext_buff, int *extract_bu
 			tmp = malloc(tmpbufsiz);
 			origbuf = *ext_buff;
 			tmpsize = extbuf - origbuf;
-			memcpy(tmp, origbuf, tmpsize);
+			memcpy((void *)tmp, origbuf, tmpsize);
 			free(origbuf);
 			*ext_buff = tmp;
 			*extract_bufsiz = tmpbufsiz;
@@ -102,8 +102,8 @@ char	*jnl2extcvt(jnl_record *rec, int4 jnl_len, char **ext_buff, int *extract_bu
 
 char	*jnl2ext(char *jnl_buff, char *ext_buff, char *ext_bufftop)
 {
-  	char		*curr, *val_ptr, rectype;
-	unsigned char	*ptr;
+	char		*curr, *val_ptr;
+	unsigned char	*ptr, rectype;
 	jnl_record	*rec;
 	gv_key		*key;
 	jnl_string	*keystr, *ztwormstr;
