@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2003-2023 Fidelity National Information	*
+ * Copyright (c) 2003-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -86,6 +86,7 @@ uint4 jnl_file_open_common(gd_region *reg, off_jnl_t os_file_size, char *buff, s
 	off_jnl_t		adjust;
 	uint4			end_of_data, jnl_fs_block_size, read_write_size, read_size;
 	int4			status;
+	int			gdid_err = 0;
 	gtm_uint64_t		header_virtual_size;
 	DCL_THREADGBL_ACCESS;
 
@@ -146,7 +147,7 @@ uint4 jnl_file_open_common(gd_region *reg, off_jnl_t os_file_size, char *buff, s
 		sgtm_putmsg(buff, buff_len, VARLSTCNT(7) ERR_JNLOPNERR, 4, JNL_LEN_STR(csd), DB_LEN_STR(reg), ERR_JNLPREVRECOV);
 		RETURN_AND_SET_JPC(ERR_JNLOPNERR, ERR_JNLPREVRECOV, buff);
 	}
-	if (!is_gdid_file_identical(&FILE_ID(reg), (char *)header->data_file_name, header->data_file_name_length))
+	if (!is_gdid_file_identical(&FILE_ID(reg), (char *)header->data_file_name, header->data_file_name_length, &gdid_err))
 	{
 		rts_error_csa(CSA_ARG(csa) VARLSTCNT(7) ERR_JNLOPNERR, 4, JNL_LEN_STR(csd), DB_LEN_STR(reg), ERR_FILEIDMATCH);
 		assert(FALSE);	/* we don't expect the rts_error in the line above to return */
