@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2005-2018 Fidelity National Information	*
+ * Copyright (c) 2005-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -12,11 +12,10 @@
 #ifndef JNL_GET_CHECKSUM_H_INCLUDED
 #define JNL_GET_CHECKSUM_H_INCLUDED
 
-#define INIT_CHECKSUM_SEED 0xFFFFFFFF
+#define INIT_CHECKSUM_SEED ((uint4) ~0x0)
 
 #define SLICE_BY	4
 #define TABLE_SIZE	256
-#define BYTEMASK	0xFF
 
 GBLREF uint4 csum_table[SLICE_BY][TABLE_SIZE];
 
@@ -34,10 +33,10 @@ MBSTART {														\
 #define HIBYTE	3
 #define ADJUST_CHECKSUM(cursum, num4, newsum)										\
 MBSTART {														\
-	uint4 tmpsum = csum_table[HIBYTE - 0][(cursum ^ num4) & BYTEMASK] ^ 						\
-			csum_table[HIBYTE - 1][((cursum ^ num4) >> (1 * BITS_PER_UCHAR)) & BYTEMASK] ^			\
-			csum_table[HIBYTE - 2][((cursum ^ num4) >> (2 * BITS_PER_UCHAR)) & BYTEMASK] ^ 			\
-			csum_table[HIBYTE - 3][((cursum ^ num4) >> (3 * BITS_PER_UCHAR)) & BYTEMASK]; 			\
+	uint4 tmpsum = csum_table[HIBYTE - 0][(cursum ^ (num4)) & BYTEMASK] ^ 						\
+			csum_table[HIBYTE - 1][((cursum ^ (num4)) >> (1 * BITS_PER_UCHAR)) & BYTEMASK] ^		\
+			csum_table[HIBYTE - 2][((cursum ^ (num4)) >> (2 * BITS_PER_UCHAR)) & BYTEMASK] ^ 		\
+			csum_table[HIBYTE - 3][((cursum ^ (num4)) >> (3 * BITS_PER_UCHAR)) & BYTEMASK]; 		\
 	newsum = tmpsum ? tmpsum : INIT_CHECKSUM_SEED;									\
 } MBEND
 #endif
@@ -45,13 +44,16 @@ MBSTART {														\
 #define ADJUST_CHECKSUM_TN(cursum, tn, newsum)										\
 MBSTART {														\
 	uint4 tmpsum_tn;												\
-	ADJUST_CHECKSUM(cursum, *(uint4 *)tn, tmpsum_tn);								\
-	ADJUST_CHECKSUM(tmpsum_tn, *(uint4 *)((char *)tn + SIZEOF(uint4)), newsum);					\
+	ADJUST_CHECKSUM(cursum, *(uint4 *)(tn), tmpsum_tn);								\
+	ADJUST_CHECKSUM(tmpsum_tn, *(uint4 *)((char *)(tn) + SIZEOF(uint4)), newsum);					\
 } MBEND
 
 #define COMPUTE_COMMON_CHECKSUM(common_cksum, prefix)									\
 MBSTART {														\
-	ADJUST_CHECKSUM_TN(INIT_CHECKSUM_SEED, &(prefix.tn), common_cksum);						\
+	trans_num_cksum		tn;											\
+															\
+	tn.tn = (prefix).tn;												\
+	ADJUST_CHECKSUM_TN(INIT_CHECKSUM_SEED, tn.enc, common_cksum);							\
 	ADJUST_CHECKSUM(common_cksum, prefix.pini_addr, common_cksum);							\
 	ADJUST_CHECKSUM(common_cksum, prefix.time, common_cksum);							\
 } MBEND
