@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2003-2016 Fidelity National Information	*
+ * Copyright (c) 2003-2017 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -13,9 +13,6 @@
 #include "mdef.h"
 
 #include "gtm_inet.h"
-#ifdef VMS
-#include <descrip.h> /* Required for gtmsource.h */
-#endif
 
 #include "gtm_time.h"
 #include "gdsroot.h"
@@ -38,14 +35,13 @@
 GBLREF	jnl_fence_control	jnl_fence_ctl;
 GBLREF 	jnl_gbls_t		jgbl;
 GBLREF	seq_num			seq_num_zero;
-GBLREF	trans_num		local_tn;	/* transaction number for THIS PROCESS */
 GBLREF	uint4			process_id;
 
-void	jnl_write_ztp_logical(sgmnt_addrs *csa, jnl_format_buffer *jfb, uint4 com_csum, seq_num jnl_seqno,
-				jnlpool_write_ctx_t *jplctx)
+void	jnl_write_ztp_logical(sgmnt_addrs *csa, jnl_format_buffer *jfb, uint4 com_csum, seq_num jnl_seqno)
 {
 	struct_jrec_upd		*jrec;
 	jnl_private_control	*jpc;
+	boolean_t		in_phase2;
 
 	/* If REPL_WAS_ENABLED(csa) is TRUE, then we would not have gone through the code that initializes
 	 * jgbl.gbl_jrec_time or jpc->pini_addr. But in this case, we are not writing the journal record
@@ -55,27 +51,17 @@ void	jnl_write_ztp_logical(sgmnt_addrs *csa, jnl_format_buffer *jfb, uint4 com_c
 	jpc = csa->jnl;
 	assert((0 != jpc->pini_addr) || REPL_WAS_ENABLED(csa));
 	assert(jgbl.gbl_jrec_time || REPL_WAS_ENABLED(csa));
-	assert(csa->now_crit);
 	assert(IS_SET_KILL_ZKILL_ZTRIG(jfb->rectype));
 	assert(IS_ZTP(jfb->rectype));
 	jrec = (struct_jrec_upd *)jfb->buff;
 	jrec->prefix.pini_addr = (0 == jpc->pini_addr) ? JNL_HDR_LEN : jpc->pini_addr;
-	jrec->prefix.tn = csa->ti->curr_tn;
+	in_phase2 = IN_PHASE2_JNL_COMMIT(csa);
+	jrec->prefix.tn = JB_CURR_TN_APPROPRIATE(in_phase2, jpc, csa);
 	jrec->prefix.time = jgbl.gbl_jrec_time;
-	if (QWEQ(jnl_fence_ctl.token, seq_num_zero))
-	{	/* generate token once after op_ztstart and use for all its mini-transactions
-		 * jnl_fence_ctl.token is set to seq_num_zero in op_ztstart */
-		if (REPL_ALLOWED(csa))
-			QWASSIGN(jnl_fence_ctl.token, jnl_seqno);
-		else
-		{
-			TOKEN_SET(&jnl_fence_ctl.token, local_tn, process_id);
-		}
-	}
 	assert(0 != jnl_fence_ctl.token);
 	jrec->token_seq.token = jnl_fence_ctl.token;
 	jrec->strm_seqno = 0;	/* strm_seqno is only for replication & ZTCOM does not work with replic */
 	COMPUTE_LOGICAL_REC_CHECKSUM(jfb->checksum, jrec, com_csum, jrec->prefix.checksum);
 	assert(!REPL_ALLOWED(csa));
-	JNL_WRITE_APPROPRIATE(csa, jpc, jfb->rectype, (jnl_record *)jrec, NULL, jfb, jplctx);
+	JNL_WRITE_APPROPRIATE(csa, jpc, jfb->rectype, (jnl_record *)jrec, jfb);
 }
