@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -14,6 +14,6 @@
 #define LKE_CLEARTREE_H_INCLUDED
 
 bool lke_cleartree(mlk_pvtctl_ptr_t pctl, struct CLB *lnk, mlk_shrblk_ptr_t tree, bool all,
-			bool interactive, int4 pid, mstr one_lock, boolean_t exact);
+			bool interactive, int4 pid, mstr one_lock, boolean_t exact, intrpt_state_t *prev_intrpt_state);
 
 #endif
