@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -11,6 +12,7 @@
 
 #include "mdef.h"
 #include "gtm_caseconv.h"
+#include "gtm_ctype.h"
 
 LITREF unsigned char lower_to_upper_table[];
 
@@ -20,6 +22,6 @@ void lower_to_upper(uchar_ptr_t d, uchar_ptr_t s, int4 len)
 
 	d_top = d + len;
 	for ( ; d < d_top; )
-	{	*d++ = lower_to_upper_table[*s++];
+	{	*d++ = TOUPPER(*s++);
 	}
 }
