@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2011 Fidelity Inforformation Services, Inc	*
+ * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -14,6 +15,7 @@
 #include "opcode.h"
 #include "toktyp.h"
 #include "cmd.h"
+#include "start_fetches.h"
 
 int m_break(void)
 {
@@ -24,9 +26,7 @@ int m_break(void)
 		if (!m_xecute())
 			return FALSE;
 	newtriple(OC_BREAK);
-	if (TREF(for_stack_ptr) == TADR(for_stack))
-		start_fetches (OC_FETCH);
-	else
-		start_for_fetches ();
+	/* Because the activity in direct mode brought on by the BREAK can alter the environment, start a new fetch */
+	MID_LINE_REFETCH;
 	return TRUE;
 }
