@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2024 Fidelity National Information	*
+ * Copyright (c) 2001-2025 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -41,6 +41,7 @@ int m_xecute(void)
 	oprtype		*cr, x;
 	triple		*obp, *oldchain, *ref0, *ref1, tmpchain, *triptr;
 	mval		*v;
+	boolean_t	tval;
 	DCL_THREADGBL_ACCESS;
 
 	SETUP_THREADGBL_ACCESS;
@@ -133,9 +134,10 @@ int m_xecute(void)
 		if (OC_LIT == triptr->opcode)
 		{	/* it is a literal so optimize it */
 			v = &triptr->operand[0].oprval.mlit->v;
+			tval = MV_FORCE_BOOL(v);
 			unuse_literal(v);
 			dqdel(triptr, exorder);
-			if (0 == MV_FORCE_BOOL(v))
+			if (0 == tval)
 				setcurtchain(oldchain);	/* it's FALSE so just discard the whole thing */
 			else
 			{	/* it's TRUE so treat as if no argument postconditional */
