@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -137,6 +137,7 @@ error_def(ERR_MEMORY);
 error_def(ERR_NOEXCNOZTRAP);
 error_def(ERR_NOTPRINCIO);
 error_def(ERR_REPEATERROR);
+error_def(ERR_SOCKHANGUP);
 error_def(ERR_STACKCRIT);
 error_def(ERR_STACKOFLOW);
 error_def(ERR_TERMHANGUP);
@@ -251,6 +252,7 @@ CONDITION_HANDLER(mdb_condition_handler)
 	boolean_t		error_in_zyerror;
 	boolean_t		compile_time;
 	boolean_t		repeat_error, etrap_handling, reset_mpc;
+	boolean_t		hangup;
 	int			level, rc;
 	boolean_t		reserve_sock_dev = FALSE;
 	unix_db_info		*udi;
@@ -272,7 +274,7 @@ CONDITION_HANDLER(mdb_condition_handler)
 			remove_rms(gtm_err_dev);
 		gtm_err_dev = NULL;
 	}
-	if (repeat_error = (ERR_REPEATERROR == SIGNAL)) /* assignment and comparison */
+	if ((repeat_error = (ERR_REPEATERROR == SIGNAL))) /* assignment and comparison */
 		SIGNAL = dollar_ecode.error_last_ecode;
 	preemptive_db_clnup(SEVERITY);
 	assert(NULL == alias_retarg);
@@ -286,10 +288,10 @@ CONDITION_HANDLER(mdb_condition_handler)
 		 * we signal the error and do it here
 		 */
 		neterr_pending = TRUE;
-                FIX_XFER_ENTRY(xf_linefetch, op_fetchintrrpt);
-                FIX_XFER_ENTRY(xf_linestart, op_startintrrpt);
-                FIX_XFER_ENTRY(xf_forchk1, op_startintrrpt);
-                FIX_XFER_ENTRY(xf_forloop, op_forintrrpt);
+		FIX_XFER_ENTRY(xf_linefetch, op_fetchintrrpt);
+		FIX_XFER_ENTRY(xf_linestart, op_startintrrpt);
+		FIX_XFER_ENTRY(xf_forchk1, op_startintrrpt);
+		FIX_XFER_ENTRY(xf_forloop, op_forintrrpt);
 		CONTINUE;
 	}
 	MDB_START;
@@ -602,7 +604,6 @@ CONDITION_HANDLER(mdb_condition_handler)
 	if ((int)ERR_CTRLC == SIGNAL)
 	{
 		xfer_reset_if_setter(ctrlc);
-		outofband = no_event;
 		if (!trans_action && !dm_action)
 		{	/* Verify not indirect or that context is unchanged before reset context */
 			assert(NULL != frame_pointer->restart_pc);
@@ -642,12 +643,12 @@ CONDITION_HANDLER(mdb_condition_handler)
 			dec_err(VARLSTCNT(4) ERR_NOTPRINCIO, 2, io_curr_device.out->trans_name->len,
 				io_curr_device.out->trans_name->dollar_io);
 		MUM_TSTART;
-	} else if (((int)ERR_CTRAP == SIGNAL) || ((int)ERR_TERMHANGUP == SIGNAL))
+	} else if ((hangup = ((int)ERR_TERMHANGUP == SIGNAL) || ((int)ERR_SOCKHANGUP == SIGNAL)) || ((int)ERR_CTRAP == SIGNAL))
 	{
 		if (outofband && !repeat_error)
 		{	/* don't need to do this again if re-throwing the error */
-			assert((((int)ERR_TERMHANGUP == SIGNAL) ? sighup : ctrap) == outofband);
-			if ((int)ERR_TERMHANGUP == SIGNAL)
+			assert((hangup ? sighup : ctrap) == outofband);
+			if (hangup)
 			{
 				assert(hup_on || prin_in_dev_failure);
 				SAVE_ZSTATUS_INTO_RTS_STRINGPOOL(dollar_ecode.error_last_b_line, NULL);
@@ -658,7 +659,6 @@ CONDITION_HANDLER(mdb_condition_handler)
 			real_xfer_reset(outofband);
 			TAREF1(save_xfer_root, outofband).event_state = not_in_play;	/* sighup & ctrap both headed to trap */
 		}
-		outofband = no_event;
 		if (!trans_action && !(frame_pointer->type & SFT_DM))
 		{
 			if (!repeat_error)
