@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -13,11 +14,7 @@
 
 /* Declare parms for mlk_prcblk_add.c */
 
-void mlk_prcblk_add(gd_region *region,
-		    mlk_ctldata_ptr_t ctl,
-		    mlk_shrblk_ptr_t d,
-		    uint4 pid);
-
+boolean_t	mlk_prcblk_add(gd_region *region, mlk_ctldata_ptr_t ctl, mlk_shrblk_ptr_t d, uint4 pid);
 
 #define MLK_PRCBLK_ADD_DEFINED
 
