@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -82,38 +82,39 @@ Input Parameters:
 	i_blk_fill_size : Maximum fill allowed in an index block
 Output Parameters:
 	kill_set_ptr : List of blocks to be freed from LBM (already killed in mu_clsce)
-	remove_rtsib : if right sibling was completely merged with working
+	pending_levels : A count of number of levels to ascend in order to handle effects of
+	rightsibling removal in previous coalesces
 Returns:
 	cdb_sc_normal on success
 	Other wise error status
  *************************************************************************************************/
-enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_set_ptr, boolean_t *remove_rtsib)
+enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_set_ptr, int *pending_levels, const int min_level)
 {
-	boolean_t	complete_merge = FALSE,
-			old_ref_star_only = FALSE,
+	boolean_t	old_ref_star_only = FALSE,
 			new_rtsib_star_only = FALSE,
 			star_only_merge = FALSE,
 			blk2_ances_star_only = FALSE,
 			delete_all_blk2_ances = TRUE,
 			levelp_next_is_star, forward_process,
 			old_blk1_long_blk_id, old_blk2_long_blk_id,
-			long_blk_id;
+			old_levelp_long_blk_id, long_blk_id;
 	unsigned char	oldblk1_prev_key[MAX_KEY_SZ+1],
 			old_levelp_cur_prev_key[MAX_KEY_SZ+1],
 			old_levelp_cur_key[MAX_KEY_SZ+1]; /* keys in private memory */
 	unsigned short	temp_ushort;
 	int		new_levelp_cur_cmpc, new_levelp_cur_next_cmpc, tkeycmpc,
-			oldblk1_last_cmpc, newblk1_mid_cmpc, newblk1_last_cmpc;
-	int		tmp_cmpc;
+			oldblk1_last_cmpc, newblk1_mid_cmpc = -1, newblk1_last_cmpc;
+	int		tmp_cmpc, lcl_pending_levels = 0;
 	int		levelp, level2;
 	int		old_blk1_sz, old_blk2_sz,
-			bstar_rec_sz, blkid_sz;
+			bstar_rec_sz, blkid_sz,
+			old_levelp_bstar_rec_sz, old_levelp_blkid_sz;
 	int		old_levelp_cur_prev_keysz,
 			old_levelp_cur_keysz,
-			old_levelp_cur_next_keysz,
-			newblk1_last_keysz,
-			newblk2_first_keysz,
-			new_blk2_ances_first_keysz;
+			old_levelp_cur_next_keysz = 0,
+			newblk1_last_keysz = 0,
+			newblk2_first_keysz = 0,
+			new_blk2_ances_first_keysz = 0;
 	int		old_levelp_cur_keylen,
 			new_levelp_cur_keylen,
 			old_levelp_cur_next_keylen,
@@ -121,17 +122,17 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 			oldblk1_last_keylen,
 			newblk1_last_keylen,
 			newblk2_first_keylen;
-	int		rec_size, piece_len, tkeylen, old_levelp_rec_offset;
-	int		blk_seg_cnt, blk_size;
+	int		rec_size, piece_len = -1, tkeylen, old_levelp_rec_offset;
+	int		blk_seg_cnt, blk_size, exp_level = level;
 	enum cdb_sc	status;
-	sm_uc_ptr_t	oldblk1_last_key, old_levelp_cur_next_key,
-			newblk1_last_key, newblk2_first_key, new_blk2_ances_first_key; /* shared memory keys */
+	sm_uc_ptr_t	oldblk1_last_key, old_levelp_cur_next_key = NULL,
+			newblk1_last_key, newblk2_first_key = NULL, new_blk2_ances_first_key = NULL; /* shared memory keys */
 	sm_uc_ptr_t	rec_base, old_levelp_blk_base,
-			bn_ptr1, bn_ptr2, blk2_ances_remain, old_blk1_base, old_blk2_base,
-			new_blk1_top, new_blk2_first_rec_base, new_blk2_remain; /* shared memory pointers */
+			bn_ptr1, bn_ptr2, blk2_ances_remain = NULL, old_blk1_base, old_blk2_base,
+			new_blk1_top, new_blk2_first_rec_base, new_blk2_remain = NULL; /* shared memory pointers */
 	sm_uc_ptr_t	rPtr1, rPtr2;
-	rec_hdr_ptr_t	star_rec_hdr, old_last_rec_hdr1, new_rec_hdr1, new_rec_hdr2,
-			blk2_ances_hdr, new_levelp_cur_hdr, new_levelp_cur_next_hdr;
+	rec_hdr_ptr_t	old_levelp_star_rec_hdr, star_rec_hdr, old_last_rec_hdr1, new_rec_hdr1 = NULL, new_rec_hdr2 = NULL,
+			blk2_ances_hdr = NULL, new_levelp_cur_hdr, new_levelp_cur_next_hdr;
 	blk_segment	*bs_ptr1, *bs_ptr2;
 	srch_hist	*blk1ptr, *blk2ptr; /* blk2ptr is for right sibling's hist from a minimum sub-tree containing both blocks */
 	srch_blk_status	*old_blk1_stat, *old_blk2_stat, *old_levelp_blk_stat;
@@ -145,18 +146,12 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 	old_blk1_base = old_blk1_stat->buffaddr;
 	old_blk2_stat = &blk2ptr->h[level];
 	old_blk2_base = old_blk2_stat->buffaddr;
-	if (((blk_hdr_ptr_t)old_blk1_base)->bver != ((blk_hdr_ptr_t)old_blk2_base)->bver)
-	{
-		assert(t_tries < CDB_STAGNATE);
-		NONTP_TRACE_HIST_MOD(old_blk1_stat, t_blkmod_mu_clsce);
-		return cdb_sc_blkmod;
-	}
+	if ((0 != level) && (((blk_hdr_ptr_t)old_blk1_base)->bver != ((blk_hdr_ptr_t)old_blk2_base)->bver))
+		return cdb_sc_oprnotneeded;	/* Allow REORG to continue in spite of the mismatch */
 	old_blk1_sz = ((blk_hdr_ptr_t)old_blk1_base)->bsiz;
 	old_blk2_sz = ((blk_hdr_ptr_t)old_blk2_base)->bsiz;
 	old_blk1_long_blk_id = (BLK_ID_32_VER < ((blk_hdr_ptr_t)old_blk1_base)->bver);
 	old_blk2_long_blk_id = (BLK_ID_32_VER < ((blk_hdr_ptr_t)old_blk2_base)->bver);
-	if(old_blk1_long_blk_id != old_blk2_long_blk_id)
-		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_GTMCURUNSUPP);
 	long_blk_id = old_blk1_long_blk_id;
 	bstar_rec_sz = bstar_rec_size(long_blk_id);
 	blkid_sz = long_blk_id ? SIZEOF(block_id_64) : SIZEOF(block_id_32);
@@ -178,9 +173,12 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 		old_levelp_blk_stat = &blk1ptr->h[levelp];
 		old_levelp_blk_base = old_levelp_blk_stat->buffaddr;
 		old_levelp_rec_offset = blk1ptr->h[levelp].curr_rec.offset;
+		old_levelp_long_blk_id = (BLK_ID_32_VER < ((blk_hdr_ptr_t)old_levelp_blk_base)->bver);
+		old_levelp_bstar_rec_sz = bstar_rec_size(old_levelp_long_blk_id);
+		old_levelp_blkid_sz = old_levelp_long_blk_id ? SIZEOF(block_id_64) : SIZEOF(block_id_32);
 		rec_base = old_levelp_blk_base + old_levelp_rec_offset;
 		GET_RSIZ(rec_size, rec_base);
-	} while (bstar_rec_sz == rec_size); /* search ancestors to get a real value */
+	} while (old_levelp_bstar_rec_sz == rec_size); /* search ancestors to get a real value */
 
 	/*
 	old_levelp_cur_prev_key = real value of the key before the curr_key at levelp
@@ -191,13 +189,14 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 		old_levelp_cur_prev_keysz = 0;
 	else
 	{
-		if (cdb_sc_normal != (status = gvcst_expand_any_key (old_levelp_blk_stat, rec_base,
-			&old_levelp_cur_prev_key[0], &rec_size, &tkeylen, &tkeycmpc, NULL)))
+		if (cdb_sc_normal != (status = gvcst_expand_any_key(old_levelp_blk_stat, rec_base,
+			&old_levelp_cur_prev_key[0], &rec_size, &tkeylen, &tkeycmpc, NULL, &exp_level)))
 		{
 			assert(t_tries < CDB_STAGNATE);
 			NONTP_TRACE_HIST_MOD(old_levelp_blk_stat, t_blkmod_mu_clsce);
 			return cdb_sc_blkmod;
 		}
+		assert((levelp == exp_level) || (t_tries < CDB_STAGNATE));
 		old_levelp_cur_prev_keysz = tkeylen + tkeycmpc;
 	}
 
@@ -242,7 +241,6 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 		levelp_next_is_star = FALSE;
 	}
 
-
 	/*
 	Now process the actual working block at current level
 		oldblk1_last_key = real value of last key of the working block
@@ -254,14 +252,16 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 	BLK_ADDR(oldblk1_last_key, MAX_KEY_SZ + 1, unsigned char);
 	if (0 == level) /* data block */
 	{
-		if (cdb_sc_normal != (status = gvcst_expand_any_key (old_blk1_stat, old_blk1_base + old_blk1_sz,
-			oldblk1_last_key, &rec_size, &oldblk1_last_keylen, &oldblk1_last_cmpc, NULL)))
+		if (cdb_sc_normal != (status = gvcst_expand_any_key(old_blk1_stat, old_blk1_base + old_blk1_sz,
+			oldblk1_last_key, &rec_size, &oldblk1_last_keylen, &oldblk1_last_cmpc, NULL, &exp_level)))
 		{
 			assert(t_tries < CDB_STAGNATE);
 			NONTP_TRACE_HIST_MOD(old_blk1_stat, t_blkmod_mu_clsce);
 			return cdb_sc_blkmod;
 		}
+		assert((0 == exp_level) || (t_tries < CDB_STAGNATE));
 		rec_base = old_blk1_base + old_blk1_sz;
+		old_last_rec_hdr1 = NULL;
 	} else  /* Index blocks */
 	{
 		/* Since we will join this working block with the right sibling,
@@ -271,14 +271,15 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 		memcpy (oldblk1_last_key, &old_levelp_cur_key[0], old_levelp_cur_keysz);
 		if (!old_ref_star_only) /* if the index block is not a *-key only block) */
 		{
-			if (cdb_sc_normal != (status = gvcst_expand_any_key (old_blk1_stat,
+			if (cdb_sc_normal != (status = gvcst_expand_any_key(old_blk1_stat,
 				old_blk1_base + old_blk1_sz - bstar_rec_sz, &oldblk1_prev_key[0],
-				&rec_size, &tkeylen, &tkeycmpc, NULL)))
+				&rec_size, &tkeylen, &tkeycmpc, NULL, &exp_level)))
 			{
 				assert(t_tries < CDB_STAGNATE);
 				NONTP_TRACE_HIST_MOD(old_blk1_stat, t_blkmod_mu_clsce);
 				return cdb_sc_blkmod;
 			}
+			assert((level == exp_level) || (t_tries < CDB_STAGNATE));
 			GET_CMPC(oldblk1_last_cmpc, oldblk1_prev_key, old_levelp_cur_key);
 			oldblk1_last_keylen = old_levelp_cur_keysz - oldblk1_last_cmpc;
 		}
@@ -294,14 +295,15 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 	}
 
 	/*
-	newblk1_last_key = new working blocks final appended key
-	newblk1_mid_cmpc = new working blocks firstly appended key's cmpc
-	newblk1_last_keysz = new working blocks lastly appended key's size
-	star_only_merge = TRUE, we can append only a *-key record into the working block
-				(decompressing current *-key)
-	complete_merge = TRUE, rtsib can be completely merged with working block
-	piece_len = Size of data from old rtsibling to be merged into working block (includes rec_hdr size)
-	*/
+	 * newblk1_last_key = new working blocks final appended key
+	 * newblk1_mid_cmpc = new working blocks firstly appended key's cmpc
+	 * newblk1_last_keysz = new working blocks lastly appended key's size
+	 * star_only_merge = TRUE, we can append only a *-key record into the working block
+	 * (decompressing current *-key)
+	 * lcl_pending_levels = (1 + levelp - level) if rtsib can be completely merged with working block,
+	 * since levelp is the highest level which will be affected by the merge in the target block.
+	 * piece_len = Size of data from old rtsibling to be merged into working block (includes rec_hdr size)
+	 */
 	BLK_ADDR(newblk1_last_key, MAX_KEY_SZ + 1, unsigned char);
 	rec_base = old_blk2_base + SIZEOF(blk_hdr);
 	READ_RECORD(status, &rec_size, &newblk1_last_cmpc, &newblk1_last_keylen, newblk1_last_key,
@@ -311,7 +313,7 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 		if (old_blk1_sz + oldblk1_last_keylen + bstar_rec_sz > i_max_fill ) /* cannot fit even one record */
 			return cdb_sc_oprnotneeded;
 		star_only_merge = TRUE;
-		complete_merge = TRUE;
+		lcl_pending_levels = 1 + levelp - level;
 		rec_base = old_blk2_base + SIZEOF(blk_hdr) + bstar_rec_sz;
 	} else if (cdb_sc_normal != status)
 	{
@@ -341,24 +343,24 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 	new_blk2_first_rec_base = new_blk1_top = rec_base;
 	if (!star_only_merge)
 	{
+		assert(0 <= newblk1_mid_cmpc);
 		BLK_ADDR(new_rec_hdr1, SIZEOF(rec_hdr), rec_hdr);
 		new_rec_hdr1->rsiz = piece_len;
 		SET_CMPC(new_rec_hdr1, newblk1_mid_cmpc);
 	}
 	/* else only new_blk1_last_key will be appeneded in working block */
 
-
 	/* find a piece of the right sibling to be copied into the working block.
 	Note: rec_base points to 2nd record of old rtsib */
 	if (0 == level) /* if data block */
 	{
-		complete_merge = TRUE;
+		lcl_pending_levels = 1 + levelp - level;
 		while (rec_base < old_blk2_base + old_blk2_sz)
 		{
 			GET_RSIZ(rec_size, rec_base);
 			if (old_blk1_sz + piece_len + rec_size > d_max_fill )
 			{
-				complete_merge = FALSE;
+				lcl_pending_levels = 0;
 				break;
 			}
 			READ_RECORD(status, &rec_size, &newblk1_last_cmpc, &newblk1_last_keylen, newblk1_last_key,
@@ -379,7 +381,7 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 		if (!star_only_merge)
 		{
 			/* we know we can fit more record in working block and rtsibling has more records */
-			complete_merge = TRUE;
+			lcl_pending_levels = 1 + levelp - level;
 			while (rec_base < old_blk2_base + old_blk2_sz)
 			{
 				GET_RSIZ(rec_size, rec_base);
@@ -402,7 +404,7 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 				piece_len += rec_size;
 				if (old_blk1_sz + oldblk1_last_keylen + piece_len + bstar_rec_sz > i_max_fill )
 				{
-					complete_merge = FALSE;
+					lcl_pending_levels = 0;
 					break;
 				}
 			}/* end of "while" loop */
@@ -410,7 +412,7 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 		} /* end else  *-only merge */
 	} /* end else index block */
 
-	if (!complete_merge)
+	if (!lcl_pending_levels)
 	{
 		/*
 		Adjust new right sibling's buffer
@@ -439,22 +441,23 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 			new_rec_hdr2->rsiz = rec_size + tkeycmpc;
 			SET_CMPC(new_rec_hdr2, 0);
 		}
+		level2 = -1;
 	}
 
 
 	/*
-	if complete_merge and level+1 <= level2 < levelp,
+	if lcl_pending_levels and level+1 <= level2 < levelp,
 		if blk2ptr->h[level2].blk_num is *-record block then
 			delete it
 		else
 			prepare to update  blk2ptr->h[level2].blk_num (for first level2>level+1)
 			that is, we will delete 1st record pointing to rtsib which is merged with working.
 	*/
-	else /* complete merge */
+	else /* lcl_pending_levels (complete merge of the target) */
 	{
 		for (level2 = level + 1; level2 < levelp; level2++)
 		{
-			if (SIZEOF(blk_hdr) + bstar_rec_sz == ((blk_hdr_ptr_t)blk2ptr->h[level2].buffaddr)->bsiz)
+			if (SIZEOF(blk_hdr) + old_levelp_bstar_rec_sz == ((blk_hdr_ptr_t)blk2ptr->h[level2].buffaddr)->bsiz)
 			{
 				kill_set_ptr->blk[kill_set_ptr->used].flag = 0;
 				kill_set_ptr->blk[kill_set_ptr->used].level = 0;
@@ -466,6 +469,11 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 				new_blk2_ances_first_keysz = new rtsib's ancestor's 1st key size
 				blk2_ances_hdr = new rtsib's ancestor's 1st record's header
 				*/
+				if ((((blk_hdr_ptr_t)blk1ptr->h[level2].buffaddr)->bver
+						!= ((blk_hdr_ptr_t)blk2ptr->h[level2].buffaddr)->bver)
+						|| (((blk_hdr_ptr_t)blk1ptr->h[levelp].buffaddr)->bver
+							!= ((blk_hdr_ptr_t)blk2ptr->h[level2].buffaddr)->bver))
+					return cdb_sc_oprnotneeded;	/* Block version not all the same, skip the coalesce */
 				delete_all_blk2_ances = FALSE;
 				BLK_ADDR(new_blk2_ances_first_key, MAX_KEY_SZ + 1, unsigned char);
 				rec_base =  blk2ptr->h[level2].buffaddr + SIZEOF(blk_hdr);
@@ -487,7 +495,7 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 				rec_base += rec_size;
 				READ_RECORD(status, &rec_size, &tkeycmpc, &tkeylen, new_blk2_ances_first_key,
 						level2, &blk2ptr->h[level2], rec_base);
-				blk2_ances_remain = rec_base + rec_size - blkid_sz;
+				blk2_ances_remain = rec_base + rec_size - old_levelp_blkid_sz;
 				if (cdb_sc_starrecord == status)
 					blk2_ances_star_only = TRUE;
 				else if (cdb_sc_normal != status)
@@ -499,20 +507,20 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 				{
 					new_blk2_ances_first_keysz = tkeylen + tkeycmpc;
 					BLK_ADDR(blk2_ances_hdr, SIZEOF(rec_hdr), rec_hdr); /* new 1st record's header */
-					blk2_ances_hdr->rsiz = new_blk2_ances_first_keysz + bstar_rec_sz;
+					blk2_ances_hdr->rsiz = new_blk2_ances_first_keysz + old_levelp_bstar_rec_sz;
 					SET_CMPC(blk2_ances_hdr, 0);
 				}
 				break;
 			}
 		} /* end for level2 */
-	} /* end if/else complete_merge */
+	} /* end if/else lcl_pending_levels */
 
 	/*
 	new_levelp_cur_hdr = new ancestor level curr_key header
 	new_levelp_cur_keylen =  new ancestor level curr_key length
 	new_levelp_cur_cmpc = new ancestor level curr_key compression count
 	*/
-	if (!complete_merge || !delete_all_blk2_ances) /* old_levelp_cur_key will be
+	if (!lcl_pending_levels || !delete_all_blk2_ances) /* old_levelp_cur_key will be
 							replaced by newblk1_last_key */
 	{
 		if (old_levelp_cur_prev_keysz == 0)	/* If a previous record doesn't exist */
@@ -529,8 +537,13 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 		in the upper index block
 		*/
 		BLK_ADDR(new_levelp_cur_hdr, SIZEOF(rec_hdr), rec_hdr);
-		new_levelp_cur_hdr->rsiz = bstar_rec_sz + new_levelp_cur_keylen;
+		new_levelp_cur_hdr->rsiz = old_levelp_bstar_rec_sz + new_levelp_cur_keylen;
 		SET_CMPC(new_levelp_cur_hdr, new_levelp_cur_cmpc);
+	} else
+	{
+		new_levelp_cur_hdr = NULL;
+		new_levelp_cur_keylen = 0;
+		new_levelp_cur_cmpc = -1;
 	}
 	/* else  old_levelp_cur_key will be deleted */
 
@@ -541,7 +554,8 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 	*/
 	if (!levelp_next_is_star) /* if next record is not a *-record after levelp currkey */
 	{
-		if (!complete_merge || !delete_all_blk2_ances) /* old_levelp_cur_key will be
+		assert(0 < old_levelp_cur_next_keysz);
+		if (!lcl_pending_levels || !delete_all_blk2_ances) /* old_levelp_cur_key will be
 			replaced by newblk1_last_key and followed by old_levelp_cur_next_key */
 		{
 			GET_CMPC(new_levelp_cur_next_cmpc, newblk1_last_key, old_levelp_cur_next_key);
@@ -567,21 +581,27 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 		in the upper index block
 		*/
 		BLK_ADDR(new_levelp_cur_next_hdr, SIZEOF(rec_hdr), rec_hdr);
-		new_levelp_cur_next_hdr->rsiz = bstar_rec_sz + new_levelp_cur_next_keylen;
+		new_levelp_cur_next_hdr->rsiz = old_levelp_bstar_rec_sz + new_levelp_cur_next_keylen;
 		SET_CMPC(new_levelp_cur_next_hdr, new_levelp_cur_next_cmpc);
 	} else
 	{
-		if (!complete_merge || !delete_all_blk2_ances)
+		if (!lcl_pending_levels || !delete_all_blk2_ances)
 		{
 			if (((blk_hdr_ptr_t)old_levelp_blk_base)->bsiz
 				- old_levelp_cur_keylen + new_levelp_cur_keylen > i_max_fill)
 				return cdb_sc_oprnotneeded;
 		}
+		new_levelp_cur_next_cmpc = -1;
+		new_levelp_cur_next_hdr = NULL;
+		new_levelp_cur_next_keylen = 0;
 	}
 
 	BLK_ADDR(star_rec_hdr, SIZEOF(rec_hdr), rec_hdr);
 	star_rec_hdr->rsiz = bstar_rec_sz;
 	SET_CMPC(star_rec_hdr, 0);
+	BLK_ADDR(old_levelp_star_rec_hdr, SIZEOF(rec_hdr), rec_hdr);
+	old_levelp_star_rec_hdr->rsiz = old_levelp_bstar_rec_sz;
+	SET_CMPC(old_levelp_star_rec_hdr, 0);
 	/* ------------------------
 	 * Working block's t_write
 	 * ------------------------
@@ -589,6 +609,8 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 	BLK_INIT(bs_ptr2, bs_ptr1);
 	if (0 == level)
 	{	/* if a data block */
+		assert(new_rec_hdr1);
+		assert(0 <= newblk1_mid_cmpc);
 		/* adjust old block */
 		BLK_SEG(bs_ptr2, old_blk1_base + SIZEOF(blk_hdr), old_blk1_sz - SIZEOF(blk_hdr) );
 		/* Join data from right sibling */
@@ -597,6 +619,7 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 			      piece_len - SIZEOF(rec_hdr), &blk1ptr->h[level]);
 	} else
 	{	/* if an index block */
+		assert(old_last_rec_hdr1);
 		BLK_ADDR(bn_ptr1, blkid_sz, unsigned char);
 		memcpy(bn_ptr1, old_blk1_base + old_blk1_sz - blkid_sz, blkid_sz);
 		/* Keep whatever was there in working block */
@@ -613,7 +636,9 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 			REORG_BLK_SEG(bs_ptr2, new_blk1_top - blkid_sz, blkid_sz, &blk1ptr->h[level]);
 		} else
 		{
-			if (complete_merge)
+			assert(new_rec_hdr1);
+			assert(0 <= newblk1_mid_cmpc);
+			if (lcl_pending_levels)
 			{	/* First key from rtsib had cmpc=0. After coalesce it will be nonzero.
 				 * Remainings from rtsib will be appened without change.
 				 */
@@ -643,16 +668,20 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 		NONTP_TRACE_HIST_MOD(&blk1ptr->h[level], t_blkmod_mu_clsce);
 		return cdb_sc_blkmod;
 	}
-	t_write(&blk1ptr->h[level], (unsigned char *)bs_ptr1, 0, 0, level, FALSE, TRUE, GDS_WRITE_KILLTN);
+	t_write(&blk1ptr->h[level], bs_ptr1, 0, 0, level, FALSE, TRUE, GDS_WRITE_KILLTN);
 	/* -----------------
 	 * The right sibling
 	 * -----------------
 	 */
-	if (!complete_merge)
+	if (!lcl_pending_levels)
 	{
 		BLK_INIT(bs_ptr2, bs_ptr1);
 		if (!new_rtsib_star_only) /* more than one record in rtsib */
 		{
+			assert(new_rec_hdr2);
+			assert(newblk2_first_key);
+			assert(0 < newblk2_first_keysz);
+			assert(new_blk2_remain);
 			BLK_SEG(bs_ptr2, (sm_uc_ptr_t)new_rec_hdr2, SIZEOF(rec_hdr));
 			BLK_SEG(bs_ptr2, newblk2_first_key, newblk2_first_keysz);
 			BLK_SEG(bs_ptr2, new_blk2_remain, old_blk2_base + old_blk2_sz - new_blk2_remain );
@@ -668,7 +697,7 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 			NONTP_TRACE_HIST_MOD(&blk2ptr->h[level], t_blkmod_mu_clsce);
 			return cdb_sc_blkmod;
 		}
-		t_write(&blk2ptr->h[level], (unsigned char *)bs_ptr1, 0, 0, level, TRUE, TRUE, GDS_WRITE_KILLTN);
+		t_write(&blk2ptr->h[level], bs_ptr1, 0, 0, level, TRUE, TRUE, GDS_WRITE_KILLTN);
 	} else
 	{
 		kill_set_ptr->blk[kill_set_ptr->used].flag = 0;
@@ -681,15 +710,17 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 	 * --------------------------
 	 * bn_ptr2 = child of levelp ancestor block of currkey
 	 */
-	BLK_ADDR(bn_ptr2, blkid_sz, unsigned char);
-	memcpy(bn_ptr2, old_levelp_blk_base + old_levelp_rec_offset + SIZEOF(rec_hdr) + old_levelp_cur_keylen, blkid_sz);
+	BLK_ADDR(bn_ptr2, old_levelp_blkid_sz, unsigned char);
+	memcpy(bn_ptr2, old_levelp_blk_base + old_levelp_rec_offset + SIZEOF(rec_hdr) + old_levelp_cur_keylen, old_levelp_blkid_sz);
 
 	BLK_INIT(bs_ptr2, bs_ptr1);
 	/* data up to cur_rec */
 	BLK_SEG(bs_ptr2, old_levelp_blk_base + SIZEOF(blk_hdr), old_levelp_rec_offset - SIZEOF(blk_hdr) );
 	if (!levelp_next_is_star) /* if next record is not a *-record at levelp currkey */
 	{
-		if (complete_merge && delete_all_blk2_ances)
+		assert(0 <= new_levelp_cur_next_cmpc);
+		assert(new_levelp_cur_next_hdr);
+		if (lcl_pending_levels && delete_all_blk2_ances)
 		{ /* old_levelp_curr_key will be removed and old_levelp_cur_next_key will be inserted there */
 			assert (t_tries < CDB_STAGNATE || 0 != new_levelp_cur_next_keylen);
 			assert (t_tries < CDB_STAGNATE || (old_levelp_rec_offset - SIZEOF(blk_hdr)) || !new_levelp_cur_next_cmpc);
@@ -698,51 +729,57 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 			/* new key value of curr_next_key */
 			BLK_SEG(bs_ptr2, old_levelp_cur_next_key + new_levelp_cur_next_cmpc, new_levelp_cur_next_keylen);
 			/* new child is the working block (= descendent of levelp ancestor of currkey) */
-			BLK_SEG(bs_ptr2, bn_ptr2, blkid_sz);
+			BLK_SEG(bs_ptr2, bn_ptr2, old_levelp_blkid_sz);
 			/* remaining records after levelp cur_next */
-			BLK_SEG(bs_ptr2, old_levelp_blk_base + old_levelp_rec_offset +
-				old_levelp_cur_keylen + bstar_rec_sz + old_levelp_cur_next_keylen + bstar_rec_sz,
-				((blk_hdr_ptr_t)old_levelp_blk_base)->bsiz - old_levelp_rec_offset -
-				(old_levelp_cur_keylen + bstar_rec_sz + old_levelp_cur_next_keylen + bstar_rec_sz));
+			BLK_SEG(bs_ptr2, old_levelp_blk_base + old_levelp_rec_offset + old_levelp_cur_keylen
+						+ old_levelp_bstar_rec_sz + old_levelp_cur_next_keylen + old_levelp_bstar_rec_sz,
+				((blk_hdr_ptr_t)old_levelp_blk_base)->bsiz - old_levelp_rec_offset
+					- (old_levelp_cur_keylen + old_levelp_bstar_rec_sz
+						+ old_levelp_cur_next_keylen + old_levelp_bstar_rec_sz));
 			forward_process = TRUE;
 		} else
 		{ /* old_levelp_curr_key will be replaced by newblk1_last_key and old_levelp_cur_next_key will be inserted there */
-			assert (t_tries < CDB_STAGNATE || 0 != new_levelp_cur_keylen);
-			assert (t_tries < CDB_STAGNATE || 0 != old_levelp_rec_offset - SIZEOF(blk_hdr) || 0 == new_levelp_cur_cmpc);
+			assert(0 <= new_levelp_cur_cmpc);
+			assert((t_tries < CDB_STAGNATE) || (0 < new_levelp_cur_keylen));
+			assert((t_tries < CDB_STAGNATE) || (0 != old_levelp_rec_offset - SIZEOF(blk_hdr))
+							|| (0 == new_levelp_cur_cmpc));
+			assert(new_levelp_cur_hdr);
 			/* new header for new cur_rec of levelp */
 			BLK_SEG(bs_ptr2, (sm_uc_ptr_t)new_levelp_cur_hdr, SIZEOF(rec_hdr) );
 			/* new key value for cur_rec of levelp  */
 			BLK_SEG(bs_ptr2, newblk1_last_key + new_levelp_cur_cmpc, new_levelp_cur_keylen);
 			/* new child is old child */
-			BLK_SEG(bs_ptr2, bn_ptr2, blkid_sz);
+			BLK_SEG(bs_ptr2, bn_ptr2, old_levelp_blkid_sz);
 			/* new header for next record after cur_rec of levelp */
 			BLK_SEG(bs_ptr2, (sm_uc_ptr_t)new_levelp_cur_next_hdr, SIZEOF(rec_hdr) );
 			/* new key value for cur_next of levelp  */
 			BLK_SEG(bs_ptr2, old_levelp_cur_next_key + new_levelp_cur_next_cmpc, new_levelp_cur_next_keylen);
 			/* copy old contents after old_levelp_cur_key */
 			BLK_SEG(bs_ptr2, old_levelp_blk_base + old_levelp_rec_offset +
-				bstar_rec_sz + old_levelp_cur_keylen + SIZEOF(rec_hdr) + old_levelp_cur_next_keylen,
+				old_levelp_bstar_rec_sz + old_levelp_cur_keylen + SIZEOF(rec_hdr) + old_levelp_cur_next_keylen,
 				((blk_hdr_ptr_t)old_levelp_blk_base)->bsiz - old_levelp_rec_offset -
-				(bstar_rec_sz + old_levelp_cur_keylen + SIZEOF(rec_hdr) + old_levelp_cur_next_keylen));
+				(old_levelp_bstar_rec_sz + old_levelp_cur_keylen + SIZEOF(rec_hdr) + old_levelp_cur_next_keylen));
 			forward_process = FALSE;
 		}
 	} else /* there is *-rec after old_levelp_cur_key */
 	{
-		if (complete_merge && delete_all_blk2_ances)
+		if (lcl_pending_levels && delete_all_blk2_ances)
 		{	/* delete old old_levelp_cur_key and *-key and write new *-key */
-			BLK_SEG(bs_ptr2, (sm_uc_ptr_t)star_rec_hdr, SIZEOF(rec_hdr));
-			BLK_SEG(bs_ptr2, bn_ptr2, blkid_sz);
+			BLK_SEG(bs_ptr2, (sm_uc_ptr_t)old_levelp_star_rec_hdr, SIZEOF(rec_hdr));
+			BLK_SEG(bs_ptr2, bn_ptr2, old_levelp_blkid_sz);
 			forward_process = TRUE;
 		} else
 		{	/* new header for new cur_rec of levelp */
+			assert(0 <= new_levelp_cur_cmpc);
+			assert((t_tries < CDB_STAGNATE) || (0 < new_levelp_cur_keylen));
 			BLK_SEG(bs_ptr2, (sm_uc_ptr_t)new_levelp_cur_hdr, SIZEOF(rec_hdr) );
 			/* new key value for cur_rec of levelp  */
 			BLK_SEG(bs_ptr2, newblk1_last_key + new_levelp_cur_cmpc, new_levelp_cur_keylen);
 			/* new child is old child */
-			BLK_SEG(bs_ptr2, bn_ptr2, blkid_sz);
+			BLK_SEG(bs_ptr2, bn_ptr2, old_levelp_blkid_sz);
 			/* old *-rec */
-			BLK_SEG(bs_ptr2, old_levelp_blk_base + ((blk_hdr_ptr_t)old_levelp_blk_base)->bsiz - bstar_rec_sz,
-				bstar_rec_sz);
+			BLK_SEG(bs_ptr2, old_levelp_blk_base + ((blk_hdr_ptr_t)old_levelp_blk_base)->bsiz - old_levelp_bstar_rec_sz,
+				old_levelp_bstar_rec_sz);
 			forward_process = FALSE;
 		}
 	}
@@ -752,7 +789,7 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 		NONTP_TRACE_HIST_MOD(&blk1ptr->h[levelp], t_blkmod_mu_clsce);
 		return cdb_sc_blkmod;
 	}
-	t_write(&blk1ptr->h[levelp], (unsigned char *)bs_ptr1, 0, 0, levelp, FALSE, forward_process, GDS_WRITE_KILLTN);
+	t_write(&blk1ptr->h[levelp], bs_ptr1, 0, 0, levelp, FALSE, forward_process, GDS_WRITE_KILLTN);
 	/* ---------------------------------------------------------------------------
 	 * if delete_all_blk2_ances and level+1 <= level2 < levelp,
 	 * 	if blk2ptr->h[level2].blk_num are *-record blocks
@@ -763,12 +800,17 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 	 */
 	if (!delete_all_blk2_ances)
 	{
+		assert(blk2_ances_remain);
+		assert(0 <= level2);
 		BLK_INIT(bs_ptr2, bs_ptr1);
 		if (blk2_ances_star_only)
 		{
-			BLK_SEG(bs_ptr2, (sm_uc_ptr_t)star_rec_hdr, SIZEOF(rec_hdr));
+			BLK_SEG(bs_ptr2, (sm_uc_ptr_t)old_levelp_star_rec_hdr, SIZEOF(rec_hdr));
 		} else
 		{
+			assert(blk2_ances_hdr);
+			assert(new_blk2_ances_first_key);
+			assert(new_blk2_ances_first_keysz);
 			BLK_SEG(bs_ptr2,  (sm_uc_ptr_t)blk2_ances_hdr, SIZEOF(rec_hdr));
 			BLK_SEG(bs_ptr2, new_blk2_ances_first_key,  new_blk2_ances_first_keysz);
 			assert (t_tries < CDB_STAGNATE || 0 != new_blk2_ances_first_keysz);
@@ -781,7 +823,7 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 			NONTP_TRACE_HIST_MOD(&blk2ptr->h[level2], t_blkmod_mu_clsce);
 			return cdb_sc_blkmod;
 		}
-		t_write(&blk2ptr->h[level2], (unsigned char *)bs_ptr1, 0, 0, level2, TRUE, TRUE, GDS_WRITE_KILLTN);
+		t_write(&blk2ptr->h[level2], bs_ptr1, 0, 0, level2, TRUE, TRUE, GDS_WRITE_KILLTN);
 	}
 	/* else do not need to change blk2ptr->h[level2].blk_num.
 	 * Because, for level+1 == levelp this is the same as levelp ancestor block (blk1ptr->h[levelp].blk_num).
@@ -791,12 +833,29 @@ enum cdb_sc mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_s
 	 * 	and still blk2ptr->h[level+1] correctly points to the
 	 * 	right most value of collation sequence at correct block.)
 	 */
-	*remove_rtsib = complete_merge;
+	/* If lcl_pending_levels is greater than the current, raise the pending_levels so that the caller continues the
+	 * coalesce operation.
+	 */
+	if (*pending_levels < lcl_pending_levels)
+		*pending_levels = lcl_pending_levels;
 	/* prepare next gv_currkey for reorg */
-	if (0 == level && !complete_merge)
+	if ((min_level == level) && !lcl_pending_levels)
 	{
-		memcpy(&gv_currkey_next_reorg->base[0], newblk2_first_key, newblk2_first_keysz);
-		gv_currkey_next_reorg->end = newblk2_first_keysz - 1;
+		if (new_rtsib_star_only)
+		{	/* Need to maintain variant that any successful coalesce sets up gv_currkey_next_reorg. Can't do that
+			 * if we've only got a star key, so instead force a go-around after t_end so we get into gvcst_rtsib and
+			 * populate the buffer explicitly.
+			 */
+			assert((t_tries < CDB_STAGNATE) || level);
+			if (!(*pending_levels))
+				*pending_levels = 1;
+		} else
+		{
+			assert(newblk2_first_key);
+			assert((newblk2_first_keysz) && (newblk2_first_keysz <= MAX_KEY_SZ));
+			memcpy(&gv_currkey_next_reorg->base[0], newblk2_first_key, newblk2_first_keysz);
+			gv_currkey_next_reorg->end = newblk2_first_keysz - 1;
+		}
 	}
 	return cdb_sc_normal;
 } /* end of the program */
