@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -146,7 +146,7 @@ GBLREF gtm_uint64_t		mu_int_cum[CUM_TYPE_MAX][MAX_BT_DEPTH + 1];
 GBLREF uint4			mu_int_offset[];
 GBLREF uint4			mu_int_errknt;
 GBLREF block_id			mu_int_path[];
-GBLREF int4			mu_int_blks_to_upgrd;
+GBLREF block_id			mu_int_blks_to_upgrd;
 GBLREF global_list		*trees;
 GBLREF global_list		*trees_tail;
 GBLREF gv_key			*mu_end_key;
@@ -162,6 +162,8 @@ GBLREF boolean_t		nct_err_type;
 GBLREF boolean_t		debug_mupip;
 GBLREF int			rec_len;
 GBLREF jnlpool_addrs_ptr_t	jnlpool;
+GBLREF int4			max_data_blk_size;
+GBLREF int4			max_index_blk_size;
 error_def(ERR_DBBADKYNM);
 error_def(ERR_DBBADNSUB);
 error_def(ERR_DBBADPNTR);
@@ -198,6 +200,7 @@ error_def(ERR_DBSPANCHUNKORD);
 error_def(ERR_DBNULCOL);
 error_def(ERR_NULSUBSC);
 error_def(ERR_DBNONUMSUBS);
+error_def(ERR_BSIZTOOLARGE);
 
 LITDEF boolean_t mu_int_possub[16][16] = {
 	{0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
@@ -250,7 +253,7 @@ LITDEF boolean_t mu_int_exponent[256] = {
 
 boolean_t mu_int_blk(
 		block_id blk,
-		char level,
+		unsigned char level,
 		boolean_t is_root,
 		unsigned char *bot_key,
 		int bot_len,
@@ -282,7 +285,7 @@ boolean_t mu_int_blk(
 	boolean_t	first_key, is_top, pstar, valid_gbl, hasht_global, instance_frozen;
 	boolean_t	muint_range_done = FALSE, nct_checked = FALSE, long_blk_id;
 	int4		blk_id_sz;
-	int		blk_size, buff_length, b_index, cmcc, comp_length, key_size, len, name_len,
+	int		blk_size, buff_length, b_index, cmcc, comp_length, key_size, len, name_len = -1,
 			num_len, rec_size, s_index, start_index, sub_start_index, hdr_len, idx;
 	int		tmp_cmpc, tmp_numsubs, max_allowed_key_size;
 	block_id	child, root_pointer, blk_lmap;
@@ -324,9 +327,14 @@ boolean_t mu_int_blk(
 	blk_id_sz = SIZEOF_BLK_ID(long_blk_id);
 	blk_size = (int)((blk_hdr_ptr_t)blk_base)->bsiz;
 	blk_levl = ((blk_hdr_ptr_t)blk_base)->levl;
+#ifdef DEBUG_BLKS_TO_UPGRD
+	if (debug_mupip)
+		util_out_print("MUPIP INFO: 0x!@XQ:!UL:!UL", TRUE, &blk, ((blk_hdr_ptr_t)blk_base)->bver, blk_levl);
+#endif
 	if (!muint_fast)
 	{	/* conditions of the if below may need adjustment as versions go forward */
-		if ((GDSVCURR != mu_int_data.creation_db_ver) && (((blk_hdr_ptr_t)blk_base)->bver != mu_int_data.desired_db_format))
+		if ((GDSV7m == mu_int_data.certified_for_upgrade_to) && (BLK_ID_32_VER >= ondsk_blkver)
+				&& (LCL_MAP_LEVL != blk_levl))
 			mu_int_blks_to_upgrd++;
 		if (tn_reset_this_reg)
 		{
@@ -407,9 +415,20 @@ boolean_t mu_int_blk(
 	buff_length = 0;
 	comp_length = bot_len;
 	is_top = FALSE;
-	memcpy(buff, bot_key, bot_len);
+	memcpy((void *)buff, bot_key, bot_len);
 	mu_sub_list[0].index = NO_SUBSCRIPTS;
 	rec_num = 0;
+	if (level)
+	{
+		if ((max_index_blk_size > 0) && (blk_size > max_index_blk_size))
+			MU_INT_RETRY_INCR_PLEN(ERR_BSIZTOOLARGE, TRUE, FALSE, bot_key, bot_len, top_key,
+					top_len, (unsigned int)blk_levl);
+	} else
+	{
+		if ((max_data_blk_size > 0) && (blk_size > max_data_blk_size))
+			MU_INT_RETRY_INCR_PLEN(ERR_BSIZTOOLARGE, TRUE, FALSE, bot_key, bot_len, top_key,
+					top_len, (unsigned int)blk_levl);
+	}
 	for (rec_base = blk_base + SIZEOF(blk_hdr);  (rec_base < blk_top) && (FALSE == muint_range_done);
 		rec_base = rec_top, comp_length = buff_length)
 	{
@@ -449,6 +468,7 @@ boolean_t mu_int_blk(
 			ptr = rec_base + SIZEOF(rec_hdr);
 		} else
 		{
+			assert(first_key || (0 <= name_len));
 			if (first_key)
 			{
 				if (rec_cmpc)
@@ -542,7 +562,7 @@ boolean_t mu_int_blk(
 						(unsigned int)blk_levl);
 				}
 			}
-			memcpy(old_buff, buff, comp_length);
+			memcpy((void *)old_buff, buff, comp_length);
 			memcpy(buff + rec_cmpc, key_base, key_size);
 			buff_length = rec_cmpc + key_size;
 			rec_len = buff_length;
@@ -766,8 +786,17 @@ boolean_t mu_int_blk(
 				}
 				span_key = buff + buff_length - SPAN_SUBS_LENGTH - 1;
 				if (is_trigger)
-					max_allowed_key_size = MAX_KEY_SZ - 4;
-				else
+				{
+					long_blk_id = (BLK_ID_32_VER < mu_int_data.desired_db_format);
+					if ((MAX_KEY_SZ + SIZEOF(blk_hdr) + 2 * SIZEOF(rec_hdr) + 2 * SIZEOF_BLK_ID(long_blk_id))
+								< mu_int_data.blk_size)
+						max_allowed_key_size = MAX_KEY_SZ - 4;
+					else
+					{	/* The maximum key size is a function of the block size */
+						max_allowed_key_size = mu_int_data.blk_size - SIZEOF(blk_hdr) - SIZEOF(rec_hdr)
+							- SIZEOF_BLK_ID(long_blk_id) - bstar_rec_size(long_blk_id);
+					}
+				} else
 					max_allowed_key_size = mu_int_data.max_key_size;
 				if ((SPAN_SUBS_LENGTH < key_size + rec_cmpc) && (KEY_DELIMITER == *span_key++)
 						&& (SPAN_START_BYTE == *span_key))
@@ -984,7 +1013,7 @@ boolean_t mu_int_blk(
 				}
 				*c1 = 0;
 				assert(SIZEOF(muint_temp_buff) == SIZEOF(temp_buff));
-				memcpy(muint_temp_buff, temp_buff, SIZEOF(temp_buff));
+				memcpy((void *)muint_temp_buff, temp_buff, SIZEOF(temp_buff));
 				if (mu_key)
 				{
 					if (mu_end_key)	/* range */
@@ -1041,6 +1070,7 @@ boolean_t mu_int_blk(
 				}
 			}
 		}
+
 	}
 	if (top_len)
 	{
