@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2023 Fidelity National Information	*
+ * Copyright (c) 2001-2025 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -73,7 +73,7 @@ void mu_int_maps(void)
 {
 	unsigned char	*local;
 	char		time_str[CTIME_BEFORE_NL + 2]; /* for GET_CUR_TIME macro */
-	uchar_ptr_t	blk_base, buff_blk_base, free_blk_base;
+	uchar_ptr_t	blk_base, buff_blk_base = NULL, free_blk_base;
 	boolean_t	wait_on_kip, agree, disk_full, local_full, master_full;
 	block_id	maps, mapsize, mcnt, lcnt, bcnt;
 	unsigned int	level;
@@ -94,6 +94,11 @@ void mu_int_maps(void)
 		util_out_print("!/MUPIP INFO: mu_int_maps: !AD : Start kill-in-prog wait.", TRUE,
 			CTIME_BEFORE_NL, time_str);
 	}
+#	ifdef DEBUG
+	if (WBTEST_ENABLED(WBTEST_INTEG_RTS_ERR))
+		RTS_ERROR_CSA_ABT(CSA_ARG(NULL) VARLSTCNT(4) MAKE_MSG_ERROR(ERR_TEXT), 2,
+				RTS_ERROR_TEXT("White Box integ rts_error"));
+#	endif
 	while (((cs_data && cs_data->kill_in_prog) || mu_int_data.kill_in_prog) && (MAX_CRIT_TRY > crit_counter++))
 	{
 		if (cs_addrs)
