@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -223,7 +223,7 @@ void mupip_backup(void)
 	unsigned short		s_len, length;
 	int4			size, crit_counter, save_errno, rv, orig_buff_size;
 	uint4			ustatus, reg_count;
-	trans_num		tn;
+	trans_num		tn = 0;
 	shmpool_buff_hdr_ptr_t	sbufh_p;
 	shmpool_blk_hdr_ptr_t	sblkh_p, next_sblkh_p;
 	backup_reg_list		*rptr, *rrptr, *nocritrptr;
@@ -238,14 +238,14 @@ void mupip_backup(void)
 	char			*jnl_str_ptr, jnl_str[256], entry[256], prev_jnl_fn[JNL_NAME_SIZE];
 	int			index, jnl_fstat, attemptcnt, maxtries;
 	mstr			tempdir_log, tempdir_trans, *file, *rfile, *replinstfile, tempdir_full, filestr;
-	uint4			jnl_status, temp_file_name_len, tempdir_trans_len, trans_log_name_status;
+	uint4			jnl_status, temp_file_name_len, tempdir_trans_len, trans_log_name_status = SS_NORMAL;
 	boolean_t		jnl_options[jnl_end_of_list] = {FALSE, FALSE, FALSE}, save_no_prev_link;
 	jnl_private_control	*jpc;
 	jnl_buffer_ptr_t	jbp;
 	jnl_tm_t		save_gbl_jrec_time;
 	gd_region		*r_save, *reg;
 	int			sync_io_status;
-	boolean_t		sync_io, sync_io_specified, showprogress;
+	boolean_t		sync_io = FALSE, sync_io_specified = FALSE, showprogress;
 	boolean_t		dummy_ftok_counter_halted;
 	void			*repl_inst_available;
 	struct stat		stat_buf;
@@ -263,7 +263,7 @@ void mupip_backup(void)
 	struct shmid_ds		shm_buf;
 	struct semid_ds		semstat;
 	union semun		semarg;
-	int4			shm_id, sem_id;
+	int4			shm_id = INVALID_SHMID, sem_id = INVALID_SEMID;
 	replpool_identifier	replpool_id;
 	DEBUG_ONLY(jnlpool_addrs_ptr_t	jnlpool_save);
 	sm_uc_ptr_t		start_addr;
@@ -292,7 +292,7 @@ void mupip_backup(void)
 		gvinit();
 	/* ============================ STEP 2. Parse and construct grlist ================================== */
 	tn_specified = FALSE;
-	if (incremental = (CLI_PRESENT == cli_present("INCREMENTAL") || CLI_PRESENT == cli_present("BYTESTREAM")))
+	if ((incremental = ((CLI_PRESENT == cli_present("INCREMENTAL")) || (CLI_PRESENT == cli_present("BYTESTREAM")))))
 	{
 		trans_num temp_tn;
 		if (0 == cli_get_hex64("TRANSACTION", &temp_tn))
@@ -1097,8 +1097,8 @@ repl_inst_bkup_done1:
 					error_mupip = TRUE;
 					goto repl_inst_bkup_done2;
 				}
-				assert(!pool_init || (INVALID_SHMID != shm_id) && (INVALID_SEMID != sem_id));
-				assert(pool_init || (INVALID_SHMID == shm_id) && (INVALID_SEMID == sem_id));
+				assert(!pool_init || ((INVALID_SHMID != shm_id) && (INVALID_SEMID != sem_id)));
+				assert(pool_init || ((INVALID_SHMID == shm_id) && (INVALID_SEMID == sem_id)));
 				if (pool_init)
 				{	/* The journal pool exists. Note down the journal seqno from there and copy that onto
 					 * the backed up instance file header. Also, clean up other fields in the backed up
@@ -1401,14 +1401,6 @@ repl_inst_bkup_done2:
 				sbufh_p->dskaddr = 0;
 				sbufh_p->backup_errno = 0;
 				sbufh_p->failed = 0;
-#				ifdef DEBUG
-				/* Once the process register its pid as backup_pid, sleep for the 1 seconds, so that test
-				 * tests hits the scenario where BKUPRUNNING message is printed. Note that sleep of 1 sec
-				 * is fine because it is the box boxes which are failing to hit the concurrency scenario.
-				 */
-				if (gtm_white_box_test_case_enabled && (WBTEST_CONCBKUP_RUNNING == gtm_white_box_test_case_number))
-					LONG_SLEEP(1);
-#				endif
 				/* Make sure that the backup queue does not have any remnants on it. Note that we do not
 				   depend on the queue count here as it is imperative that, in the event that the count
 				   and queue get out of sync, that there ARE NO BLOCKS on this queue when we start or
@@ -1521,7 +1513,11 @@ repl_inst_bkup_done2:
 				result = (incremental ? mubinccpy(rptr) : mubfilcpy(rptr, showprogress, attemptcnt, &stopretries));
 				if (result)
 					break; /* break to dqloop */
-
+				/* In mubfilcpy() we change cs_addrs->nl->nbb to BACKUP_NOT_IN_PROGRESS
+				 * for concurrent online rollback and for certain error conditions. In such a case,
+				 * do not retry for online backup.  */
+				if ((online) && (BACKUP_NOT_IN_PROGRESS == cs_addrs->nl->nbb))
+					stopretries = TRUE;
 				if ((attemptcnt == maxtries) || (TRUE == stopretries))
 				{
 					if (file_backed_up)
