@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -17,7 +17,7 @@
 /* prototypes */
 
 boolean_t mu_reorg(glist *gl_ptr, glist *exclude_glist_ptr, boolean_t *resume,
-			int index_fill_factor, int data_fill_factor, int reorg_op);
+			int index_fill_factor, int data_fill_factor, int reorg_op, int min_level);
 # ifdef UNIX
 void		mu_swap_root(glist *gl_ptr, int *root_swap_statistic_ptr, block_id upg_mv_block);
 block_id	mu_swap_root_blk(glist *gl_ptr, srch_hist *gvt_hist_ptr, srch_hist  *dir_hist_ptr, kill_set *kill_set_list,
@@ -25,13 +25,15 @@ block_id	mu_swap_root_blk(glist *gl_ptr, srch_hist *gvt_hist_ptr, srch_hist  *di
 block_id	swap_root_or_directory_block(int parent_blk_lvl, int level, srch_hist *dir_hist_ptr, block_id child_blk_id,
 		sm_uc_ptr_t child_blk_ptr, kill_set *kill_set_list, trans_num curr_tn, block_id upg_mv_block);
 # endif
-enum cdb_sc	mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_set_ptr, boolean_t *remove_rtsib);
-enum cdb_sc	mu_split(int cur_level, int i_max_fill, int d_max_fill, int *blks_created, int *lvls_increased);
+enum cdb_sc	mu_clsce(int level, int i_max_fill, int d_max_fill, kill_set *kill_set_ptr, int *pending_levels,
+		const int min_level);
+enum cdb_sc	mu_split(int cur_level, int i_max_fill, int d_max_fill, int *blks_created, int *lvls_increased,
+			int *max_rightblk_lvl);
 enum cdb_sc	mu_swap_blk(int level, block_id *pdest_blk_id, kill_set *kill_set_ptr, glist *exclude_glist_ptr,
 			block_id upg_mv_block);
 enum cdb_sc	mu_reduce_level(kill_set *kill_set_ptr);
-enum cdb_sc	gvcst_expand_any_key (srch_blk_status *blk_stat, sm_uc_ptr_t rec_top, sm_uc_ptr_t expanded_key,
-					int *rec_size, int *keylen, int *keycmpc, srch_hist *hist_ptr);
+enum cdb_sc	gvcst_expand_any_key(srch_blk_status *blk_stat, sm_uc_ptr_t rec_top, sm_uc_ptr_t expanded_key,
+					int *rec_size, int *keylen, int *keycmpc, srch_hist *hist_ptr, int *reached_level);
 boolean_t in_exclude_list(unsigned char *curr_key_ptr, int key_len, glist *exclude_glist_ptr);
 void mupip_reorg(void);
 
