@@ -1,6 +1,6 @@
 /***************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -667,6 +667,7 @@ typedef struct reg_ctl_list_struct
 	int			region_index;	/* Per-region index value, aligned to the order the region appears in grlist.
 						 * Used by mupip_freeze()
 						 */
+	boolean_t		ORLBKROLLED_msg_issued; /* Only issue this message once per region */
 } reg_ctl_list;
 
 typedef struct redirect_list_struct
@@ -1089,7 +1090,7 @@ typedef struct {
 				}												\
 			}													\
 		}														\
-		assert((NULL == FORW_MULTI) || (FORW_MULTI->time == REC_TIME) && (FORW_MULTI->token == REC_TOKEN));		\
+		assert((NULL == FORW_MULTI) || ((FORW_MULTI->time == REC_TIME) && (FORW_MULTI->token == REC_TOKEN)));		\
 	} else															\
 		FORW_MULTI = NULL;												\
 }
@@ -1166,7 +1167,7 @@ typedef struct {
 	char			strbuff[256], *ptr;										\
 	char			time_str[CTIME_BEFORE_NL + 2];	/* for GET_CUR_TIME macro */					\
 	time_t			seconds;											\
-	multi_proc_shm_hdr_t	*mp_hdr;	/* Pointer to "multi_proc_shm_hdr_t" structure in shared memory */		\
+	multi_proc_shm_hdr_t	*mp_hdr = NULL;	/* Pointer to "multi_proc_shm_hdr_t" structure in shared memory */		\
 																\
 	if (mur_options.verbose)												\
 	{															\
@@ -1214,7 +1215,10 @@ typedef struct {
 				murgbl.broken_cnt, murgbl.broken_cnt);								\
 		}														\
 		if (multi_proc_in_use)												\
+		{														\
+			assert(mp_hdr);												\
 			rel_latch(&mp_hdr->multi_proc_latch);									\
+		}														\
 	}															\
 }
 
