@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2003-2020 Fidelity National Information	*
+ * Copyright (c) 2003-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -35,7 +35,6 @@
 #include "gtmmsg.h"
 #include "send_msg.h"
 #include "dbfilop.h"
-#include "gds_blk_downgrade.h"
 #include "gdsbml.h"
 #include "bit_clear.h"
 #include "bit_set.h"
@@ -49,6 +48,8 @@
 #include "gtm_pthread_init_key.h"
 #include "interlock.h"
 #include "gtm_multi_proc.h"
+#include "io.h"
+#include "gtmio.h"
 
 GBLREF	volatile int4		db_fsync_in_prog;	/* for DB_FSYNC macro usage */
 GBLREF	boolean_t		blocksig_initialized;
@@ -64,6 +65,7 @@ error_def(ERR_JNLREAD);
 error_def(ERR_JNLREADBOF);
 error_def(ERR_NOPREVLINK);
 error_def(ERR_ORLBKNOSTP);
+error_def(ERR_ORLBKROLLED);
 
 /* Returns 0 (SS_NORMAL) for success; Non-zero for failure */
 /* #GTM_THREAD_SAFE : The below function (mur_apply_pblk) is thread-safe */
@@ -81,9 +83,17 @@ uint4 mur_apply_pblk(reg_ctl_list *rctl)
 	int			save_errno;
 	jnl_record		*jnlrec;
 	unix_db_info		*udi;
+	DCL_THREADGBL_ACCESS;
 
+	SETUP_THREADGBL_ACCESS;
 	reg = rctl->gd;
 	status = gtm_pthread_init_key(reg);
+        if (WBTEST_ENABLED(WBTEST_MU_STOP_THREAD))
+        {
+		DBGFPF((stderr, "region %s thread will sleep indefinitely now\n",reg->rname));
+                while (TRUE)
+                        LONG_SLEEP(60);
+        }
 	if (0 != status)
 		return status;
 	udi = FILE_INFO(rctl->gd);
@@ -376,17 +386,7 @@ uint4 mur_output_pblk(reg_ctl_list *rctl)
 		if (pblkrec.blknum > csa->nl->highest_lbm_blk_changed)
 			csa->nl->highest_lbm_blk_changed = pblkrec.blknum;
 	}
-	if (IS_GDS_BLK_DOWNGRADE_NEEDED(pblkrec.ondsk_blkver))
-	{	/* This block was not in GDSVCURR format before the GT.M update wrote this PBLK record. But since all buffers in
-		 * the cache are stored in GDSVCURR format, the before-image in the PBLK record is in GDSVCURR
-		 * format. In order to really undo the update, downgrade the before-image before playing it back.
-		 * This can thankfully be done inline (i.e. using the same buffer) due to the following reasons.
-		 *	a) The reformat routine allows for the source and target buffers to be the same AND
-		 *	b) The block downgrade routine always needs less space for the target buffer than the source buffer AND
-		 *	c) Recovery does not rely on the blk_contents of a PBLK journal record other than in this routine.
-		 */
-		 gds_blk_downgrade((v15_blk_hdr_ptr_t)pblkcontents, (blk_hdr_ptr_t)pblkcontents);
-	}
+	/* Previously, blocks could be downgraded here as needed */
 	db_ctl = rctl->db_ctl;
 	/* apply PBLKs to database of "rctl".
 	 * This only takes place during rollback/recover, and is thus the first restoration being done to the database;
@@ -512,5 +512,16 @@ uint4 mur_output_pblk(reg_ctl_list *rctl)
 		}
 		PTHREAD_MUTEX_UNLOCK_IF_NEEDED(was_holder);
 	}
+	/* If this is an online rollback and we have applied at least one pblk and we have not already issued the message
+	 * let them know the region has been taken back in time from the application's point of view.
+	 */
+	if (jgbl.onlnrlbk && murgbl.incr_onln_rlbk_cycle && !(rctl->ORLBKROLLED_msg_issued))
+	{
+		send_msg_csa(CSA_ARG(NULL) VARLSTCNT(8) ERR_ORLBKROLLED, 6,
+			LEN_AND_STR(jnlpool->repl_inst_filehdr->inst_info.this_instname),
+			LEN_AND_STR(rctl->gd->rname),
+			LEN_AND_STR(udi->fn));
+		rctl->ORLBKROLLED_msg_issued = TRUE;
+	}
 	return (dbfilop(db_ctl));
 }
