@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2003-2024 Fidelity National Information	*
+ * Copyright (c) 2003-2025 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -63,6 +63,8 @@
 #endif
 #include "interlock.h"
 #include "do_semop.h"
+#include "inline_atomic_pid.h" /* for DEFINE_ATOMIC_OP(gtm_atomic_uint, ATOMIC_LOAD, memory_order_acquire) */
+#include "inline_not_frozen.h" /* for not_frozen_chilled */
 
 #define WARN_STATUS(jctl)											\
 if (SS_NORMAL != jctl->status)											\
@@ -824,7 +826,7 @@ boolean_t mur_close_files(void)
 				 * timeout with a SEQNUMSEARCHTIMEOUT error (if no GT.M processes have any flush timers active and
 				 * if online rollback does not do the flush either) so it is actually necessary.
 				 */
-				assert(!FROZEN_CHILLED(cs_addrs));
+				assert(not_frozen_chilled(cs_addrs));
 				wcs_flu(WCSFLU_FLUSH_HDR | WCSFLU_WRITE_EPOCH | WCSFLU_SYNC_EPOCH);
 			}
 			/* Note: udi/csa is used a little later after the "gds_rundown" call to determine if "db_ipcs_reset"
@@ -840,7 +842,7 @@ boolean_t mur_close_files(void)
 		/* If this was a RECOVER/ROLLBACK and rctl->standalone is FALSE, then gvcst_init/mu_rndwn_file did not happen in
 		 * successfully for this region. Increment wrn_count in this case
 		 */
-		assert(!mur_options.update || rctl->standalone || !murgbl.clean_exit);
+		assert(!mur_options.update || rctl->standalone || !murgbl.clean_exit || (!rctl->db_present && IS_AUTODB_REG(reg)));
 		if (rctl->standalone && (EXIT_NRM == rundown_status))
 			/* Avoid db_ipcs_reset if "gds_rundown" did not remove shared memory */
 			if ((NULL != udi) && udi->shm_deleted && !db_ipcs_reset(reg))
