@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -58,6 +58,7 @@
 #include "gds_rundown.h"
 #include "wcs_clean_dbsync.h"
 #include "gtmcrypt.h"
+#include "hugetlbfs_overrides.h"
 #ifdef DEBUG
 #include "is_proc_alive.h"
 #endif
@@ -155,7 +156,7 @@ uint4	mur_forward(jnl_tm_t min_broken_time, seq_num min_broken_seqno, seq_num lo
 	sts = gtm_multi_proc((gtm_multi_proc_fnptr_t)&mur_forward_multi_proc, max_procs, max_procs,
 				murgbl.ret_array, (void *)mur_ctl, SIZEOF(reg_ctl_list),
 				shm_size, (gtm_multi_proc_fnptr_t)&mur_forward_multi_proc_init,
-				(gtm_multi_proc_fnptr_t)&mur_forward_multi_proc_finish);
+				(gtm_multi_proc_fnptr_t)&mur_forward_multi_proc_finish, GTM_MULTI_PROC_RECOVER);
 	return (uint4)sts;
 }
 
@@ -243,6 +244,10 @@ int	mur_forward_multi_proc(reg_ctl_list *rctl)
 				rctl->csa->now_crit = FALSE;		/* reset since we don't own this region */
 			}
 		}
+	} else
+	{
+		mp_hdr = NULL;
+		shm_rctl_start = NULL;
 	}
 	first_shm_rctl = NULL;
 	/* Phase1 of forward recovery starts */
@@ -775,7 +780,8 @@ finish:
 			}
 			if ((SS_NORMAL == status) && shm_size)
 			{
-				shmid = gtm_shmget(IPC_PRIVATE, shm_size, 0600 | IPC_CREAT, TRUE);
+				shmid = gtm_shmget(IPC_PRIVATE, shm_size, 0600 | IPC_CREAT, TRUE,
+									DATABASE_FILE, (char*)rctl->gd->dyn.addr->fname);
 				if (-1 == shmid)
 				{
 					save_errno = errno;
