@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2015-2021 Fidelity National Information	*
+ * Copyright (c) 2015-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -55,8 +55,8 @@ error_def(ERR_SYSCALL);
 	((ELEM1->time > ELEM2->time)							\
 		|| ((ELEM1->time == ELEM2->time)					\
 			&& ((ELEM1->token_seq.token > ELEM2->token_seq.token)		\
-				|| (ELEM1->token_seq.token == ELEM2->token_seq.token)	\
-					&& (ELEM1->update_num >= ELEM2->update_num))))
+				|| ((ELEM1->token_seq.token == ELEM2->token_seq.token)	\
+					&& (ELEM1->update_num >= ELEM2->update_num)))))
 
 /* Adds an element into heap "heap_array". Updates "heap_size".
  * If element cannot be added right away (due to multi-region TP resolution) it will add element into a hashtable.
@@ -264,7 +264,7 @@ int mur_merge_sort_extfmt(void)
 {
 	FILE			*fp, *fp_out, **fp_array;
 	boolean_t		extr_file_created, single_reg, skip_sort;
-	boolean_t		is_dummy_gbldir, errored_out;
+	boolean_t		is_dummy_gbldir, errored_out = FALSE;
 	char			*buff, extr_fn[MAX_FN_LEN + 1], *fn, *fn_out;
 	char			rename_fn[MAX_FN_LEN + 1];
 	int			rename_fn_len, fn_len;
