@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2016 Fidelity National Information	*
+ * Copyright (c) 2001-2020 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -16,11 +16,15 @@ typedef	struct inc_list
 	struct inc_list		*next;
 } inc_list_struct;
 
+//If i_hdr is changed then update INC_HEADER_LABEL_DFLT and the version check at mupip_restore.c:316
+
 #define INC_HDR_LABEL_SZ		26
 #define INC_HDR_DATE_SZ			14
 #define INC_HEADER_LABEL_V5_NOENCR	"GDSV5   INCREMENTAL BACKUP"
 #define INC_HEADER_LABEL_V6_ENCR	"GDSV6   INCREMENTAL BACKUP"
 #define INC_HEADER_LABEL_V7		"GDSV7   INCREMENTAL BACKUP"
+#define INC_HEADER_LABEL_V8		"GDSV8   INCREMENTAL BACKUP"
+#define INC_HEADER_LABEL_DFLT		INC_HEADER_LABEL_V8
 
 typedef struct i_hdr
 {
@@ -29,11 +33,12 @@ typedef struct i_hdr
 	char		reg[MAX_RN_LEN];
 	trans_num	start_tn;
 	trans_num	end_tn;
-	uint4		db_total_blks;
+	block_id	db_total_blks;
 	uint4		blk_size;
-	int4		blks_to_upgrd;
+	int4		filler;	/* make 8-byte alignment explicit */
+	block_id	blks_to_upgrd;
 	uint4		is_encrypted;
-	char            encryption_hash[GTMCRYPT_RESERVED_HASH_LEN];
+	char		encryption_hash[GTMCRYPT_RESERVED_HASH_LEN];
 	char		encryption_hash2[GTMCRYPT_RESERVED_HASH_LEN];
 	boolean_t	non_null_iv;
 	block_id	encryption_hash_cutoff;
