@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2013 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -12,10 +13,6 @@
 #ifndef MUTEX_DEADLOCK_CHECK_INCLUDED
 #define MUTEX_DEADLOCK_CHECK_INCLUDED
 
-#ifdef VMS
-void mutex_deadlock_check(mutex_struct_ptr_t addr);
-#else
-void mutex_deadlock_check(mutex_struct_ptr_t addr, sgmnt_addrs *csa);
-#endif
+void mutex_deadlock_check(CRIT_PTR_T addr, sgmnt_addrs *csa);
 
 #endif
