@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2016 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -25,6 +25,7 @@
 #include "format_targ_key.h"
 
 GBLREF	gv_namehead	*gv_target;
+GBLREF	gd_region	*gv_cur_region;
 
 static readonly unsigned char pos_code[100] =
 {
@@ -63,7 +64,7 @@ unsigned char *mval2subsc(mval *in_val, gv_key *out_key, boolean_t std_null_coll
 	int4		mt, mw, mx;
 	uint4		mvt;	/* Local copy of mvtype, bit ands use a int4, so do conversion once */
 	unsigned int	digs, exp_val;
-	int		tmp_len, avail_bytes;
+	int		avail_bytes, length_exceed, max_len, tmp_len;
 	DCL_THREADGBL_ACCESS;
 
 	SETUP_THREADGBL_ACCESS;
@@ -122,14 +123,17 @@ unsigned char *mval2subsc(mval *in_val, gv_key *out_key, boolean_t std_null_coll
 		 * 	store the STR_SUB_ESCAPE byte. Decrement the available space until it becomes zero
 		 *	at which point issue a GVSUBOFLOW error as well.
 		 */
-		avail_bytes = out_key->top - (out_key->end + tmp_len + 3);
+		length_exceed = out_key->end + tmp_len + 3;
+		max_len = out_key->top;
+		avail_bytes = max_len - length_exceed;
 		if (0 > avail_bytes)
-			ISSUE_GVSUBOFLOW_ERROR(out_key, KEY_COMPLETE_FALSE);
+			ISSUE_GVSUBOFLOW_ERROR(out_key, KEY_COMPLETE_FALSE, length_exceed, max_len, gv_cur_region);
 		if (0 < tmp_len)
 		{
 			*out_ptr++ = STR_SUB_PREFIX;
 			do
 			{
+				length_exceed++;
 				ch = *in_ptr++;
 				if (ch <= 1)
 				{
@@ -139,7 +143,8 @@ unsigned char *mval2subsc(mval *in_val, gv_key *out_key, boolean_t std_null_coll
 						/* Ensure input key to format_targ_key is double null terminated */
 						assert(STR_SUB_PREFIX == out_key->base[out_key->end]);
 						out_key->base[out_key->end] = KEY_DELIMITER;
-						ISSUE_GVSUBOFLOW_ERROR(out_key, KEY_COMPLETE_FALSE);
+						ISSUE_GVSUBOFLOW_ERROR(out_key, KEY_COMPLETE_FALSE, length_exceed,
+												max_len, gv_cur_region);
 					}
 					ch++;	/* promote character */
 				}
@@ -168,13 +173,13 @@ unsigned char *mval2subsc(mval *in_val, gv_key *out_key, boolean_t std_null_coll
 		}
 		if (10 > mt)
 		{
-			*out_ptr++ = is_negative ? ~(SUBSCRIPT_BIAS - 2) : (SUBSCRIPT_BIAS - 2);
+			*out_ptr++ = is_negative ? (unsigned char)~(SUBSCRIPT_BIAS - 2) : (unsigned char)(SUBSCRIPT_BIAS - 2);
 			*out_ptr++ = cvt_table[mt * 10];
 			goto FINISH_NUMBER;
 		}
 		if (100 > mt)
 		{
-			*out_ptr++ = is_negative ? ~(SUBSCRIPT_BIAS - 1) : (SUBSCRIPT_BIAS - 1);
+			*out_ptr++ = is_negative ? (unsigned char)~(SUBSCRIPT_BIAS - 1) : (unsigned char)(SUBSCRIPT_BIAS - 1);
 			*out_ptr++ = cvt_table[mt];
 			goto FINISH_NUMBER;
 		}
@@ -300,7 +305,8 @@ ALLDONE:
 	 * MAX_GVKEY_PADDING_LEN bytes (allocated additionally as part of the DBKEYSIZE macro) left at the end.
 	 * If not, we have overflown the original max-key-size length. Issue error.
 	 */
-	if ((MAX_GVKEY_PADDING_LEN + 1) > (int)(out_key->top - out_key->end))
-		ISSUE_GVSUBOFLOW_ERROR(out_key, KEY_COMPLETE_FALSE);
+	length_exceed = out_key->end + MAX_GVKEY_PADDING_LEN + 1;
+	if (length_exceed > (max_len = out_key->top))
+		ISSUE_GVSUBOFLOW_ERROR(out_key, KEY_COMPLETE_FALSE, length_exceed, MIN((MAX_KEY_SZ - 4), max_len), gv_cur_region);
 	return out_ptr;
 }
