@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2017 Fidelity National Information	*
+ * Copyright (c) 2001-2022 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -114,7 +114,7 @@ void op_fnname(UNIX_ONLY_COMMA(int sub_count) mval *finaldst, ...)
 	if (depth_count < 0)
 	{
 		va_end(var);
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_FNNAMENEG);
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_FNNAMENEG);
 	}
 	/* Note about garbage collection : *dst and all possible *arg's in this function are anchored in the stringpool chains
 	 * and preserved during garbage collection (run time argument mvals provided by compiler). So, if we maintain dst->str.len
@@ -136,7 +136,7 @@ void op_fnname(UNIX_ONLY_COMMA(int sub_count) mval *finaldst, ...)
 		if (!gv_currkey || gv_currkey->prev == 0)
 		{
 			va_end(var);
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_GVNAKED);
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_GVNAKED);
 		}
 		/* Reserve enough space for naked reference. Include space for ^() and a maximum of sub_count ',' separators for
 		 * subscripts specified as arguments to $NAME() in addition to those in the naked reference
@@ -165,6 +165,7 @@ void op_fnname(UNIX_ONLY_COMMA(int sub_count) mval *finaldst, ...)
 					sptr = gvsub2str(key_ptr, &opstr, TRUE); /* gvsub2str assumes enough buffer available */
 					while (*key_ptr++)
 						;
+					assert(0 <= depth_count);
 					if (depth_count != MAXPOSINT4) /* although this may not make a difference in reality, */
 						depth_count--;	       /* do not disturb depth_count (used later) if default  */
 					*sptr++ = ',';
@@ -248,7 +249,7 @@ void op_fnname(UNIX_ONLY_COMMA(int sub_count) mval *finaldst, ...)
 	}
 	va_end(var);
 	if (MAX_STRLEN < dst->str.len)
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_MAXSTRLEN);
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_MAXSTRLEN);
 	*finaldst = *dst;
 	POP_MV_STENT(); /* don't need no temporary no more */
 	return;
