@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2010 Fidelity Information Services, Inc	*
+ * Copyright (c) 2010-2018 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -14,7 +15,7 @@
 #include "op.h"
 #include "patcode.h"
 #include "mvalconv.h"
-#ifdef	UNICODE_SUPPORTED
+#ifdef	UTF8_SUPPORTED
 #include <wchar.h>
 #include "gtm_icu_api.h"
 #include "gtm_utf8.h"
@@ -33,7 +34,7 @@ void op_fnzwidth(mval* src, mval* dst)
 	MV_FORCE_STR(src);
 
 	srcptr = (unsigned char *)src->str.addr;
-#ifdef	UNICODE_SUPPORTED
+#ifdef	UTF8_SUPPORTED
 	if (!gtm_utf8_mode)
 	{
 #endif
@@ -43,9 +44,9 @@ void op_fnzwidth(mval* src, mval* dst)
 			if ((pattern_typemask[*srcptr] & PATM_C))
 				width -= 1;
 		}
-#ifdef	UNICODE_SUPPORTED
+#ifdef	UTF8_SUPPORTED
 	} else
-		width = gtm_wcswidth(srcptr, src->str.len, TRUE, 0);	/* TRUE => strict checking of BADCHARs */
+		width = gtm_wcswidth(srcptr, src->str.len, !badchar_inhibit, 0);
 #endif
 	MV_FORCE_MVAL(dst, width);
 }
