@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -89,7 +89,7 @@ void op_gvput(mval *var)
 		gv_replication_error = gv_replopen_error;
 		gv_replopen_error = FALSE;
 		save_reg = gv_cur_region;
-		while (gv_cur_region = gv_cur_region->dyn.addr->repl_list) /* set replicated segments */
+		while ((gv_cur_region = gv_cur_region->dyn.addr->repl_list)) /* set replicated segments */
 		{
 			if (gv_cur_region->open && !gv_cur_region->read_only
 				&& (((temp = gv_currkey->end + 1) <= gv_cur_region->max_key_size)
