@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -40,29 +40,17 @@
 #include "op.h"
 #include "mv_stent.h"
 #include "find_mvstent.h"
-#include "gdskill.h"
-#include "gdsbt.h"
-#include "gtm_facility.h"
 #include "gtm_maxstr.h"
-#include "fileinfo.h"
-#include "gdsfhead.h"
-#include "gdscc.h"
-#include "filestruct.h"
-#include "buddy_list.h"		/* needed for tp.h */
 #include "io.h"
-#include "jnl.h"
-#include "tp.h"
-#include "send_msg.h"
-#include "gtmmsg.h"		/* for gtm_putmsg() prototype */
-#include "change_reg.h"
-#include "setterm.h"
-#include "getzposition.h"
+#include "iott_setterm.h"
+#include "tpnotacid_chk_inline.h"
 #include "lockdefs.h"
 #include "is_proc_alive.h"
 #include "mvalconv.h"
 #include "min_max.h"
 
 GBLREF	bool		out_of_time, remlkreq;
+GBLREF	intrpt_state_t	intrpt_ok_state;
 GBLREF	mlk_pvtblk	*mlk_pvt_root;
 GBLREF	mlk_stats_t	mlk_stats;			/* Process-private M-lock statistics */
 GBLREF	mv_stent	*mv_chain;
@@ -77,9 +65,10 @@ error_def(ERR_LOCKINCR2HIGH);
 error_def(ERR_LOCKIS);
 error_def(ERR_LOCKTIMINGINTP);
 
+#define LCKLEVELLMT 511
 #define LOCKTIMESTR "LOCK"
-#define ZALLOCTIMESTR "ZALLOCATE"
 #define MAX_WARN_STR_ARG_LEN 256
+#define ZALLOCTIMESTR "ZALLOCATE"
 
 /* We made these messages seperate functions because we did not want to do the MAXSTR_BUFF_DECL(buff) declaration in op_lock2,
  * because  MAXSTR_BUFF_DECL macro would allocate a huge stack every time op_lock2 is called.
@@ -94,7 +83,7 @@ STATICFNDCL void level_err(mlk_pvtblk *pvt_ptr)
 	MAXSTR_BUFF_DECL(buff);
 	MAXSTR_BUFF_INIT;
 	lock_str_to_buff(pvt_ptr, buff, MAX_STRBUFF_INIT);
-	RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(7) ERR_LOCKINCR2HIGH, 1, pvt_ptr->level, ERR_LOCKIS, 2, LEN_AND_STR(buff));
+	RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(7) ERR_LOCKINCR2HIGH, 1, LCKLEVELLMT, ERR_LOCKIS, 2, LEN_AND_STR(buff));
 }
 STATICFNDCL void tp_warning(mlk_pvtblk *pvt_ptr)
 {
@@ -145,11 +134,12 @@ int	op_lock2(mval *timeout, unsigned char laflag)	/* timeout is in milliseconds
 	SETUP_THREADGBL_ACCESS;
 	gotit = -1;
 	cm_action = laflag;
-	out_of_time = timer_on = FALSE;
+	out_of_time = FALSE;
+	timer_on = FALSE;
 	if (CM_ZALLOCATES == cm_action)		/* can't use ? : syntax here because of the way the macros nest */
-		MV_FORCE_MSTIMEOUT(timeout, msec_timeout, ZALLOCTIMESTR);
+		MV_FORCE_MSTIMEOUT(timeout, &msec_timeout, ZALLOCTIMESTR);
 	else
-		MV_FORCE_MSTIMEOUT(timeout, msec_timeout, LOCKTIMESTR);
+		MV_FORCE_MSTIMEOUT(timeout, &msec_timeout, LOCKTIMESTR);
 	if (NO_M_TIMEOUT != msec_timeout)
 	{
 		if (0 == msec_timeout)
@@ -208,6 +198,7 @@ int	op_lock2(mval *timeout, unsigned char laflag)	/* timeout is in milliseconds
 			if (!gotit)
 			{	/* only REQIMMED returns false */
 				blocked = TRUE;
+				assert(INTRPT_IN_MLK_SHM_MODIFY != intrpt_ok_state);
 				break;
 			}
 		}
@@ -228,7 +219,8 @@ int	op_lock2(mval *timeout, unsigned char laflag)	/* timeout is in milliseconds
 					pvt_ptr1->level = 1;
 					break;
 				case INCREMENTAL:
-					if (pvt_ptr1->level < 511) /* The same lock can not be incremented more than 511 times. */
+					if (LCKLEVELLMT >= (pvt_ptr1->level + pvt_ptr1->translev))
+						/* The same lock can not be incremented more than 511 times. */
 						pvt_ptr1->level += pvt_ptr1->translev;
 					else
 						level_err(pvt_ptr1);
@@ -248,7 +240,10 @@ int	op_lock2(mval *timeout, unsigned char laflag)	/* timeout is in milliseconds
 		}
 		/* If we did not get blocked, we are all done */
 		if (!blocked)
+		{
+			assert(INTRPT_IN_MLK_SHM_MODIFY != intrpt_ok_state);
 			break;
+		}
 		/* We got blocked and need to keep retrying after some time interval */
 		if (remlkreq)
 			gvcmx_susremlk(cm_action);
@@ -310,6 +305,7 @@ int	op_lock2(mval *timeout, unsigned char laflag)	/* timeout is in milliseconds
 							if (0 >= msec_timeout)
 							{
 								out_of_time = TRUE;
+								assert(INTRPT_IN_MLK_SHM_MODIFY != intrpt_ok_state);
 								break;
 							}
 							if ((tptimeout != outofband) && (ctrlc != outofband))
@@ -336,6 +332,7 @@ int	op_lock2(mval *timeout, unsigned char laflag)	/* timeout is in milliseconds
 						lks_this_cmd = 0;	/* no return - clear flag that we're in LOCK processing */
 						async_action(FALSE);
 					}
+					assert(INTRPT_IN_MLK_SHM_MODIFY != intrpt_ok_state);
 					break;
 				}
 			}
@@ -378,13 +375,17 @@ int	op_lock2(mval *timeout, unsigned char laflag)	/* timeout is in milliseconds
 					already_locked = NULL;
 				} else
 					already_locked = pvt_ptr1;
+				assert(INTRPT_IN_MLK_SHM_MODIFY != intrpt_ok_state);
 				break;
 			}
 			if (pvt_ptr1->nodptr)
 				mlk_check_own(pvt_ptr1);		/* clear an abandoned owner */
 		}
 		if (blocked && out_of_time)
+		{
+			assert(INTRPT_IN_MLK_SHM_MODIFY != intrpt_ok_state);
 			break;
+		}
 		if (locks_bckout)
 			TREF(mlk_yield_pid) = MLK_FAIRNESS_DISABLED; /* Disable fairness to avoid livelocks */
 	}
