@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2019 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -15,30 +15,12 @@
 #include "io.h"
 #include "iosp.h"
 #include "iotimer.h"
+#include "iott_setterm.h"
 #include "stringpool.h"
 #include "op.h"
 #include "mvalconv.h"
 #include "ebc_xlat.h"
-#include "gdsroot.h"
-#include "gdskill.h"
-#include "gdsbt.h"
-#include "gtm_facility.h"
-#include "fileinfo.h"
-#include "gdsfhead.h"
-#include "gdscc.h"
-#include "filestruct.h"
-#include "buddy_list.h"		/* needed for tp.h */
-#include "jnl.h"
-#include "tp.h"
-#include "send_msg.h"
-#include "gtmmsg.h"		/* for gtm_putmsg() prototype */
-#include "change_reg.h"
-#include "setterm.h"
-#include "getzposition.h"
-#include "min_max.h"
-#ifdef DEBUG
-#include "have_crit.h"		/* for the TPNOTACID_CHECK macro */
-#endif
+#include "tpnotacid_chk_inline.h"
 
 #define TMP_BUF_LEN	1
 
@@ -58,7 +40,7 @@ int op_rdone(mval *v, mval *timeout)
 	DCL_THREADGBL_ACCESS;
 
 	SETUP_THREADGBL_ACCESS;
-	MV_FORCE_MSTIMEOUT(timeout, msec_timeout, READTIMESTR);
+	MV_FORCE_MSTIMEOUT(timeout, &msec_timeout, READTIMESTR);
 	active_device = io_curr_device.in;
 	x = -1;
 	assert(SIZEOF(mint) == SIZEOF(x));
