@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -34,10 +34,7 @@
 #include "repl_msg.h"			/* for gtmsource.h */
 #include "gtmsource.h"			/* for jnlpool_addrs_ptr_t */
 #include "have_crit.h"
-#include "deferred_events_queue.h"
-#include "deferred_events.h"
 #include "error_trap.h"
-#include "ztimeout_routines.h"
 #include "db_snapshot.h"
 #include "gvt_inline.h"
 
@@ -133,7 +130,6 @@ void	op_trollback(int rb_levels)		/* rb_levels -> # of transaction levels by whi
 				rel_crit(curreg);			/* release any crit regions */
 		}
 		reg_reset = FALSE;
-		CALL_ZTIMEOUT_IF_DEFERRED;
 		if (!process_exiting && lcl_implicit_trollback && tp_pointer->implicit_tstart)
 		{	/* This is an implicit TROLLBACK of an implicit TSTART started for a non-tp explicit update.
 			 * gv_currkey needs to be restored to the value it was at the beginning of the implicit TSTART.
