@@ -37,6 +37,8 @@ oprtype put_lit_s(mval *x, triple *dst_triple)
 
 	assert(MV_DEFINED(x));
 	MV_FORCE_STR(x);
+	if (MV_IS_CANONICAL(x))
+		MV_FORCE_NUM(x);
 	DEBUG_ONLY(litent = NULL);
 	if (dst_triple == NULL)
 		ref = newtriple(OC_LIT);
@@ -56,6 +58,7 @@ oprtype put_lit_s(mval *x, triple *dst_triple)
 			{
 				a->rt_addr--;
 				ref->operand[0].oprval.mlit = a;
+				a->reference_count += 1;
 				return put_tref(ref);
 			}
 	} else
@@ -89,12 +92,15 @@ oprtype put_lit_s(mval *x, triple *dst_triple)
 			assert(a);
 			assert(MV_DEFINED(&(a->v)));
 			assert(is_equ(x, &(a->v)));
+			assert(a->reference_count);
 			a->rt_addr--;
 			ref->operand[0].oprval.mlit = a;
+			a->reference_count += 1;
 			return put_tref(ref);
 		}
 	}
 	ref->operand[0].oprval.mlit = a = (mliteral *)mcalloc(SIZEOF(mliteral));
+	a->reference_count = 1;
 	dqins(&literal_chain, que, a);
 	a->rt_addr = -1;
 	a->v = *x;
