@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ * Copyright (c) 2001-2015 Fidelity National Information 	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -10,12 +11,17 @@
  ****************************************************************/
 
 #include "mdef.h"
+
 #include "compiler.h"
 
-oprtype put_mlab(mident *l)
+/* Routine to add the given label mident to the local label table and return an
+ * oprtype structure that defines the label.
+ */
+oprtype put_mlab(mident *lbl)
 {
-oprtype a;
-a.oprclass = MLAB_REF;
-a.oprval.lab = get_mladdr(l);
-return a;
+	oprtype a;
+
+	a.oprclass = MLAB_REF;
+	a.oprval.lab = get_mladdr(lbl);
+	return a;
 }
