@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ * Copyright (c) 2001-2015 Fidelity National Information 	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -12,11 +13,11 @@
 #include "mdef.h"
 #include "compiler.h"
 
-oprtype put_tref(x)
-triple *x;
+/* Create reference to given triple and return constructed reference operator type */
+oprtype put_tref(triple *x)
 {
-oprtype a;
-a.oprclass = TRIP_REF;
-a.oprval.tref = x;
-return a;
+	oprtype a;
+	a.oprclass = TRIP_REF;
+	a.oprval.tref = x;
+	return a;
 }
