@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Copyright (c) 2001-2020 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -13,7 +13,14 @@
 #ifndef RC_CPT_OPS_H_INCLUDED
 #define RC_CPT_OPS_H_INCLUDED
 
-int rc_cpt_entry(int blk);
+#ifndef GDSROOT_H
+/*This is a duplicate of the definition in gdsroot.h to keep from having to #include it.
+ * If that definition changes then so should this.
+ */
+typedef gtm_int8	block_id;
+#endif
+
+int rc_cpt_entry(block_id blk);
 int rc_cpt_inval(void);
 void rc_close_section(void);
 int mupip_rundown_cpt(void);
