@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2003-2018 Fidelity National Information	*
+ * Copyright (c) 2003-2025 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -12,6 +12,8 @@
 
 #ifndef READ_DB_FILES_FROM_GLD_H_INCLUDED
 #define READ_DB_FILES_FROM_GLD_H_INCLUDED
+#define MUST_OPEN_GTCM FALSE
+#define DO_NOT_OPEN_GTCM TRUE
 
 typedef struct gld_dbname_list_struct
 {
@@ -20,6 +22,6 @@ typedef struct gld_dbname_list_struct
 	struct gd_region_struct		*gd;
 } gld_dbname_list;
 
-gld_dbname_list *read_db_files_from_gld(gd_addr *addr);
+gld_dbname_list *read_db_files_from_gld(gd_addr *addr, bool skipGTCM);
 
 #endif
