@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -12,6 +13,6 @@
 #ifndef RESOLVE_LAB_INCLUDED
 #define RESOLVE_LAB_INCLUDED
 
-void resolve_lab(mlabel *label, int *errknt);
+void resolve_lab(mtreenode *node, void *arg);
 
 #endif /* RESOLVE_LAB_INCLUDED */
