@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2017-2020 Fidelity National Information	*
+ * Copyright (c) 2017-2022 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -10,9 +10,8 @@
  *								*
  ****************************************************************/
 
-#define RESTRICTED(FACILITY)											\
+#define RESTRICTED(FACILITY)								\
 		(!restrict_initialized ? (restrict_init(), restrictions.FACILITY) : restrictions.FACILITY)
-
 #define COMM_FILTER_FILENAME     	"filter_commands.tab"
 #define PIPE_C_CALL_NAME		"gtmpipeopen"
 #define ZSY_C_CALL_NAME			"gtmzsystem"
@@ -27,11 +26,16 @@ struct restrict_facilities
 	boolean_t	break_op;		/* V6.3-002 */
 	boolean_t	zbreak_op;
 	boolean_t	zedit_op;
+	boolean_t	zlink_op;
+	boolean_t	zrupdate_op;
 	boolean_t	zsystem_op;
 	boolean_t	pipe_open;
 	boolean_t	trigger_mod;
+	boolean_t	zroutines_op;
 	boolean_t	cenable;
 	boolean_t	dse;
+	boolean_t	lkeclear;
+	boolean_t	lke;
 	boolean_t	dmode;
 	boolean_t	zcmdline;
 	boolean_t	halt_op;		/* V6.3-003 */
@@ -39,11 +43,14 @@ struct restrict_facilities
 	boolean_t	zsy_filter;		/* V6.3-006 */
 	boolean_t	pipe_filter;
 	boolean_t	library_load_path;	/* V6.3-007 */
+	boolean_t	mupip_audit_enable;	/* V7.0-004 */
+	boolean_t	lke_audit_enable;
+	boolean_t	dse_audit_enable;
 	uint4		dm_audit_enable;
 	boolean_t	logdenials;		/* V6.3-012 */
+	boolean_t	aza_enable;
+	boolean_t	gde_enable;
 };
-
 GBLREF	struct restrict_facilities	restrictions;
 GBLREF	boolean_t			restrict_initialized;
-
 void restrict_init(void);
