@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2010 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2019 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -12,7 +13,7 @@
 #ifndef SGNL_INCLUDED
 #define SGNL_INCLUDED
 
-void sgnl_gvnulsubsc(void);
+void sgnl_gvnulsubsc(char *place);
 void sgnl_gvreplerr(void);
 void sgnl_gvundef(void);
 
