@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2005 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2019 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -11,6 +12,6 @@
 #ifndef SGTM_PUTMSG_H
 #define SGTM_PUTMSG_H
 
-void		sgtm_putmsg(char *out_str, ...);
+void		sgtm_putmsg(char *out_str, size_t out_str_len, ...);
 
 #endif
