@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2007 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -9,8 +10,8 @@
  *								*
  ****************************************************************/
 
-#ifndef __SORTS_AFTER_H__
-#define __SORTS_AFTER_H__
+#ifndef SORTS_AFTER_H_INCLUDED
+#define SORTS_AFTER_H_INCLUDED
 
 long sorts_after(mval *lhs, mval *rhs);
 
