@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2024 Fidelity National Information	*
+ * Copyright (c) 2001-2025 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -88,6 +88,7 @@
 #include "jnl_file_close_timer.h"
 #include "gtmdbglvl.h"		/* for GDL_UnconditionalEpoch */
 #include "inline_atomic_pid.h"
+#include "inline_not_frozen.h" /* for not_frozen_hard */
 
 GBLREF	bool			rc_locked;
 GBLREF	unsigned char		t_fail_hist[CDB_MAX_TRIES];
@@ -732,7 +733,7 @@ trans_num t_end(srch_hist *hist1, srch_hist *hist2, trans_num ctn)
 	}
 	CHECK_TN(csa, csd, cti->curr_tn);	/* macro might issue rts_error TNTOOLARGE */
 	/* We should never proceed to update a frozen database. Only exception is DSE */
-	assert(!FROZEN_HARD(csa) || IS_DSE_IMAGE);
+	assert(not_frozen_hard(csa) || IS_DSE_IMAGE);
 	/* We never expect to come here with file_corrupt set to TRUE (in case of an online rollback) because
 	 * grab_crit done above will make sure of that. The only exception is RECOVER/ROLLBACK itself coming
 	 * here in the forward phase
@@ -1917,7 +1918,7 @@ trans_num t_end(srch_hist *hist1, srch_hist *hist2, trans_num ctn)
 	SET_CUR_CMT_STEP_IF(TRUE, TREF(cur_cmt_step), CMT12);
 	assert(cdb_sc_normal == status);
 	/* Should never increment curr_tn on a frozen database except if DSE. */
-	assert(!(FROZEN_HARD(csa) || (replication && IS_REPL_INST_FROZEN_JPL(jnlpool, TREF(defer_instance_freeze))))
+	assert(not_frozen_hard(csa) || !(replication && IS_REPL_INST_FROZEN_JPL(jnlpool, TREF(defer_instance_freeze)))
 			|| IS_DSE_IMAGE);
 	/* To avoid confusing concurrent processes, MM requires a barrier before incrementing db TN. For BG, cr->in_tend
 	 * serves this purpose so no barrier is needed. See comment in tp_tend.
