@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2007-2024 Fidelity National Information	*
+ * Copyright (c) 2007-2025 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -92,6 +92,7 @@
 #include "wcs_wt.h"
 #include "mu_upgrade_bmm.h"	/* for MUPIP_REORG_UPGRADE_NOW_SPLITTING */
 #include "inline_atomic_pid.h"
+#include "inline_not_frozen.h" /* for not_frozen_chilled */
 
 error_def(ERR_DBFILERR);
 error_def(ERR_FREEBLKSLOW);
@@ -555,14 +556,14 @@ enum cdb_sc bg_update_phase1(cw_set_element *cs, trans_num ctn, sgm_info *si)
 			{
 				assert(gtm_white_box_test_case_enabled);
 #				ifdef DEBUG
-				if (NULL != save_cr)
+				if ((NULL != save_cr) && ((cache_rec_ptr_t)CR_NOTVALID != save_cr))
 				{	/* release the r_epid lock on the valid cache-record returned from db_csh_getn */
 					assert(save_cr->r_epid == process_id);
 					save_cr->r_epid = 0;
 					assert(0 == save_cr->read_in_progress);
 					RELEASE_BUFF_READ_LOCK(save_cr);
-					TREF(block_now_locked) = NULL;
 				}
+				TREF(block_now_locked) = NULL;
 #				endif
 				BG_TRACE_PRO(wcb_t_end_sysops_nocr_invcr);
 				send_msg_csa(CSA_ARG(csa) VARLSTCNT(8) ERR_WCBLOCKED, 6, LEN_AND_LIT("wcb_t_end_sysops_nocr_invcr"),
@@ -740,7 +741,7 @@ enum cdb_sc bg_update_phase1(cw_set_element *cs, trans_num ctn, sgm_info *si)
 				{
 					assert(gtm_white_box_test_case_enabled);
 #					ifdef DEBUG
-					if (NULL != save_cr)
+					if ((NULL != save_cr) && ((cache_rec_ptr_t)CR_NOTVALID != save_cr))
 					{	/* Since we are simulating a "db_csh_getn" failure return,
 						 * undo all changes in db_csh_getn that would otherwise persist.
 						 */
@@ -752,8 +753,8 @@ enum cdb_sc bg_update_phase1(cw_set_element *cs, trans_num ctn, sgm_info *si)
 						RELEASE_BUFF_READ_LOCK(save_cr);
 						assert(blkid == save_cr->blk);
 						save_cr->blk = CR_BLKEMPTY;
-						TREF(block_now_locked) = NULL;
 					}
+					TREF(block_now_locked) = NULL;
 #					endif
 					BG_TRACE_PRO(wcb_t_end_sysops_dirty_invcr);
 					send_msg_csa(CSA_ARG(csa) VARLSTCNT(8) ERR_WCBLOCKED, 6,
@@ -1462,7 +1463,7 @@ void wcs_stale(TID tid, int4 hd_len, gd_region **region)
 				}
 				break;
 			case dba_mm:
-				assert(!FROZEN_CHILLED(csa));
+				assert(not_frozen_chilled(csa));
 				wcs_wtstart(reg, 0, NULL, NULL);
 				assert(csd == csa->hdr);
 				need_new_timer = FALSE;
