@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2011 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -12,8 +13,7 @@
 #include "mdef.h"
 #include "compiler.h"
 
-void tnxtarg(a)
-oprtype *a;
+void tnxtarg(oprtype *a)
 {	/*return a reference to the next triple to be produced */
 	DCL_THREADGBL_ACCESS;
 
