@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -20,8 +20,6 @@
 #include "buddy_list.h"
 #include "jnl.h"
 
-error_def(ERR_TPNOTACID);
-
 #define JNL_LIST_INIT_ALLOC		16		/* initial allocation for si->jnl_list */
 #define	CW_SET_LIST_INIT_ALLOC		64		/* initial allocation for si->cw_set_list */
 #define	TLVL_CW_SET_LIST_INIT_ALLOC     64		/* initial allocation for si->tlvl_cw_set_list */
@@ -216,6 +214,12 @@ typedef struct
 #endif
 } off_chain;
 
+typedef union
+{
+	block_id	id;
+	off_chain	chain;
+} block_ref;
+
 typedef struct
 {
 #ifdef	BIGENDIAN
@@ -229,29 +233,45 @@ typedef struct
 #endif
 } v6_off_chain;
 
-static inline void WRITE_OFF_CHAIN(boolean_t long_blk_id, off_chain* chain, v6_off_chain* v6_chain, sm_uc_ptr_t ptr)
+typedef union
+{
+	block_id_32	id;
+	v6_off_chain	chain;
+} v6_block_ref;
+
+static inline void WRITE_OFF_CHAIN(boolean_t long_blk_id, off_chain* chain, sm_uc_ptr_t ptr)
 {
 	if (long_blk_id)
-		GET_BLK_ID_64P(ptr, chain);
-	else
+	{	block_ref	*ref = (block_ref *)chain;
+
+		PUT_BLK_ID_64(ptr, ref->id);
+	} else
 	{
-		v6_chain->flag = chain->flag;
-		v6_chain->cw_index = chain->cw_index;
-		v6_chain->next_off = chain->next_off;
-		GET_BLK_ID_32P(ptr, v6_chain);
+		v6_block_ref	v6_ref;
+
+		v6_ref.chain.flag = chain->flag;
+		v6_ref.chain.cw_index = chain->cw_index;
+		v6_ref.chain.next_off = chain->next_off;
+		PUT_BLK_ID_32(ptr, v6_ref.id);
 	}
 }
 
-static inline void READ_OFF_CHAIN(boolean_t long_blk_id, off_chain* chain, v6_off_chain* v6_chain, sm_uc_ptr_t ptr)
+static inline void READ_OFF_CHAIN(boolean_t long_blk_id, off_chain* chain, sm_uc_ptr_t ptr)
 {
 	if (long_blk_id)
-		GET_BLK_ID_64P(chain, ptr);
-	else
 	{
-		GET_BLK_ID_32P(v6_chain, ptr);
-		chain->flag = v6_chain->flag;
-		chain->cw_index = v6_chain->cw_index;
-		chain->next_off = v6_chain->next_off;
+		block_ref	ref;
+
+		GET_BLK_ID_64(ref.id, ptr);
+		*chain = ref.chain;
+	} else
+	{
+		v6_block_ref	v6_ref;
+
+		GET_BLK_ID_32(v6_ref.id, ptr);
+		chain->flag = v6_ref.chain.flag;
+		chain->cw_index = v6_ref.chain.cw_index;
+		chain->next_off = v6_ref.chain.next_off;
 	}
 }
 
@@ -337,7 +357,7 @@ static inline void READ_OFF_CHAIN(boolean_t long_blk_id, off_chain* chain, v6_of
 {														\
 	int		cw_set_depth;										\
 	int		level;											\
-	off_chain	chain1;											\
+	block_ref	chain1;											\
 														\
 	cw_set_depth = CW_DEPTH;										\
 	if (GVNH->split_cleanup_needed)										\
@@ -346,8 +366,8 @@ static inline void READ_OFF_CHAIN(boolean_t long_blk_id, off_chain* chain, v6_of
 		 */												\
 		for (level = 0; level < ARRAYSIZE(GVNH->last_split_blk_num); level++)				\
 		{												\
-			chain1 = *(off_chain *)&GVNH->last_split_blk_num[level];				\
-			if (chain1.flag && ((unsigned)cw_set_depth <= (unsigned)chain1.cw_index))		\
+			chain1.id = GVNH->last_split_blk_num[level];						\
+			if (chain1.chain.flag && ((unsigned)cw_set_depth <= (unsigned)chain1.chain.cw_index))	\
 				GVNH->last_split_blk_num[level] = 0;						\
 		}												\
 	}													\
@@ -360,6 +380,7 @@ static inline void READ_OFF_CHAIN(boolean_t long_blk_id, off_chain* chain, v6_of
  */
 #  define RESET_ALL_GVT_CLUES											\
 {														\
+	GBLREF	uint4		mu_upgrade_in_prog;		/* 1 indicates MUPIP UPGRADE in progress */	\
 	GBLREF	gv_namehead	*gv_target_list;								\
 	GBLREF	gv_namehead	*reorg_gv_target;								\
 														\
@@ -370,7 +391,7 @@ static inline void READ_OFF_CHAIN(boolean_t long_blk_id, off_chain* chain, v6_of
 		gvnh->clue.end = 0;										\
 		if (gvnh->gd_csa && (gvnh != gvnh->gd_csa->dir_tree))						\
 		{												\
-			assert ((DIR_ROOT != gvnh->root) || (gvnh == reorg_gv_target));				\
+			assert ((DIR_ROOT != gvnh->root) || (gvnh == reorg_gv_target) || mu_upgrade_in_prog);	\
 			gvnh->root = 0;										\
 		}												\
 		/* Cleanup any block-split info (of created block #) in gvtarget histories */			\
@@ -568,12 +589,12 @@ typedef struct trans_restart_hist_struct
 
 #define INVALIDATE_CLUE(CSE) 					\
 {								\
-	off_chain	macro_chain;				\
+	block_ref	macro_chain;				\
 								\
 	assert(CSE->blk_target);				\
 	CSE->blk_target->clue.end = 0;				\
-	macro_chain = *(off_chain *)&CSE->blk_target->root;	\
-	if (macro_chain.flag)					\
+	macro_chain.id = CSE->blk_target->root;			\
+	if (macro_chain.chain.flag)				\
 		CSE->blk_target->root = 0;			\
 }
 
@@ -907,69 +928,6 @@ typedef enum
 GBLREF	uint4		dollar_tlevel;
 GBLREF	unsigned int	t_tries;
 
-#define	IS_TP_AND_FINAL_RETRY 		(dollar_tlevel && (CDB_STAGNATE <= t_tries))
-
-#define	TP_REL_CRIT_ALL_REG							\
-{										\
-	sgmnt_addrs		*csa;						\
-	tp_region		*tr;						\
-										\
-	GBLREF	tp_region	*tp_reg_list;					\
-										\
-	for (tr = tp_reg_list;  NULL != tr;  tr = tr->fPtr)			\
-	{									\
-		assert(tr->reg->open);						\
-		if (!tr->reg->open)						\
-			continue;						\
-		csa = (sgmnt_addrs *)&FILE_INFO(tr->reg)->s_addrs;		\
-		assert(!csa->hold_onto_crit);					\
-		if (csa->now_crit)						\
-			rel_crit(tr->reg);					\
-	}									\
-	assert(!have_crit(CRIT_HAVE_ANY_REG));					\
-}
-
-#define	TP_FINAL_RETRY_DECREMENT_T_TRIES_IF_OK									\
-{														\
-	GBLREF	boolean_t	mupip_jnl_recover;								\
-														\
-	assert(dollar_tlevel);											\
-	assert(CDB_STAGNATE == t_tries);									\
-	/* mupip_jnl_recovery operates with t_tries=CDB_STAGNATE so we should not adjust t_tries		\
-	 * In that case, because we have standalone access, we don't expect anyone else to interfere with us 	\
-	 * and cause a restart, but if they do, TPNOTACID_CHECK (below) gives a TPNOTACID message.		\
-	 */													\
-	if (!mupip_jnl_recover)											\
-	{													\
-		assert(dollar_trestart >= TREF(tp_restart_dont_counts));					\
-		t_tries = CDB_STAGNATE - 1;									\
-		DEBUG_ONLY(if (0 == TREF(tp_restart_dont_counts)))						\
-			DEBUG_ONLY((TREF(tp_restart_dont_counts))++);	/* can live with one too many */	\
-		DEBUG_ONLY(if (0 < TREF(tp_restart_dont_counts)))						\
-			DEBUG_ONLY((TREF(tp_restart_dont_counts)) = -(TREF(tp_restart_dont_counts)));		\
-	}													\
-}
-
-#define TPNOTACID_DEFAULT_TIME	2 * MILLISECS_IN_SEC	/* default for tpnotacidtime */
-#define TPNOTACID_MAX_TIME	30	/* maximum (in seconds)for tpnotacidtime */
-#define TPTIMEOUT_MAX_TIME	60	/* maximum (in seconds) for dollar_zmaxtptime - enforced in gtm_env_init, not in op_svput */
-
-#define	TPNOTACID_CHECK(CALLER_STR)												\
-{																\
-	GBLREF	boolean_t	mupip_jnl_recover;										\
-	mval		zpos;													\
-																\
-	if (IS_TP_AND_FINAL_RETRY)												\
-	{															\
-		TP_REL_CRIT_ALL_REG;												\
-		assert(!mupip_jnl_recover);											\
-		TP_FINAL_RETRY_DECREMENT_T_TRIES_IF_OK;										\
-		getzposition(&zpos);												\
-		send_msg_csa(CSA_ARG(NULL) VARLSTCNT(9) ERR_TPNOTACID, 7, LEN_AND_LIT(CALLER_STR), zpos.str.len, zpos.str.addr, \
-			 (TREF(tpnotacidtime)).str.len, (TREF(tpnotacidtime)).str.addr, dollar_trestart);			\
-	}															\
-}
-
 #define SAVE_REGION_INFO(SAVE_KEY_BUF, SAVE_TARGET, SAVE_CUR_REG, SAVE_SI_PTR, SAVE_JNLPOOL)	\
 MBSTART {											\
 	SAVE_TARGET = gv_target;								\
@@ -1017,8 +975,6 @@ void tp_timeout_action_dummy(void);
 boolean_t	tp_tend(void);
 boolean_t	tp_crit_all_regions(void);
 
-#endif
-
 #define	GVNAME_UNKNOWN		"*BITMAP"
 #define GVNAME_DIRTREE		"*DIR"
 
@@ -1026,3 +982,5 @@ static readonly char		gvname_unknown[] = GVNAME_UNKNOWN;
 static readonly int4		gvname_unknown_len = STR_LIT_LEN(GVNAME_UNKNOWN);
 static readonly char		gvname_dirtree[] = GVNAME_DIRTREE;
 static readonly int4		gvname_dirtree_len = STR_LIT_LEN(GVNAME_DIRTREE);
+
+#endif
