@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2019 Fidelity National Information	*
+ * Copyright (c) 2001-2021 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -16,7 +16,7 @@
 #include <rtnhdr.h> /* For urx.h */
 #include "urx.h"
 
-void urx_putlab (char *lab, int lablen, urx_rtnref *rtn, char *addr)
+void urx_putlab (char *lab, unsigned int lablen, urx_rtnref *rtn, char *addr)
 {
 	urx_labref	*lp0, *lp1, *tmplp;
 	boolean_t	found;
@@ -60,7 +60,7 @@ void urx_putlab (char *lab, int lablen, urx_rtnref *rtn, char *addr)
 	{	/* Add new label name to list */
 		tmplp = (urx_labref *)malloc(SIZEOF(urx_labref) + lablen);
 		tmplp->len = lablen;
-		memcpy(&tmplp->name[0], lab, lablen);
+		memcpy(&tmplp->name[0], lab, tmplp->len);
 		tmplp->addr = 0;
 		tmplp->next = lp1;
 		if (lp0 == (urx_labref *)rtn)
