@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2007 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -15,6 +16,6 @@ typedef	struct urx_addr_type
 		struct urx_addr_type	*next;
 	}	urx_addr;
 
-void urx_putlab(char *lab, int lablen, urx_rtnref *rtn, char *addr);
+void urx_putlab(char *lab, unsigned int lablen, urx_rtnref *rtn, char *addr);
 bool azl_geturxlab (char *addr, urx_rtnref *rp);
 bool azl_geturxrtn (char *addr, mstr *rname, urx_rtnref **rp);
