@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2012 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -15,7 +16,7 @@
 
 GBLREF bool	out_of_time;
 
-void wake_alarm(void)
+void wake_alarm(TID tid, int4 len, void *data)
 {
 	out_of_time = TRUE;
 	GT_WAKE;
