@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -72,13 +72,26 @@ error_def(ERR_STACKOFLOW);
 error_def(ERR_STACKCRIT);
 error_def(ERR_MAXNRSUBSCRIPTS);
 
+static int gv_sbs_depth(gv_key *key)
+{
+	int i, depth;
+	
+	depth = 0;
+	for (i = 0; i < key->end; ++i)
+	{
+		if (key->base[i] == KEY_DELIMITER)
+			++depth;
+	}
+	return depth;
+}
+
 void zshow_output(zshow_out *out, const mstr *str)
 {
 	boolean_t	is_base_var, lvundef, utf8_active, zshow_depth;
 	char		buff, *leadptr, *piecestr, *strbase, *strnext, *strptr, *strtokptr, *strtop, *tempstr;
 	gd_addr		*gbl_gd_addr;
 	gvnh_reg_t	*gvnh_reg;
-	int		dbg_sbs_depth, sbs_depth, str_processed;
+	int		dbg_sbs_depth, sbs_depth, str_processed, tmp_len;
 	lv_val		*lv, *lv_child;
 	mval		lmv, *mv_child, *mv;
 	ssize_t		buff_len, cumul_width, device_width, inchar_width, len, outlen, chcnt, char_len, disp_len;
@@ -222,7 +235,7 @@ void zshow_output(zshow_out *out, const mstr *str)
 					ENSURE_STP_FREE_SPACE(len);
 					mv_child->str.addr = (char *)stringpool.free;
 					stringpool.free +=len;
-					strncpy(mv_child->str.addr, piecestr, (size_t)len);
+					memcpy(mv_child->str.addr, piecestr, (size_t)len);
 					mv_child->str.len = len;
 					/* make sure the subscript will fit */
 					is_base_var = LV_IS_BASE_VAR(lv_child);
@@ -350,15 +363,16 @@ void zshow_output(zshow_out *out, const mstr *str)
 			gvnh_reg = TREF(gd_targ_gvnh_reg);	/* set by op_gvname/op_gvextnam/op_gvnaked at start of ZSHOW cmd */
 			gv_currkey->end = out->out_var.gv.end;
 			gv_currkey->prev = out->out_var.gv.prev;
-			gv_currkey->base[gv_currkey->end] = 0;
+			gv_currkey->base[gv_currkey->end] = KEY_DELIMITER;
 			/* add the "code" subscript */
 			mval2subsc(mv_child, gv_currkey, gv_cur_region->std_null_coll);
 			/* ensure this subscript "code" does not exist by deleting it*/
 			if (out->code && out->code != out->curr_code)
 			{
 				GV_BIND_SUBSNAME_FROM_GVNH_REG_IF_GVSPAN(gvnh_reg, gbl_gd_addr, gv_currkey);
-				if (gv_currkey->end >= gv_cur_region->max_key_size)
-					ISSUE_GVSUBOFLOW_ERROR(gv_currkey, KEY_COMPLETE_TRUE);
+				if ((tmp_len = gv_currkey->end) >= gv_cur_region->max_key_size)
+					ISSUE_GVSUBOFLOW_ERROR(gv_currkey, KEY_COMPLETE_TRUE, (tmp_len+1),
+							gv_cur_region->max_key_size, gv_cur_region);
 				op_gvkill();
 			}
 			tempstr=str->addr;
@@ -375,8 +389,9 @@ void zshow_output(zshow_out *out, const mstr *str)
 				mv_child->str.len = len;
 				mval2subsc(mv_child, gv_currkey, gv_cur_region->std_null_coll);
 				GV_BIND_SUBSNAME_FROM_GVNH_REG_IF_GVSPAN(gvnh_reg, gbl_gd_addr, gv_currkey);
-				if (gv_currkey->end >= gv_cur_region->max_key_size)
-					ISSUE_GVSUBOFLOW_ERROR(gv_currkey, KEY_COMPLETE_TRUE);
+				if ((tmp_len = gv_currkey->end) >= gv_cur_region->max_key_size)
+					ISSUE_GVSUBOFLOW_ERROR(gv_currkey, KEY_COMPLETE_TRUE, (tmp_len+1),
+										gv_cur_region->max_key_size, gv_cur_region);
 			}
 			op_gvput((mval *)&literal_null); /* create the global */
 			POP_MV_STENT(); /* we are done with our mval */
@@ -395,13 +410,17 @@ void zshow_output(zshow_out *out, const mstr *str)
 			mv->str.len = 1;
 			mv->str.addr = &buff;
 			*mv->str.addr = out->code;
+			sbs_depth = gv_sbs_depth(gv_currkey);
+			if (MAX_GVSUBSCRIPTS <= (sbs_depth + 1))
+				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_MAXNRSUBSCRIPTS);
 			mval2subsc(mv, gv_currkey, gv_cur_region->std_null_coll);
 			/* If gvnh_reg corresponds to a spanning global, then determine
 			 * gv_cur_region/gv_target/gd_targ_* variables based on updated gv_currkey.
 			 */
 			GV_BIND_SUBSNAME_FROM_GVNH_REG_IF_GVSPAN(gvnh_reg, gbl_gd_addr, gv_currkey);
-			if (gv_currkey->end >= gv_cur_region->max_key_size)
-				ISSUE_GVSUBOFLOW_ERROR(gv_currkey, KEY_COMPLETE_TRUE);
+			if ((tmp_len = gv_currkey->end) >= gv_cur_region->max_key_size)
+				ISSUE_GVSUBOFLOW_ERROR(gv_currkey, KEY_COMPLETE_TRUE, (tmp_len+1), gv_cur_region->max_key_size,
+													gv_cur_region);
 			assert(gv_currkey->end - 3 == out->out_var.gv.end);	/* true for current 1 character string codes */
 			op_gvkill();
 		}
@@ -450,8 +469,9 @@ void zshow_output(zshow_out *out, const mstr *str)
 							 * gv_cur_region/gv_target/gd_targ_* variables based on updated gv_currkey.
 							 */
 							GV_BIND_SUBSNAME_FROM_GVNH_REG_IF_GVSPAN(gvnh_reg, gbl_gd_addr, gv_currkey);
-							if (gv_currkey->end >= gv_cur_region->max_key_size)
-								ISSUE_GVSUBOFLOW_ERROR(gv_currkey, KEY_COMPLETE_TRUE);
+							if ((tmp_len = gv_currkey->end) >= gv_cur_region->max_key_size)
+								ISSUE_GVSUBOFLOW_ERROR(gv_currkey, KEY_COMPLETE_TRUE, (tmp_len+1),
+											gv_cur_region->max_key_size, gv_cur_region);
 						}
 					}
 					ENSURE_STP_FREE_SPACE((int)(out->ptr - out->buff));
@@ -468,8 +488,9 @@ void zshow_output(zshow_out *out, const mstr *str)
 						MV_FORCE_MVAL(mv, out->line_cont);	/* but the rest go down a level */
 						mval2subsc(mv, gv_currkey, gv_cur_region->std_null_coll);
 						GV_BIND_SUBSNAME_FROM_GVNH_REG_IF_GVSPAN(gvnh_reg, gbl_gd_addr, gv_currkey);
-						if (gv_currkey->end >= gv_cur_region->max_key_size)
-							ISSUE_GVSUBOFLOW_ERROR(gv_currkey, KEY_COMPLETE_TRUE);
+						if ((tmp_len = gv_currkey->end) >= gv_cur_region->max_key_size)
+							ISSUE_GVSUBOFLOW_ERROR(gv_currkey, KEY_COMPLETE_TRUE, (tmp_len+1),
+											gv_cur_region->max_key_size, gv_cur_region);
 					}
 				}
 			}
@@ -494,8 +515,9 @@ void zshow_output(zshow_out *out, const mstr *str)
 					 * gv_cur_region/gv_target/gd_targ_* variables based on updated gv_currkey.
 					 */
 					GV_BIND_SUBSNAME_FROM_GVNH_REG_IF_GVSPAN(gvnh_reg, gbl_gd_addr, gv_currkey);
-					if (gv_currkey->end >= gv_cur_region->max_key_size)
-						ISSUE_GVSUBOFLOW_ERROR(gv_currkey, KEY_COMPLETE_TRUE);
+					if ((tmp_len = gv_currkey->end) >= gv_cur_region->max_key_size)
+						ISSUE_GVSUBOFLOW_ERROR(gv_currkey, KEY_COMPLETE_TRUE, (tmp_len+1),
+											gv_cur_region->max_key_size, gv_cur_region);
 				}
 			}
 			ENSURE_STP_FREE_SPACE((int)(out->ptr - out->buff));
