@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -141,6 +141,7 @@ static readonly char ztwormhole_text[] = "$ZTWORMHOLE";
 static readonly char zusedstor_text[] = "$ZUSEDSTOR";
 static readonly char zversion_text[] = "$ZVERSION";
 static readonly char zreldate_text[] = "$ZRELDATE";
+static readonly char zicuver_text[] = "$ZICUVER";
 static readonly char zyerror_text[] = "$ZYERROR";
 static readonly char zonlnrlbk_text[] = "$ZONLNRLBK";
 static readonly char zclose_text[] = "$ZCLOSE";
@@ -150,7 +151,7 @@ static readonly char arrow_text[] = "->";
 GBLREF boolean_t		dollar_zquit_anyway;
 GBLREF int4			dollar_zeditor, dollar_zsystem, zdir_form;
 GBLREF io_log_name		*dollar_principal, *io_root_log_name;
-GBLREF io_pair			io_curr_device, *io_std_device;;
+GBLREF io_pair			io_curr_device, *io_std_device;
 GBLREF mlk_subhash_val_t	mlk_last_hash;
 GBLREF mstr			dollar_zchset, dollar_zpatnumeric, dollar_zpin, dollar_zpout;
 GBLREF mval			dollar_estack_delta, dollar_job, dollar_system, dollar_zdir, dollar_zerror, dollar_zgbldir;
@@ -163,15 +164,16 @@ GBLREF volatile boolean_t	dollar_zininterrupt;
 #ifdef GTM_TRIGGER
 GBLREF int4			gtm_trigger_depth;
 GBLREF mstr			*dollar_ztname;
+GBLREF mstr			dollar_zicuver;
 GBLREF mval			*dollar_ztdata, *dollar_ztdelim, *dollar_ztoldval, *dollar_ztriggerop, dollar_ztslate;
 GBLREF mval			*dollar_ztupdate, *dollar_ztvalue, dollar_ztwormhole;
 #endif
 
-LITREF mval		literal_zero, literal_one, literal_null;
 LITREF char		gtm_release_name[];
 LITREF int4		gtm_release_name_len;
 LITREF char		gtm_release_stamp[];
 LITREF int4		gtm_release_stamp_len;
+LITREF mval		literal_mv_bias, literal_null, literal_zero, literal_one;
 
 #define ZWRITE_DOLLAR_PRINCIPAL(MVAL, X, TEXT, OUTPUT)					\
 {											\
@@ -336,8 +338,11 @@ void zshow_svn(zshow_out *output, int one_sv)
 				break;
 		/* CAUTION: fall through */
 		case SV_STORAGE:
-			/* double2mval(&var, getstorage()); Causes issues with unaligned stack on x86_64 - remove until fixed */
-			i2mval(&var, getstorage());
+			count = (0 < zmalloclim) ? ((int)zmalloclim) : ((int)gtm_getrlimit());
+			count -= (int)totalRmalloc;
+			if (0 > count)
+				count = 0;
+			MV_FORCE_MVAL(&var, count);
 			ZS_VAR_EQU(&x, storage_text);
 			mval_write(output, &var, TRUE);
 			if (SV_ALL != one_sv)
@@ -477,7 +482,7 @@ void zshow_svn(zshow_out *output, int one_sv)
 			setzdir(NULL, &zdir);
 			if (zdir.str.len != dollar_zdir.str.len || 0 != memcmp(zdir.str.addr, dollar_zdir.str.addr, zdir.str.len))
 			{
-				memcpy(zdir_error, zdir.str.addr, zdir.str.len);
+				memcpy((void *)zdir_error, zdir.str.addr, zdir.str.len);
 				memcpy(&zdir_error[zdir.str.len], arrow_text, STR_LIT_LEN(arrow_text));
 				zdir_error_rem_len = ZDIR_ERR_LEN - zdir.str.len - STR_LIT_LEN(arrow_text);
 				sgtm_putmsg(&zdir_error[zdir.str.len + STR_LIT_LEN(arrow_text)], zdir_error_rem_len,
@@ -525,6 +530,14 @@ void zshow_svn(zshow_out *output, int one_sv)
 			if (SV_ALL != one_sv)
 				break;
 		/* CAUTION: fall through */
+		case SV_ZICUVER:
+			var.mvtype = MV_STR;
+			var.str = dollar_zicuver;
+			ZS_VAR_EQU(&x, zicuver_text);
+			mval_write(output, &var, TRUE);
+			if (SV_ALL != one_sv)
+				break;
+		/* CAUTION: fall through */
 		case SV_ZININTERRUPT:
 			MV_FORCE_MVAL(&var, dollar_zininterrupt);
 			ZS_VAR_EQU(&x, zininterrupt_text);
@@ -594,6 +607,8 @@ void zshow_svn(zshow_out *output, int one_sv)
 		/* CAUTION: fall through */
 		case SV_ZMAXTPTIME:
 			MV_FORCE_MVAL(&var, TREF(dollar_zmaxtptime));
+			assert(MV_BIAS == MILLISECS_IN_SEC);				/* check math if this changes */
+			op_div(&var, (mval*)&literal_mv_bias, &var);
 			ZS_VAR_EQU(&x, zmaxtptime_text);
 			mval_write(output, &var, TRUE);
 			if (SV_ALL != one_sv)
