@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2009 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -30,16 +31,9 @@ void gtcm_init_ast(struct CLB *c)
 {
 	connection_struct *cs;
 
-	cs = UNIX_ONLY(c->usr;) /* for Unix, allocated already -- setup now */
-	     VMS_ONLY((connection_struct *)malloc(SIZEOF(connection_struct));)
+	cs = c->usr; /* allocated already -- setup now */
 	memset(cs, 0, SIZEOF(*cs));
-	UNIX_ONLY(gettimeofday(&cs->connect, NULL);)
-	VMS_ONLY(
-		sys$gettim(&cs->connect[0]);
-		c->usr = cs;
-		c->mbf = malloc(CM_MSG_BUF_SIZE + CM_BUFFER_OVERHEAD);
-		c->mbl = CM_MSG_BUF_SIZE + CM_BUFFER_OVERHEAD;
-	)
+	clock_gettime(CLOCK_REALTIME, &cs->connect);
 	cs->lk_cancel = cs->last_cancelled = CM_NOLKCANCEL;
 	cs->clb_ptr = c;
 	c->ast = gtcm_read_ast;
