@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2011 Fidelity Information Services, Inc	*
+ *	Copyright 2001, 2013 Fidelity Information Services, Inc	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -34,12 +34,12 @@ error_def(ERR_VMSMEMORY);
 
 CONDITION_HANDLER(gvcmy_open_ch)
 {
-	START_CH;
+	START_CH(TRUE);
 	if (DUMPABLE)
 	{ /* don't disturb state so that the core reflects the "bad" state */
 		NEXTCH;
 	}
-	if (WARNING == SEVERITY || INFO == SEVERITY)
+	if (WARNING == SEVERITY)
 	{
 		PRN_ERROR;
 		CONTINUE;
