@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ * Copyright (c) 2001-2015 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -12,7 +13,7 @@
 /* ch_overrun -- condition handler overrun -- default condition handler for Unix -- no normal return from this module */
 #include "mdef.h"
 
-#include "gtm_stdlib.h"	/* for exit() usage in MUMPS_EXIT macro */
+#include "gtm_stdlib.h"	/* for EXIT() usage in MUMPS_EXIT macro */
 
 #include "error.h"
 #include "send_msg.h"
@@ -21,12 +22,13 @@
 GBLREF int		mumps_status;
 GBLREF boolean_t	exit_handler_active;
 
+error_def(ERR_NOCHLEFT);
+
 void ch_overrun(void)
 {
-	error_def(ERR_NOCHLEFT);
-
-	gtm_putmsg(VARLSTCNT(1) ERR_NOCHLEFT);
-	send_msg(VARLSTCNT(1) ERR_NOCHLEFT);
+	PRN_ERROR;
+	gtm_putmsg_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_NOCHLEFT);
+	send_msg_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_NOCHLEFT);
 
 	/* If exit handler is already active, we will just core and die */
 	if (exit_handler_active)
