@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -9,9 +10,10 @@
  *								*
  ****************************************************************/
 
-#ifndef __DO_SHMAT_H__
-#define __DO_SHMAT_H__
+#ifndef DO_SHMAT_H_INCLUDED
+#define DO_SHMAT_H_INCLUDED
 
-void *do_shmat(int4 shmid, const void *shmaddr, int4 shmflg);
+void *do_shmat(int4 shmid, const void *shm_base, int4 shmflg);
+void *do_shmat_exec_perm(int4 shmid, size_t shm_size, int *save_errno);
 
 #endif
