@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2007 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -9,8 +10,8 @@
  *								*
  ****************************************************************/
 
-#ifndef __GCALL_ARGS_H__
-#define __GCALL_ARGS_H__
+#ifndef GCALL_ARGS_H_INCLUDED
+#define GCALL_ARGS_H_INCLUDED
 #include "mdef.h"
 
 typedef struct gcall_args_struct {
