@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -23,20 +23,41 @@
 
 error_def(ERR_SYSCALL);
 
+int4	gtm_getrlimit(void)
+{
+	struct rlimit	rl;
+	int 		save_errno;
+	rlim_t		size;
+
+	if (0 != getrlimit(RLIMIT_DATA, &rl))
+	{
+		save_errno = errno;
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(8) ERR_SYSCALL, 5, RTS_ERROR_LITERAL(ERRSTR), CALLFROM, save_errno);
+	}
+	/* if rlim_cur is unlimited(-1) it's also larger than MAXPOSINT4 */
+	size = (MAXPOSINT4 < rl.rlim_cur) ? MAXPOSINT4 : rl.rlim_cur;
+	return size;
+}
+
 int4	getstorage(void)
 {
 	struct rlimit	rl;
 	int 		save_errno;
-	UINTPTR_T	cur_sbrk;
-	rlim_t		size;
+	rlim_t		cur_sbrk, size;
 
-	if (0 != getrlimit(RLIMIT_DATA,&rl))
+	if (0 != getrlimit(RLIMIT_DATA, &rl))
 	{
 		save_errno = errno;
 		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(8) ERR_SYSCALL, 5, RTS_ERROR_LITERAL(ERRSTR), CALLFROM, save_errno);
 	}
 #if !defined(__MVS__)
-	cur_sbrk = (UINTPTR_T)sbrk(0); /* Two step conversion to eliminate warnings */
+	/* Two step conversion to eliminate warnings */
+	cur_sbrk = (rlim_t)sbrk(0);
+	if ((-1 == cur_sbrk) && (ENOMEM == errno))
+	{	/* sbrk() returns -1 and sets errno to ENOMEM */
+		save_errno = errno;
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(8) ERR_SYSCALL, 5, RTS_ERROR_LITERAL(ERRSTR), CALLFROM, save_errno);
+	}
 #else
 	cur_sbrk = 0;			/* smw until something better */
 #endif
@@ -45,7 +66,10 @@ int4	getstorage(void)
 	if (MAXPOSINT4 < size)
 		size = MAXPOSINT4;
 	else if (0 > size)
+	{
+		assert(FALSE);
 		size = 0;
+	}
 /* Temporarily, all platform return a diminished potential storage value until stack alignment issues on x86_64
  * are fixed allowing floats again or a better fix is made.
  *
