@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2011, 2014 Fidelity Information Services, Inc	*
+ * Copyright (c) 2011-2020 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -23,7 +24,8 @@
 
 GBLREF uint4            process_id;
 #ifdef DEBUG
-GBLREF  sgmnt_addrs     * cs_addrs;
+GBLREF	gd_region	*gv_cur_region;
+GBLREF  sgmnt_addrs     *cs_addrs;
 #endif
 int try_semop_get_c_stack(int semid, struct sembuf sops[], int nsops)
 {
@@ -31,13 +33,13 @@ int try_semop_get_c_stack(int semid, struct sembuf sops[], int nsops)
 	int                     semop_pid, save_errno;
 	int                     last_sem_trace, rc;
 #	ifdef DEBUG
-	node_local_ptr_t        cnl;
+	node_local_ptr_t        cnl = NULL;
 #	endif
 	DCL_THREADGBL_ACCESS;
 
 	SETUP_THREADGBL_ACCESS;
 #	ifdef DEBUG
-	if (NULL != cs_addrs)
+	if ((NULL != gv_cur_region) && gv_cur_region->open && (NULL != cs_addrs))
 		cnl = cs_addrs->nl;
 #	endif
 	stuckcnt = 0;
@@ -47,45 +49,46 @@ int try_semop_get_c_stack(int semid, struct sembuf sops[], int nsops)
 	TREF(semwait2long) = TRUE;
 	do
 	{
-		/* If we are entering the loop for the first time or there was an interrupt and that 	*/
-		/* was due to the timer pop (which sets semop2long), restart the timer			*/
 		if (TREF(semwait2long))
-		{
+		{	/* 1st time or semwait2long timer pop mean we need to (re)start timer */
 			TREF(semwait2long) = FALSE;
 			start_timer((TID)semwt2long_handler,(int4)MAX_SEM_WAIT_TIME, semwt2long_handler, 0, NULL);
 		}
 		rc = semop(semid, sops, nsops);
 		if (-1 == rc)
-		{
+		{	/* didn't work */
 			save_errno = errno;
-			/* Timer popped, get C-stack trace */
 			if ((EINTR == save_errno) && TREF(semwait2long))
-			{
+			{	/* semwait2long timer popped, get C-stack trace */
 				stuckcnt++;
 				last_sem_trace = -1;
 				for (loopcount = 0; loopcount < nsops; loopcount++)
-				{
+				{	/* for does 1 pass of each semop in set */
 					if ((last_sem_trace != sops[loopcount].sem_num) && (0 == sops[loopcount].sem_op))
 					{	/* Do not take trace of the same process again, in a point of time */
 						last_sem_trace = sops[loopcount].sem_num;
 						semop_pid = semctl(semid, sops[loopcount].sem_num, GETPID);
-						if ((-1 != semop_pid) && (semop_pid != process_id))
-						{
-							GET_C_STACK_FROM_SCRIPT("SEMOP_INFO", process_id, semop_pid, stuckcnt);
-							/* Got stack trace signal the first process to continue */
-							GTM_WHITE_BOX_TEST(WBTEST_SEMTOOLONG_STACK_TRACE,
-								cnl->wbox_test_seq_num, 3);
-						} else if (-1 == semop_pid)
-						{
-							rc = -1;
+						if (-1 == semop_pid)
+						{	/* no owner to trace leave the for loop with the errno from semctl */
 							save_errno = errno;
+							rc = -1;
 							break;
 						}
+						if (semop_pid != process_id)
+						{	/* not good to try tracing own process */
+							GET_C_STACK_FROM_SCRIPT("SEMOP_INFO", process_id, semop_pid, stuckcnt);
+							/* Got stack trace signal the first process to continue */
+#							ifdef DEBUG
+							if (cnl)
+								GTM_WHITE_BOX_TEST(WBTEST_SEMTOOLONG_STACK_TRACE,
+									cnl->wbox_test_seq_num, 3);
+#							endif
+						}
 					}
-				}
-			}
-		}
-	} while ((-1 == rc) && (EINTR == save_errno));
+				}	/* for */
+			}	/* our timer pop */
+		}	/* error return from semop */
+	} while ((-1 == rc) && (EINTR == save_errno));	/* keep trying as long as error is an EINTR */
 	cancel_timer((TID)semwt2long_handler);
 	return (-1 == rc) ? save_errno : 0;
 }
