@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2006-2021 Fidelity National Information	*
+ * Copyright (c) 2006-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -53,8 +53,7 @@ ZOS_ONLY(GBLREF	char	*gtm_utf8_locale_object;)
 GBLREF boolean_t		gtm_dist_ok_to_use;
 GBLREF char			gtm_dist[GTM_PATH_MAX];
 GBLREF	volatile boolean_t	timer_in_handler;
-
-typedef void (*icu_func_t)();	/* a generic pointer type to the ICU function */
+GBLREF mstr			dollar_zicuver;
 
 /* For now the minimum ICU version supported is 3.6 */
 #define	ICU_MINIMUM_SUPPORTED_VER	"3.6"
@@ -85,6 +84,8 @@ typedef void (*icu_func_t)();	/* a generic pointer type to the ICU function */
  */
 typedef uint8_t UVersionInfo[MAX_ICU_VERSION_LENGTH];
 
+typedef void (*icu_func_t)(UVersionInfo);	/* a generic pointer type to the ICU function */
+
 /* The first parameter to ICUVERLT36 can be either ICU_LIBNAME or $gtm_icu_version. Depending on the choice
  * of the first parameter, different suffix is chosen.
  */
@@ -122,10 +123,9 @@ NULL
 #undef ICU_DEF
 
 /* duplicated prototypes needed to avoid including header file gtm_icu_api.h */
-void gtm_icu_init(void);
+boolean_t gtm_icu_init(boolean_t called_by_zconvert);
 void gtm_conv_init(void);
 
-
 error_def(ERR_DLLNOOPEN);
 error_def(ERR_ICUSYMNOTFOUND);
 error_def(ERR_ICUVERLT36);
@@ -205,7 +205,7 @@ static boolean_t parse_gtm_icu_version(char *icu_ver_buf, int len, char *icusymv
 	return TRUE;
 }
 
-void gtm_icu_init(void)
+boolean_t gtm_icu_init(boolean_t called_by_zconvert)
 {
 	char		*locale, *chset, *libname, err_msg[MAX_ERRSTR_LEN];
 	char		icu_final_fname[MAX_ICU_FNAME_LEN + 1 + MAX_ICU_VERSION_STRLEN];	/* 1 for '_' in between */
@@ -219,7 +219,7 @@ void gtm_icu_init(void)
 	char_ptr_t	err_str;
 	icu_func_t	fptr;
 	int		findx, ver;
-	boolean_t	icu_getversion_found = FALSE, gtm_icu_ver_defined, symbols_renamed;
+	boolean_t	icu_getversion_found = FALSE, gtm_icu_ver_defined, symbols_renamed = -1;
 	UVersionInfo	icu_version;
 	mstr		icu_ver, trans;
 	int		iculdflags = ICU_LIBFLAGS;
@@ -228,13 +228,15 @@ void gtm_icu_init(void)
 	char		*pieceptr, *cptr;
 #	ifdef _AIX
 	int		buflen, prev_dyn_size;
-	char            buf[ICU_LIBNAME_LEN], temp_path[GTM_PATH_MAX], search_paths[MAX_SEARCH_PATH_LEN];
+	char		buf[ICU_LIBNAME_LEN], temp_path[GTM_PATH_MAX], search_paths[MAX_SEARCH_PATH_LEN];
 	char		*ptr, *each_libpath, *dyn_search_paths = NULL, *search_path_ptr;
 	struct stat	real_path_stat;		/* To see if the resolved real_path exists or not */
 #	endif
 	intrpt_state_t  prev_intrpt_state;
 
 	assert(!gtm_utf8_mode);
+	dollar_zicuver.addr = (char *) malloc(MAX_ICU_VERSION_STRLEN);
+	memset(dollar_zicuver.addr, 0, MAX_ICU_VERSION_STRLEN);
 #	ifdef __MVS__
 	if (gtm_utf8_locale_object)
 		locale = setlocale(LC_CTYPE, gtm_utf8_locale_object);
@@ -249,7 +251,7 @@ void gtm_icu_init(void)
 	chset = nl_langinfo(CODESET);
 	if (NULL == chset)	/* 4SCA : null return nl_langinfo not possible */
 		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(4) ERR_NONUTF8LOCALE, 2, LEN_AND_LIT("<undefined>"));
-	if ((NULL == locale) || (0 != strcasecmp(chset, "utf-8")) && (0 != strcasecmp(chset, "utf8")))
+	if ((NULL == locale) || ((0 != strcasecmp(chset, "utf-8")) && (0 != strcasecmp(chset, "utf8"))))
 		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(4) ERR_NONUTF8LOCALE, 2, LEN_AND_STR(chset));
 	/* By default, GT.M will henceforth expect that ICU has been built with symbol renaming disabled. If that is not the case,
 	 * GT.M can be notified of this through an environment variable (macro GTM_ICU_VERSION).  The variable should contain the
@@ -437,7 +439,6 @@ void gtm_icu_init(void)
 		}
 #		endif
 	}
-	DEBUG_ONLY(symbols_renamed = -1;)
 	for (findx = 0; findx < icu_func_n; ++findx)
 	{
 		cur_icu_fname = icu_fname[findx];
@@ -473,6 +474,8 @@ void gtm_icu_init(void)
 			}
 			if (NULL == fptr)
 			{
+				if (called_by_zconvert)
+					return FALSE;
 				COPY_DLLERR_MSG(err_str, err_msg);
 				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(8) ERR_ICUSYMNOTFOUND, 2, LEN_AND_STR(cur_icu_fname),
 					ERR_TEXT, 2, LEN_AND_STR(err_msg));
@@ -491,12 +494,12 @@ void gtm_icu_init(void)
 		 * an appropriate value in the environment then the version check would have happened before and there isn't any
 		 * need to repeat it again.
 		 */
-		if (!gtm_icu_ver_defined && (FALSE == icu_getversion_found) && (0 == strcmp(cur_icu_fname, GET_ICU_VERSION_FNAME)))
+		if (!icu_getversion_found && (0 == strcmp(cur_icu_fname, GET_ICU_VERSION_FNAME)))
 		{
 			icu_getversion_found = TRUE;
 			memset(icu_version, 0, MAX_ICU_VERSION_LENGTH);
 			fptr(icu_version);
-			if (!(IS_ICU_VER_GREATER_THAN_MIN_VER(icu_version[0], icu_version[1])))
+			if (!gtm_icu_ver_defined && !(IS_ICU_VER_GREATER_THAN_MIN_VER(icu_version[0], icu_version[1])))
 			{
 				/* Construct the first part of the ICUVERLT36 error message. */
 				SNPRINTF(tmp_errstr, SIZEOF(ICU_LIBNAME) + STR_LIT_LEN(ICU_LIBNAME_SUFFIX), "%s%s", ICU_LIBNAME,
@@ -504,10 +507,15 @@ void gtm_icu_init(void)
 				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_ICUVERLT36, 4,
 					LEN_AND_STR(tmp_errstr), icu_version[0], icu_version[1]);
 			}
+			dollar_zicuver.len = SNPRINTF(dollar_zicuver.addr, MAX_ICU_VERSION_STRLEN, "%hu.%hu",
+				icu_version[0], icu_version[1]);
+			if (MAX_ICU_VERSION_STRLEN <= dollar_zicuver.len)
+				dollar_zicuver.len = MAX_ICU_VERSION_STRLEN - 1;
 		}
 	}
 	ENABLE_INTERRUPTS(INTRPT_IN_FUNC_WITH_MALLOC, prev_intrpt_state);
 	gtm_utf8_mode = TRUE;
 	/* gtm_wcswidth()/U_ISPRINT() in util_format() can henceforth be safely called now that ICU initialization is complete */
 	gtm_conv_init();
+	return TRUE;
 }
