@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Copyright (c) 2001-2021 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -50,6 +50,7 @@
 #include "gtm_post_startup_check_init.h"
 
 GBLREF	char		gtm_dist[GTM_PATH_MAX];
+GBLREF	unsigned int	gtm_dist_len;
 GBLREF	boolean_t	gtm_dist_ok_to_use;
 LITREF	gtmImageName	gtmImageNames[];
 GBLREF	uint4		process_id;
@@ -70,37 +71,41 @@ int gtm_chk_dist(char *image)
 	char		*exename;
 	int		exename_len;
 	int		path_len;
-	int		gtm_dist_len;
 	boolean_t	status;
 	boolean_t	is_gtcm_image;
 	char		image_real_path[GTM_PATH_MAX];
 	char		real_gtm_dist_path[GTM_PATH_MAX];
 	char		comparison[GTM_PATH_MAX];
+	unsigned int	real_dist_len;
 
 	is_gtcm_image = (IS_GTCM_GNP_SERVER_IMAGE || IS_GTCM_SERVER_IMAGE); /* GT.CM servers defer issuing errors until startup */
 	/* Use the real path while checking the path length. If not valid, let it fail when checking is_file_identical  */
 	real_dist = realpath(gtm_dist, real_gtm_dist_path);
 	if (real_dist)
 	{
-		STRNLEN(real_dist, GTM_PATH_MAX, gtm_dist_len);
+		STRNLEN(real_dist, GTM_PATH_MAX, real_dist_len);
 	} else
 	{
-		STRNLEN(gtm_dist, GTM_PATH_MAX, gtm_dist_len);
+#		ifdef DEBUG
+		STRNLEN(gtm_dist, GTM_PATH_MAX, real_dist_len);	/* Set real_dist_len */
+		assert(real_dist_len == gtm_dist_len);
+#		endif
+		real_dist_len = gtm_dist_len;
 	}
-	if (gtm_dist_len)
+	if (real_dist_len)
 	{
 		assert(IS_VALID_IMAGE && (n_image_types > image_type));	/* assert image_type is initialized */
-		if (GTM_DIST_PATH_MAX <= gtm_dist_len)
+		if (GTM_DIST_PATH_MAX <= real_dist_len)
 		{
 			if (is_gtcm_image)
 				return 0;
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(3) ERR_DISTPATHMAX, 1, GTM_DIST_PATH_MAX);
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(3) ERR_DISTPATHMAX, 1, GTM_DIST_PATH_MAX);
 		}
 	} else
 	{
 		if (is_gtcm_image)
 			return 0;
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_GTMDISTUNDEF);
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_GTMDISTUNDEF);
 	}
 
 	/* Get the executable name and length */
@@ -130,11 +135,11 @@ int gtm_chk_dist(char *image)
 	{
 		if (is_gtcm_image)
 			return 0;
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(6) ERR_GTMDISTUNVERIF, 4, LEN_AND_STR(gtm_dist), LEN_AND_STR(image));
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_GTMDISTUNVERIF, 4, LEN_AND_STR(gtm_dist), LEN_AND_STR(image));
 	}
 
 	if (IS_GTM_IMAGE && memcmp(exename, GTM_IMAGE_NAME, GTM_IMAGE_NAMELEN))
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(6) ERR_IMAGENAME, 4, LEN_AND_LIT(GTM_IMAGE_NAME), LEN_AND_STR(exename));
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_IMAGENAME, 4, LEN_AND_LIT(GTM_IMAGE_NAME), LEN_AND_STR(exename));
 	gtm_post_startup_check_init();
 	return 0;
 }
