@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2007-2020 Fidelity National Information	*
+ * Copyright (c) 2007-2022 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -42,11 +42,12 @@
 #include "gtmdbglvl.h"
 #include "gtmio.h"
 #include "have_crit.h"
+#include "deferred_events_queue.h"
+#include "deferred_events.h"
 
 GBLREF  int		process_exiting;		/* Process is on it's way out */
-GBLREF	volatile int4	fast_lock_count;		/* Stop stale/epoch processing while we have our parts exposed */
 GBLREF	uint4		gtmDebugLevel;
-GBLREF	size_t		gtm_max_storalloc;		/* Max value for $ZREALSTOR or else memory error is raised */
+GBLREF	volatile int4	fast_lock_count;		/* Stop stale/epoch processing while we have our parts exposed */
 
 OS_PAGE_SIZE_DECLARE
 
@@ -65,10 +66,16 @@ OS_PAGE_SIZE_DECLARE
 #define MAXINDEX 5
 
 /* Fields to help instrument our algorithm */
+GBLREF	boolean_t	gtmSystemMalloc;		/* Use the system's malloc() instead of our own */
+GBLREF	boolean_t	malloccrit_issued;		/* set at time of MALLOCCRIT */
+GBLREF	int		gtmMallocErrorErrno;		/* Errno at point of last failure */
+GBLREF	size_t		gtmMallocErrorSize;		/* Size of last failed malloc */
+GBLREF	size_t		zmalloclim;			/* ISV memory warning of MALLOCCRIT in bytes */
 GBLREF	size_t		totalRmalloc;			/* Total storage allocated through malloc() */
 GBLREF  size_t    	totalRallocGta;                 /* Total storage currently (real) mmap alloc'd */
 GBLREF  size_t     	totalAllocGta;                  /* Total mmap allocated (includes allocation overhead but not free space */
 GBLREF  size_t     	totalUsedGta;                   /* Sum of "in-use" portions (totalAllocGta - overhead) */
+GBLREF	unsigned char	*gtmMallocErrorCallerid;	/* Callerid of last failed malloc */
 static	int		totalAllocs;                    /* Total alloc requests */
 static	int		totalFrees;                     /* Total free requests */
 static	size_t		rAllocMax;                      /* Maximum value of totalRallocGta */
@@ -80,6 +87,7 @@ static	int		freeElemCnt[MAXINDEX + 2];      /* Current count of elements on the
 static	int		freeElemMax[MAXINDEX + 2];      /* Maximum number of blocks on the free queue */
 
 error_def(ERR_INVDBGLVL);
+error_def(ERR_MALLOCCRIT);
 error_def(ERR_MEMORY);
 error_def(ERR_MEMORYRECURSIVE);
 error_def(ERR_SYSCALL);
@@ -161,7 +169,7 @@ void *gtm_text_alloc(size_t size)
         if (ENOMEM == save_errno)
 	{
 		assert(FALSE);
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(5) ERR_MEMORY, 2, tSize, CALLERID, save_errno);
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(5) ERR_MEMORY, 2, tSize, CALLERID, save_errno);
 	}
 	/* On non-allocate related error, give more general error and assertpro(FALSE) */
 	gtm_putmsg_csa(CSA_ARG(NULL) VARLSTCNT(14) ERR_SYSCALL, 5, LEN_AND_LIT("gtm_text_alloc()"), CALLFROM,
@@ -193,46 +201,55 @@ void gtm_text_free(void *addr)
 /* ******* Normal mmap() expansion ******* */
 
 /* These routines for Unix are NOT thread or interrupt safe */
-#  define TEXT_ALLOC(rsize, addr)										\
-{														\
-	int	save_errno;											\
-	if ((0 < gtm_max_storalloc) && ((rsize + totalRmalloc + totalRallocGta) > gtm_max_storalloc))		\
-	{	/* Boundary check for $gtm_max_storalloc (if set) */						\
-		--gtaSmDepth;											\
-		--fast_lock_count;										\
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(5) ERR_MEMORY, 2, rsize, CALLERID, ERR_MALLOCMAXUNIX);	\
-	}													\
- 	addr = mmap(NULL, rsize, (PROT_READ + PROT_WRITE + PROT_EXEC), (MAP_PRIVATE + MAP_ANONYMOUS), -1, 0);	\
-	if (MAP_FAILED == addr)											\
+#  define TEXT_ALLOC(SIZE, ADDR)										\
+MBSTART {													\
+	int	SAVE_ERRNO;											\
+														\
+	ADDR = mmap(NULL, SIZE, (PROT_READ + PROT_WRITE + PROT_EXEC), (MAP_PRIVATE + MAP_ANONYMOUS), -1, 0);	\
+	if (MAP_FAILED == ADDR)											\
 	{													\
 		--gtaSmDepth;											\
                 --fast_lock_count;										\
-		save_errno = errno;										\
-	        if (ENOMEM == save_errno)									\
+		SAVE_ERRNO = errno;										\
+	        if (ENOMEM == SAVE_ERRNO)									\
 		{												\
 			assert(WBTEST_ENABLED(WBTEST_SKIP_CORE_FOR_MEMORY_ERROR));				\
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(5) ERR_MEMORY, 2, rsize, CALLERID, save_errno);  	\
+			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(5) ERR_MEMORY, 2, SIZE, CALLERID, SAVE_ERRNO);	\
 		}												\
-		/* On non-allocate related error, give more general error and assertpro(FALSE) */			\
+		/* On non-allocate related error, give more general error and assertpro(FALSE) */		\
 		gtm_putmsg_csa(CSA_ARG(NULL) VARLSTCNT(14) ERR_SYSCALL, 5, LEN_AND_LIT("mmap()"), CALLFROM,	\
-			       save_errno, 0, ERR_CALLERID, 3, LEN_AND_LIT("TEXT_ALLOC"), CALLERID);		\
-		assertpro(FALSE);											\
+			       SAVE_ERRNO, 0, ERR_CALLERID, 3, LEN_AND_LIT("TEXT_ALLOC"), CALLERID);		\
+		assertpro(FALSE);										\
 	}													\
-}
-#define TEXT_FREE(addr, rsize) 											\
-{														\
-	int	rc, save_errno;											\
-	rc = munmap(addr, rsize);										\
-	if (-1 == rc)												\
+	if (!gtmSystemMalloc && !malloccrit_issued /* totalRmalloc* not available for system malloc */		\
+		&& (0 < zmalloclim) && ((SIZE + totalRmalloc + totalRallocGta) > zmalloclim))			\
+	{	/* Boundary check on zmalloclim */								\
+		gtmMallocErrorSize = SIZE;									\
+		gtmMallocErrorCallerid = CALLERID;								\
+		gtmMallocErrorErrno = ERR_MALLOCCRIT;								\
+		/* doubling here and halving in gtm_env_init accomodate the fact that 				\
+		 * stringpool expansions are large, and if occurring, not easy to gracefully			\
+		 * continue from, which is also related to deferring the MALLOCCRIT error			\
+		 */												\
+		assertpro(!IS_GTMSECSHR_IMAGE);									\
+		malloccrit_issued = TRUE;									\
+		(*xfer_set_handlers_fnptr)(defer_error, ERR_MALLOCCRIT, FALSE);					\
+	}													\
+} MBEND
+#define TEXT_FREE(ADDR, RSIZE) 											\
+MBSTART {													\
+	int	RC, SAVE_ERRNO;											\
+	RC = munmap(ADDR, RSIZE);										\
+	if (-1 == RC)												\
 	{													\
 		--gtaSmDepth;											\
                 --fast_lock_count;										\
-		save_errno = errno;										\
+		SAVE_ERRNO = errno;										\
 		gtm_putmsg_csa(CSA_ARG(NULL) VARLSTCNT(14) ERR_SYSCALL, 5, LEN_AND_LIT("munmap"), CALLFROM,	\
-			       save_errno, 0, ERR_CALLERID, 3, LEN_AND_LIT("TEXT_FREE"), CALLERID);		\
-		assertpro(FALSE);											\
+			       SAVE_ERRNO, 0, ERR_CALLERID, 3, LEN_AND_LIT("TEXT_FREE"), CALLERID);		\
+		assertpro(FALSE);										\
 	}													\
-}
+} MBEND
 #define STE_FP(p) p->userStorage.links.fPtr
 #define STE_BP(p) p->userStorage.links.bPtr
 
@@ -336,7 +353,7 @@ void gtaSmInit(void)
 	{
 		assert(0 < twoSize);
 		TwoTable[sizeIndex] = twoSize;
-		assert(TwoTable[sizeIndex] < TwoTable[sizeIndex + 1]);
+		assert((MAXINDEX == sizeIndex) || (TwoTable[sizeIndex] < TwoTable[sizeIndex + 1]));
 	}
 	/* Need to initialize the fwd/bck ptrs in the anchors to point to themselves */
 	for (uStor = &freeStorElemQs[0], i = 0; i <= MAXINDEX; ++i, ++uStor)
@@ -445,7 +462,7 @@ void *gtm_text_alloc(size_t size)
 		{
 			--gtaSmDepth;
 			assert(FALSE);
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_MEMORYRECURSIVE);
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_MEMORYRECURSIVE);
 		}
 		INCR_CNTR(totalAllocs);
 		if (0 != size)
@@ -504,7 +521,7 @@ void gtm_text_free(void *addr)
 	{
 		--gtaSmDepth;
 		assert(FALSE);
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_MEMORYRECURSIVE);
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_MEMORYRECURSIVE);
 	}
 	INCR_CNTR(totalFrees);
 	if ((unsigned char *)addr != &NullStruct.nullStr[0])
@@ -567,6 +584,7 @@ void gtm_text_free(void *addr)
  */
 void printAllocInfo(void)
 {
+#ifndef STATIC_ANALYSIS
         textElem        *eHdr, *uStor;
         int             i;
 
@@ -585,10 +603,15 @@ void printAllocInfo(void)
 	{
 		for (i = 0; i <= MAXINDEX + 1; ++i)
 		{
+			assert((ARRAYSIZE(TwoTable) > i) && (ARRAYSIZE(allocCnt) > i) &&
+				(ARRAYSIZE(freeCnt) > i)  && (ARRAYSIZE(elemSplits) > i) &&
+				(ARRAYSIZE(elemCombines) > i) && (ARRAYSIZE(freeElemCnt) > i) &&
+				(ARRAYSIZE(freeElemMax) > i)); /* For SCI */
 			FPRINTF(stderr,
 				"%9d %9d %9d %9d %9d %9d %9d\n", TwoTable[i], allocCnt[i], freeCnt[i],
 				elemSplits[i], elemCombines[i], freeElemCnt[i], freeElemMax[i]);
 		}
 	}
+#endif
 }
 #endif /* COMP_GTA */
