@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2006-2022 Fidelity National Information	*
+ * Copyright (c) 2006-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -174,7 +174,7 @@
  * (including 1-byte and 2-byte codepoints).
  */
 #define	UTF8_NONCHAR_CODEPOINT(codepoint)							\
-	(((unsigned)(codepoint) <= UTF8_3BYTE_MAX) && (UTF8_NONCHAR_CODE_3BYTE(codepoint))	\
+	((((unsigned)(codepoint) <= UTF8_3BYTE_MAX) && (UTF8_NONCHAR_CODE_3BYTE(codepoint)))	\
 		||  UTF8_NONCHAR_CODE_4BYTE(codepoint))
 
 /* boolean_t UTF8_NONCHAR_3BYTE(char* mbptr)
@@ -822,7 +822,7 @@ int	trim_U16_line_term(UChar *buffer, int len);
 		? FALSE													\
 		: u_isprint(code))
 
-static void inline copy_character(uint4 copy_length, sm_uc_ptr_t dstptr, char *rcur)
+static inline void copy_character(uint4 copy_length, sm_uc_ptr_t dstptr, char *rcur)
 {
         switch (copy_length)
         {       /* Rather than calling memcpy, do this dance so we can save some instructions */
@@ -877,4 +877,16 @@ typedef	int	(*gtm_wcswidth_fnptr_t)(unsigned char* ptr, int len, boolean_t stric
 
 GBLREF	gtm_wcswidth_fnptr_t	gtm_wcswidth_fnptr;	/* see comment above about this typedef */
 
+#ifdef UTF8_SUPPORTED
+static inline unsigned int MV_FORCE_LEN(mval *v)
+{
+	if (!(v->mvtype & MV_UTF_LEN))
+	{
+		utf8_len(&v->str);
+		v->mvtype |= MV_UTF_LEN;
+	}
+	return v->str.char_len;
+}
+#endif
+
 #endif /* GTM_UTF8_H */
