@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2008-2021 Fidelity National Information	*
+ * Copyright (c) 2008-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -119,7 +119,7 @@ int gtmrecv_poll_actions1(int *pending_data_len, int *buff_unprocessed, unsigned
 	gtmrecv_local_ptr_t	gtmrecv_local;
 	upd_helper_ctl_ptr_t	upd_helper_ctl;
 	pid_t			waitpid_res;
-	int4			msg_type, msg_len;
+	int4			msg_type, msg_len = 0;
 	DCL_THREADGBL_ACCESS;
 
 	SETUP_THREADGBL_ACCESS;
@@ -245,7 +245,7 @@ int gtmrecv_poll_actions1(int *pending_data_len, int *buff_unprocessed, unsigned
 				; /* Empty Body */
 			if (SS_NORMAL != status)
 			{
-				if (REPL_CONN_RESET(status) && EREPL_SEND == repl_errno)
+				if (REPL_CONN_RESET(status) && (EREPL_SEND == repl_errno))
 				{
 					repl_log(gtmrecv_log_fp, TRUE, TRUE, "Connection reset while sending XOFF_ACK_ME. "
 							"Status = %d ; %s\n", status, STRERROR(status));
@@ -331,20 +331,20 @@ int gtmrecv_poll_actions1(int *pending_data_len, int *buff_unprocessed, unsigned
 		{	/* Receive the header of a message */
 			assert(REPL_MSG_HDRLEN > *buff_unprocessed);	/* so we dont pass negative length in REPL_RECV_LOOP */
 			REPL_RECV_LOOP(gtmrecv_sock_fd, ((unsigned char *)gtmrecv_msgp) + *buff_unprocessed,
-				       (REPL_MSG_HDRLEN - *buff_unprocessed), REPL_POLL_WAIT)
+					(REPL_MSG_HDRLEN - *buff_unprocessed), REPL_POLL_WAIT)
 				; /* Empty Body */
 			if (SS_NORMAL == status)
 			{
 				assert(remote_side->endianness_known);	/* only then is remote_side->cross_endian reliable */
-		        	if (!remote_side->cross_endian)
-	        		{
-			                msg_len = gtmrecv_msgp->len;
-			                msg_type = gtmrecv_msgp->type;
-			        } else
-			        {
-			                msg_len = GTM_BYTESWAP_32(gtmrecv_msgp->len);
-			                msg_type = GTM_BYTESWAP_32(gtmrecv_msgp->type);
-			        }
+				if (!remote_side->cross_endian)
+				{
+					msg_len = gtmrecv_msgp->len;
+					msg_type = gtmrecv_msgp->type;
+				} else
+				{
+					msg_len = GTM_BYTESWAP_32(gtmrecv_msgp->len);
+					msg_type = GTM_BYTESWAP_32(gtmrecv_msgp->type);
+				}
 				msg_type = (msg_type & REPL_TR_CMP_MSG_TYPE_MASK);
 				assert((REPL_TR_CMP_JNL_RECS == msg_type) || (0 == (msg_len % REPL_MSG_ALIGN)));
 				msg_len = ROUND_UP2(msg_len, REPL_MSG_ALIGN);
@@ -444,7 +444,7 @@ int gtmrecv_poll_actions1(int *pending_data_len, int *buff_unprocessed, unsigned
 				repl_log(gtmrecv_log_fp, TRUE, TRUE, "REPL_BADTRANS message sent with seqno %llu\n", send_seqno);
 		} else
 		{
-			if (REPL_CONN_RESET(status) && EREPL_SEND == repl_errno)
+			if (REPL_CONN_RESET(status) && (EREPL_SEND == repl_errno))
 			{
 				if (send_cmp2uncmp)
 				{
@@ -480,7 +480,7 @@ int gtmrecv_poll_actions1(int *pending_data_len, int *buff_unprocessed, unsigned
 		}
 	}
 	if ((upd_proc_local->bad_trans && bad_trans_detected) || onln_rlbk_flg_set
-		|| (UPDPROC_START == upd_proc_local->start_upd) && (1 != report_cnt))
+		|| ((UPDPROC_START == upd_proc_local->start_upd) && (1 != report_cnt)))
 	{
 		if (UPDPROC_START == upd_proc_local->start_upd)
 		{
