@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -46,7 +46,7 @@
 #include "gtm_unistd.h"
 #include "gtm_stdio.h"
 #include "gtm_permissions.h"
-#include "gtm_select.h"
+#include "gtm_poll.h"
 
 #if defined(__MVS__)
 # include "gtm_zos_io.h"
@@ -90,6 +90,7 @@
 # include "gtm_utf8.h"
 #endif
 #include "getjobnum.h"
+#include "wbox_test_init.h"
 
 #define execname 	"gtmsecshr"	/* this is what this executable is supposed to be called. A different name is verboten */
 #define intent_open	"for open"	/* FLUSH_DB_IPCS_INFO types */
@@ -219,10 +220,11 @@ int main(int argc, char_ptr_t argv[])
 	TID			timer_id;
 	GTM_SOCKLEN_TYPE	client_addr_len;
 	char			*recv_ptr, *send_ptr, *rundir;
-	fd_set			wait_on_fd;
 	struct sockaddr_un	client_addr;
-	struct timeval		input_timeval;
 	gtmsecshr_mesg		mesg;
+	int			poll_timeout;
+	nfds_t			poll_nfds;
+	struct pollfd		poll_fdlist[1];
 	DCL_THREADGBL_ACCESS;
 
 	GTM_THREADGBL_INIT;
@@ -233,15 +235,14 @@ int main(int argc, char_ptr_t argv[])
 	timer_id = (TID)main;
 	while (TRUE)
 	{
-		input_timeval.tv_sec = MAX_TIMEOUT_VALUE;	/* Restart timeout each interation for platforms that save
-								 * unexpired time when select exits.
-								 */
-		input_timeval.tv_usec = 0;
-		assertpro(FD_SETSIZE > gtmsecshr_sockfd);
-		FD_ZERO(&wait_on_fd);
-		FD_SET(gtmsecshr_sockfd, &wait_on_fd);
 		gtmsecshr_timer_popped = FALSE;
-		SELECT(gtmsecshr_sockfd + 1, (void *)&wait_on_fd, NULL, NULL, &input_timeval, selstat);
+		poll_fdlist[0].fd = gtmsecshr_sockfd;
+		poll_fdlist[0].events = POLLIN;
+		poll_nfds = 1;
+		poll_timeout = MAX_TIMEOUT_VALUE * MILLISECS_IN_SEC; 	/* Restart timeout each interation for platforms that save
+									 * unexpired time when select exits.
+									 */
+		selstat = poll(&poll_fdlist[0], poll_nfds, poll_timeout);
 		if (0 > selstat)
 			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_GTMSECSHR, 1, process_id, ERR_GTMSECSHRSCKSEL, 0, errno);
 		else if (0 == selstat)
@@ -467,6 +468,15 @@ void gtmsecshr_init(char_ptr_t argv[], char **rundir, int *rundir_len)
 			send_msg_csa(CSA_ARG(NULL) VARLSTCNT(3) ERR_GTMSECSHRSEMGET, 1, errno);
 			gtmsecshr_exit(SEMGETERROR, FALSE);
 		}
+#		ifdef DEBUG
+		/* If the whitebox case is enabled let's force an error. Not to worry, gtmsecshr_exit knows it's a test and
+		 * just return back to us, i.e., not actual exit.  We placed an assert in that function to verify that it
+		 * properly deals with the SEMGETERROR status. Note: if an additional white box case is ever needed it needs
+		 * to also be added to gtmsecshr_wrapper.c to have it passed to gtmsecshr.c.
+		 */
+		if (WBTEST_ENABLED(WBTEST_FORCE_SEMGETERROR))
+			gtmsecshr_exit(SEMGETERROR, FALSE);
+#		endif
 	}
 	sop[0].sem_num = 0;
 	sop[0].sem_op = 0;
@@ -481,7 +491,7 @@ void gtmsecshr_init(char_ptr_t argv[], char **rundir, int *rundir_len)
 			RTS_ERROR_LITERAL("Server"), process_id, ERR_TEXT, 2,
 			RTS_ERROR_LITERAL("server already running"), errno);
 		/* If gtm_tmp is not defined, show default path */
-		if (gtm_tmp_ptr = GETENV("gtm_tmp"))		/* Warning - assignment */
+		if ((gtm_tmp_ptr = GETENV("gtm_tmp")))		/* Warning - assignment */
 			send_msg_csa(CSA_ARG(NULL) VARLSTCNT(8) ERR_GTMSECSHRTMPPATH, 2,
 				RTS_ERROR_TEXT(gtm_tmp_ptr), ERR_TEXT, 2, RTS_ERROR_TEXT("(from $gtm_tmp)"));
 		else
@@ -537,20 +547,42 @@ void gtmsecshr_exit(int exit_code, boolean_t dump)
 
 	if (dump)
 		DUMP_CORE;
-	gtmsecshr_sock_cleanup(SERVER);
-	gtmsecshr_sockfd = FD_INVALID;
-	if (SEMAPHORETAKEN != exit_code)
+#	ifdef DEBUG
+	if (!WBTEST_ENABLED(WBTEST_FORCE_SEMGETERROR))
+	{
+#	endif
+		gtmsecshr_sock_cleanup(SERVER);
+		gtmsecshr_sockfd = FD_INVALID;
+#	ifdef DEBUG
+	}
+#	endif
+	/* Only remove the semaphore if we it is ours. So, if we couldn't find/create the semaphore
+	 * or we could not lock it, don't remove it
+	 */
+	if ((SEMGETERROR != exit_code) && (SEMAPHORETAKEN != exit_code))
 	{	/* remove semaphore */
+		assert(SEMGETERROR != exit_code);
 		if (-1 == (gtmsecshr_sem = semget(gtmsecshr_key, FTOK_SEM_PER_ID, RWDALL | IPC_NOWAIT)))
 		{
 			gtmsecshr_sem = INVALID_SEMID;
 			send_msg_csa(CSA_ARG(NULL) VARLSTCNT(3) ERR_GTMSECSHRGETSEMFAIL, 1, errno);
 		}
-		if (-1 == semctl(gtmsecshr_sem, 0, IPC_RMID, 0))
-			send_msg_csa(CSA_ARG(NULL) VARLSTCNT(3) ERR_GTMSECSHRREMSEMFAIL, 1, errno);
+		if (INVALID_SEMID != gtmsecshr_sem)
+			if (-1 == semctl(gtmsecshr_sem, 0, IPC_RMID, 0))
+				send_msg_csa(CSA_ARG(NULL) VARLSTCNT(3) ERR_GTMSECSHRREMSEMFAIL, 1, errno);
 	}
 	/* Note shutdown message taken care of by generic_signal_handler */
-	EXIT(exit_code);
+
+#	ifdef DEBUG
+	/* If this is us via the white box case we just proved we did not take the above assert on the SEMGETERROR exit_code
+	 * so don't actually exit - just return to continue normal processing.
+	 */
+	if (!WBTEST_ENABLED(WBTEST_FORCE_SEMGETERROR))
+#	endif
+		EXIT(exit_code);
+#	ifdef DEBUG /* we done with our test so turn off doing white box cases */
+	gtm_white_box_test_case_enabled = FALSE;
+#	endif
 }
 
 void gtmsecshr_timer_handler(void)
