@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2008-2018 Fidelity National Information	*
+ * Copyright (c) 2008-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -59,6 +59,8 @@
 #define ASCIICTLMIN	0   /* NULL character */
 #define GTM_TMP		"gtm_tmp"
 #define GTM_DIST	"gtm_dist"
+#define GTM_WHITE_BOX_TEST_CASE_ENABLE	"gtm_white_box_test_case_enable"
+#define GTM_WHITE_BOX_TEST_CASE_NUMBER	"gtm_white_box_test_case_number"
 #define	SUB_PATH_TO_GTMSECSHRDIR "/gtmsecshrdir"
 #define	REL_PATH_TO_CURDIR "."
 #define	REL_PATH_TO_GTMSECSHR "./gtmsecshr"
@@ -73,8 +75,6 @@
 #define GTM_TZ				"TZ"
 #define TZLOCATOR			"TZ="
 #define NEWLINE				0x0a
-#define GTM_WHITE_BOX_TEST_CASE_ENABLE	"gtm_white_box_test_case_enable"
-#define GTM_WHITE_BOX_TEST_CASE_NUMBER	"gtm_white_box_test_case_number"
 #define GTMETCDIRPATH			"/etc"
 #define BADGTMETCDIRPATH		"/bogusdirnotetc"
 #define GTMENVIRONFILE			"environment"
@@ -148,20 +148,37 @@ SECSHRWRITABLE		<!AD writable. gtmsecshr will not be started>/error/fao=2!/ansi=
 */
 
 void strsanitize(char *src, char *dst);
+/**
+ * @brief Sanitize a file path for display purposes
+ *
+ * In practice, this is used only from this source file and to remove spaces & control characters
+ * from paths involving gtmsecshr.
+ *
+ * SCA complains if we copy the input directly to the output, even if we consider each byte.
+ * Using a translation table gets around that, and gives us some flexibility to add other
+ * mappings later if needed.  Currently the table is built on each call.  This could be
+ * changed, but doesn't seem worthwhile given the infrequent use of this function.
+ *
+ * @param src The input path buffer to be 'sanitized'.  Must be a null terminated C string.
+ * @param dst The output path buffer with the 'sanitized' path.  Must be as large as src
+ * @return None
+ *
+ */
 void strsanitize(char *src, char *dst)
 {
 	int i, srclen;
+	unsigned char trans_tab[256];
+
+	/* Our translation table is largely an identity table except for spaces and control chars */
+	for(i = 0; i < 256; i++)
+	{
+		trans_tab[i] = ((ASCIICTLMAX > i) && (ASCIICTLMIN < i)) ? '*' : i;
+	}
 
 	/* The calling function already validates the string length. */
 	srclen = strlen(src);
 	for (i = 0; (i <= srclen) && (MAX_ENV_VAR_VAL_LEN > i); i++)
-	{
-		/* Convert all control characters to '*'. */
-		if ((ASCIICTLMAX > (int)src[i]) && (ASCIICTLMIN < (int)src[i]))
-			dst[i] = '*';
-		else
-			dst[i] = src[i];
-	}
+                dst[i] = trans_tab[(unsigned char)src[i]];
 }
 
 int main()
@@ -178,6 +195,9 @@ int main()
 	char 		gtm_secshr_path_display[MAX_ENV_VAR_VAL_LEN];
 	char 		gtm_secshr_orig_path[MAX_ENV_VAR_VAL_LEN];
 	boolean_t	gtm_tmp_exists = FALSE;
+	boolean_t	gtm_white_box_test_case_pass_envvars = FALSE;
+	char 		gtm_white_box_test_case_enable_val[MAX_ENV_VAR_VAL_LEN];
+	char 		gtm_white_box_test_case_number_val[MAX_ENV_VAR_VAL_LEN];
 	int		rc;
 	sigset_t	mask;
 #	ifdef _AIX
@@ -305,7 +325,7 @@ int main()
 #	endif /* _AIX */
 	ret = 0; /* start positive */
 	/* get the ones we need */
-	if (env_var_ptr = getenv(GTM_DIST))		/* Warning - assignment */
+	if ((env_var_ptr = getenv(GTM_DIST)))		/* Warning - assignment */
 	{
 		if (MAX_ALLOWABLE_LEN <
 				(strlen(env_var_ptr) + STR_LIT_LEN(SUB_PATH_TO_GTMSECSHRDIR) + STR_LIT_LEN(GTMSECSHR_BASENAME)))
@@ -330,7 +350,7 @@ int main()
 		SYSLOG(LOG_USER | LOG_INFO, ERR_SECSHRNOGTMDIST);
 		ret = -1;
 	}
-	if (env_var_ptr = getenv(GTM_TMP))		/* Warning - assignment */
+	if ((env_var_ptr = getenv(GTM_TMP)))		/* Warning - assignment */
 	{
 		if (MAX_ALLOWABLE_LEN < strlen(env_var_ptr))
 		{
@@ -342,6 +362,28 @@ int main()
 			strcpy(gtm_tmp_val, env_var_ptr);
 		}
 	}
+#	ifdef DEBUG
+	/* Normally, all non-essential environment variables are cleared before calling the real
+	 * GTMSECSHR executable. For a very specific white box case, WBTEST_FORCE_SEMGETERROR,
+	 * the two environment variables used for the white box case are passed. This is only done
+	 * in debug and they are length checked. If another white box case is ever needed by GTMSECSHR
+	 * it needs to be added here and in gtmsecshr.c.
+	 */
+	if ((env_var_ptr = getenv(GTM_WHITE_BOX_TEST_CASE_NUMBER)))	/* Warning - assignment */
+	{
+		if (MAX_ALLOWABLE_LEN >= strlen(env_var_ptr))
+		{
+			strcpy(gtm_white_box_test_case_number_val, env_var_ptr);
+			if (WBTEST_FORCE_SEMGETERROR == atoi(gtm_white_box_test_case_number_val))
+				if ((env_var_ptr = getenv(GTM_WHITE_BOX_TEST_CASE_ENABLE)))	/* Warning - assignment */
+					if (MAX_ALLOWABLE_LEN >= strlen(env_var_ptr))
+					{
+						gtm_white_box_test_case_pass_envvars = TRUE;
+						strcpy(gtm_white_box_test_case_enable_val, env_var_ptr);
+					}
+		}
+	}
+#	endif
 	if (!ret)
 	{	/* clear all */
 #		if defined(SUNOS) || defined(__CYGWIN__)
@@ -371,6 +413,14 @@ int main()
 				ret = -1;
 			}
 		}
+#		ifdef DEBUG
+		/* This is only for debugging with a white box case so no need to check the status */
+		if (gtm_white_box_test_case_pass_envvars)
+		{
+			setenv(GTM_WHITE_BOX_TEST_CASE_ENABLE, gtm_white_box_test_case_enable_val, TRUE);
+			setenv(GTM_WHITE_BOX_TEST_CASE_NUMBER, gtm_white_box_test_case_number_val, TRUE);
+		}
+#		endif
 #		ifdef _AIX
 		if (gtm_TZ_found DEBUG_ONLY(|| WBTEST_ENABLED(WBTEST_SECSHRWRAP_SETENVFAIL2)))
 		{
