@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ *	Copyright 2001, 2013 Fidelity Information Services, Inc	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -14,8 +14,10 @@
 #include "mdef.h"
 #include "io.h"
 
+error_def(ERR_INVMNEMCSPC);
+
 dev_dispatch_struct *io_get_fgn_driver(mstr *s)
-{	error_def(ERR_UNIMPLOP);
-	rts_error(VARLSTCNT(1) ERR_UNIMPLOP);
+{
+	rts_error_csa(CSA_ARG(NULL) VARLSTCNT(4) ERR_INVMNEMCSPC, 2, s->len, s->addr);
 	return ((dev_dispatch_struct *)NULL);
 }
