@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2008-2021 Fidelity National Information	*
+ * Copyright (c) 2008-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -149,7 +149,7 @@ int parse_pipe(char *cmd_string, char *ret_token)
 	char *token3;
 	int notfound = FALSE;
 	int ret_stat;
-	int pathsize, path_len;
+	int pathsize, path_len = -1;
 	int cmd_string_size;
 
 	path = GETENV("PATH");
@@ -238,6 +238,7 @@ int parse_pipe(char *cmd_string, char *ret_token)
 			}
 			if (NULL != path)
 			{	/* search all the directories in the $PATH if defined */
+				assert(0 <= path_len);
 				memcpy(dir_in_path, path, path_len + 1);
 				for (str3 = dir_in_path; TRUE == notfound; str3 = NULL)
 				{
@@ -296,7 +297,7 @@ short iopi_open(io_log_name *dev_name, mval *pp, int fd, mval *mspace, int4 time
 	int		p_offset = 0;
 	int		file_des_write;
 	int		file_des_read = 0;
-	int		file_des_read_stderr;
+	int		file_des_read_stderr = FD_INVALID;
 	int		param_offset = 0;
 	struct stat 	sb;
 	int 		ret_stat;
@@ -309,7 +310,7 @@ short iopi_open(io_log_name *dev_name, mval *pp, int fd, mval *mspace, int4 time
 	char 		*sparams[3] = {0, 0, 0};
 	char 		*pcommand = 0;
 	char 		*pshell = 0;
-	char 		*pshell_name;
+	char 		*pshell_name = NULL;
 	char 		*pstderr = 0;
 	char 		*sh;
 	int		independent = FALSE;
@@ -640,7 +641,10 @@ short iopi_open(io_log_name *dev_name, mval *pp, int fd, mval *mspace, int4 time
 				else
 					ret = -1;
 		} else
+		{
+			assert(pshell_name);
 			ret = EXECL(pshell, pshell_name, "-c", pcommand, (char *)NULL);
+		}
 		if (-1 == ret)
 		{
 			save_errno = errno;
@@ -789,6 +793,7 @@ short iopi_open(io_log_name *dev_name, mval *pp, int fd, mval *mspace, int4 time
 			}
 			in_d_rm->is_pipe = TRUE;
 			io_ptr->type = rm;
+			assert(FD_INVALID != file_des_read_stderr);
 			status_read = iorm_open(stderr_naml, pp, file_des_read_stderr, mspace, timeout);
 			if (TRUE == status_read)
 				(stderr_iod->pair.in)->state = dev_open;
