@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2011 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2015 Fidelity National Information 	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -16,7 +17,13 @@
 #include "io.h"
 #include "iormdef.h"
 
+/* The rm device is unbuffered, so the flush operation is a no-op. */
 void iorm_flush(io_desc *iod)
+{
+	return;
+}
+
+void iorm_cond_wteol(io_desc *iod)
 {
 	d_rm_struct	*rm_ptr;
 	unsigned int	*dollarx_ptr;
@@ -32,7 +39,6 @@ void iorm_flush(io_desc *iod)
 		dollarx_ptr = &(iod->dollar.x);
 
 	if (*dollarx_ptr && rm_ptr->lastop == RM_WRITE && !iod->dollar.za)
-		iorm_wteol(1,iod);
+		iorm_wteol(1, iod);
 	return;
 }
-
