@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2006 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2017 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -14,7 +15,7 @@
 #include "mdef.h"
 #include "io.h"
 
-int	iorm_read(mval *v, int4 timeout)
+int	iorm_read(mval *v, int4 msec_timeout)
 {
-	return iorm_readfl(v, 0, timeout); /* 0 means not fixed length */
+	return iorm_readfl(v, 0, msec_timeout); /* 0 means not fixed length */
 }
