@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2020 Fidelity National Information	*
+ * Copyright (c) 2001-2021 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -28,7 +28,7 @@
 #include "eintr_wrappers.h"
 #include "wake_alarm.h"
 #include "min_max.h"
-#include "outofband.h"
+#include "deferred_events_queue.h"
 #include "mv_stent.h"
 #include "send_msg.h"
 #include "svnames.h"
@@ -41,13 +41,14 @@
 #include "gtm_utf8.h"
 #endif
 
-GBLREF	boolean_t       dollar_zininterrupt, gtm_utf8_mode, prin_dm_io, prin_in_dev_failure, prin_out_dev_failure;
-GBLREF	io_pair		io_curr_device, io_std_device;
-GBLREF	mval		dollar_zstatus;
-GBLREF	mv_stent      	*mv_chain;
-GBLREF	spdesc		stringpool;
-GBLREF	volatile bool	out_of_time;
-GBLREF	volatile int4	outofband;
+GBLREF	boolean_t       	gtm_utf8_mode, prin_dm_io, prin_in_dev_failure, prin_out_dev_failure;
+GBLREF	io_pair			io_curr_device, io_std_device;
+GBLREF	mval			dollar_zstatus;
+GBLREF	mv_stent      		*mv_chain;
+GBLREF	spdesc			stringpool;
+GBLREF	volatile bool		out_of_time;
+GBLREF	volatile boolean_t      dollar_zininterrupt;
+GBLREF	volatile int4		outofband;
 #ifdef UTF8_SUPPORTED
 GBLREF	UConverter	*chset_desc[];
 LITREF mstr            chset_names[];
@@ -64,7 +65,7 @@ error_def(ERR_ZINTRECURSEIO);
 #define fl_copy(a, b) (a > b ? b : a)
 
 #define SETZACANCELTIMER					\
-		io_ptr->dollar.za = 9;				\
+		io_ptr->dollar.za = ZA_IO_ERR;				\
 		v->str.len = 0;					\
 		if (!rm_ptr->follow && timed && !out_of_time)	\
 			cancel_timer(timer_id);
@@ -182,7 +183,7 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 	ESTABLISH_RET_GTMIO_CH(&io_curr_device, -1, ch_set);
 	/* don't allow a read from a writeonly fifo */
 	if (((d_rm_struct *)io_ptr->dev_sp)->write_only)
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_DEVICEWRITEONLY);
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_DEVICEWRITEONLY);
 #	ifdef __MVS__
 	/* on zos if it is a fifo device then point to the pair.out for $X and $Y */
 	if (((d_rm_struct *)io_ptr->dev_sp)->fifo)
@@ -235,7 +236,7 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 			save_errno = errno;
 			SET_DOLLARDEVICE_ONECOMMA_STRERROR(io_ptr, save_errno);
 			ISSUE_NOPRINCIO_IF_NEEDED(io_ptr, FALSE, FALSE);		/* FALSE, FALSE: READ, not socket*/
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(8) ERR_SYSCALL, 5, LEN_AND_LIT("fcntl"), CALLFROM, save_errno);
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(8) ERR_SYSCALL, 5, LEN_AND_LIT("fcntl"), CALLFROM, save_errno);
 		}
 		if (flags & O_NONBLOCK)
 		{
@@ -245,7 +246,7 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 				save_errno = errno;
 				SET_DOLLARDEVICE_ONECOMMA_STRERROR(io_ptr, save_errno);
 				ISSUE_NOPRINCIO_IF_NEEDED(io_ptr, FALSE, FALSE);	/* FALSE, FALSE: READ, not socket*/
-				rts_error_csa(CSA_ARG(NULL) VARLSTCNT(8) ERR_SYSCALL, 5, LEN_AND_LIT("fcntl"), CALLFROM,
+				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(8) ERR_SYSCALL, 5, LEN_AND_LIT("fcntl"), CALLFROM,
 					save_errno);
 			}
 		}
@@ -261,8 +262,8 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 			save_errno = errno;
 			SET_DOLLARDEVICE_ONECOMMA_STRERROR(io_ptr, save_errno);
 			ISSUE_NOPRINCIO_IF_NEEDED(io_ptr, FALSE, FALSE);		/* FALSE, FALSE: READ, not socket*/
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(9) ERR_IOERROR, 7, RTS_ERROR_LITERAL("lseek"),
-				      RTS_ERROR_LITERAL("iorm_readfl()"), CALLFROM, save_errno);
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(9) ERR_IOERROR, 7, RTS_ERROR_LITERAL("lseek"),
+				RTS_ERROR_LITERAL("iorm_readfl()"), CALLFROM, save_errno);
 		} else
 			rm_ptr->file_pos = cur_position;
 		*dollary_ptr = 0;
@@ -290,8 +291,8 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 					save_errno = errno;
 					SET_DOLLARDEVICE_ONECOMMA_STRERROR(io_ptr, save_errno);
 					ISSUE_NOPRINCIO_IF_NEEDED(io_ptr, FALSE, FALSE);	/* FALSE, FALSE: READ, not socket*/
-					rts_error_csa(CSA_ARG(NULL) VARLSTCNT(8) ERR_SYSCALL, 5, RTS_ERROR_LITERAL("fstat"),
-						      CALLFROM, save_errno);
+					RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(8) ERR_SYSCALL, 5, RTS_ERROR_LITERAL("fstat"),
+						CALLFROM, save_errno);
 				}
 				assert(UTF16BE_BOM_LEN < UTF8_BOM_LEN);
 				if ((CHSET_UTF8 == io_ptr->ichset) && (statbuf.st_size >= UTF8_BOM_LEN))
@@ -307,10 +308,10 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 						save_errno = errno;
 						SET_DOLLARDEVICE_ONECOMMA_STRERROR(io_ptr, save_errno);
 						ISSUE_NOPRINCIO_IF_NEEDED(io_ptr, FALSE, FALSE); /* FALSE, FALSE: READ, not socket*/
-						rts_error_csa(CSA_ARG(NULL) VARLSTCNT(9) ERR_IOERROR, 7,
-							      RTS_ERROR_LITERAL("lseek"), RTS_ERROR_LITERAL(
-								      "Error setting file pointer to beginning of file"),
-							      CALLFROM, save_errno);
+						RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(9) ERR_IOERROR, 7,
+							RTS_ERROR_LITERAL("lseek"), RTS_ERROR_LITERAL(
+							"Error setting file pointer to beginning of file"),
+							CALLFROM, save_errno);
 					}
 					rm_ptr->bom_num_bytes = open_get_bom(io_ptr, bom_size_toread);
 					/* move back to previous file position */
@@ -319,9 +320,9 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 						save_errno = errno;
 						SET_DOLLARDEVICE_ONECOMMA_STRERROR(io_ptr, save_errno);
 						ISSUE_NOPRINCIO_IF_NEEDED(io_ptr, FALSE, FALSE); /* FALSE, FALSE: READ, not socket*/
-						rts_error_csa(CSA_ARG(NULL) VARLSTCNT(9) ERR_IOERROR, 7,
-							      RTS_ERROR_LITERAL("lseek"), RTS_ERROR_LITERAL(
-								      "Error restoring file pointer"), CALLFROM, save_errno);
+						RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(9) ERR_IOERROR, 7,
+							RTS_ERROR_LITERAL("lseek"), RTS_ERROR_LITERAL(
+							"Error restoring file pointer"), CALLFROM, save_errno);
 					}
 				}
 				rm_ptr->bom_checked = TRUE;
@@ -335,7 +336,7 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 		assertpro(pipewhich_invalid != pipeintr->who_saved);      /* Interrupt should never have an invalid save state */
 		/* check we aren't recursing on this device */
 		if (dollar_zininterrupt)
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_ZINTRECURSEIO);
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_ZINTRECURSEIO);
 		if (pipewhich_readfl != pipeintr->who_saved)
 			assertpro(FALSE);      /* ZINTRECURSEIO should have caught */
 		PIPE_DEBUG(PRINTF("piperfl: *#*#*#*#*#*#*#  Restarted interrupted read\n"); DEBUGPIPEFLUSH);
@@ -518,7 +519,7 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 				save_errno = errno;
 				SET_DOLLARDEVICE_ONECOMMA_STRERROR(io_ptr, save_errno);
 				ISSUE_NOPRINCIO_IF_NEEDED(io_ptr, FALSE, FALSE);		/* FALSE, FALSE: READ, not socket*/
-				rts_error_csa(CSA_ARG(NULL) VARLSTCNT(8) ERR_SYSCALL, 5, LEN_AND_LIT("fcntl"), CALLFROM,
+				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(8) ERR_SYSCALL, 5, LEN_AND_LIT("fcntl"), CALLFROM,
 					save_errno);
 			}
 			FCNTL3(fildes, F_SETFL, (flags | O_NONBLOCK), fcntl_res);
@@ -527,7 +528,7 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 				save_errno = errno;
 				SET_DOLLARDEVICE_ONECOMMA_STRERROR(io_ptr, save_errno);
 				ISSUE_NOPRINCIO_IF_NEEDED(io_ptr, FALSE, FALSE);	/* FALSE, FALSE: READ, not socket*/
-				rts_error_csa(CSA_ARG(NULL) VARLSTCNT(8) ERR_SYSCALL, 5, LEN_AND_LIT("fcntl"), CALLFROM,
+				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(8) ERR_SYSCALL, 5, LEN_AND_LIT("fcntl"), CALLFROM,
 					save_errno);
 			}
 			blocked_in = FALSE;
@@ -642,8 +643,8 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 											      the interrupt */
 							(TREF(pipefifo_interrupt))++;
 							REVERT_GTMIO_CH(&io_curr_device, ch_set);
-							outofband_action(FALSE);
-							assertpro(FALSE);	/* Should *never* return from outofband_action */
+							async_action(FALSE);
+							assertpro(FALSE);	/* Should *never* return from async_action */
 							return FALSE;	/* For the compiler.. */
 						}
 						continue; /* for now try and read again if eof or no input ready */
@@ -713,8 +714,8 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 					stringpool.free += tot_bytes_read;	/* Don't step on our parade in the interrupt */
 					(TREF(pipefifo_interrupt))++;
 					REVERT_GTMIO_CH(&io_curr_device, ch_set);
-					outofband_action(FALSE);
-					assertpro(FALSE);	/* Should *never* return from outofband_action */
+					async_action(FALSE);
+					assertpro(FALSE);	/* Should *never* return from async_action */
 					return FALSE;	/* For the compiler.. */
 				}
 			}
@@ -858,9 +859,8 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 								stringpool.free += bytes_count;
 								(TREF(pipefifo_interrupt))++;
 								REVERT_GTMIO_CH(&io_curr_device, ch_set);
-								outofband_action(FALSE);
-								assertpro(FALSE);	/* Should *never* return from
-										   outofband_action */
+								async_action(FALSE);
+								assertpro(FALSE);	/* Should never return from async_action */
 								return FALSE;	/* For the compiler.. */
 							}
 							continue; /* for now try and read again if eof or no input
@@ -927,8 +927,8 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 						stringpool.free += bytes_count;
 						(TREF(pipefifo_interrupt))++;
 						REVERT_GTMIO_CH(&io_curr_device, ch_set);
-						outofband_action(FALSE);
-						assertpro(FALSE);	/* Should *never* return from outofband_action */
+						async_action(FALSE);
+						assertpro(FALSE);	/* Should *never* return from async_action */
 						return FALSE;	/* For the compiler.. */
 					}
 					if (-1 == status)
@@ -1053,8 +1053,8 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 					rm_ptr->mupintr = TRUE;
 					(TREF(pipefifo_interrupt))++;
 					REVERT_GTMIO_CH(&io_curr_device, ch_set);
-					outofband_action(FALSE);
-					assertpro(FALSE);	/* Should *never* return from outofband_action */
+					async_action(FALSE);
+					assertpro(FALSE);	/* Should *never* return from async_action */
 					return FALSE;	/* For the compiler.. */
 				}
 				chset = io_ptr->ichset;		/* in case UTF-16 was changed */
@@ -1251,8 +1251,8 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 						(TREF(pipefifo_interrupt))++;
 						PIPE_DEBUG(PRINTF(" %d utf1.1 stream outofband\n", pid); DEBUGPIPEFLUSH);
 						REVERT_GTMIO_CH(&io_curr_device, ch_set);
-						outofband_action(FALSE);
-						assertpro(FALSE);	/* Should *never* return from outofband_action */
+						async_action(FALSE);
+						assertpro(FALSE);	/* Should *never* return from async_action */
 						return FALSE;	/* For the compiler.. */
 					}
 					/* Set the UTF-16 variant if not already set, and has been determined right now */
@@ -1378,9 +1378,8 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 									stringpool.free += bytes_count;
 									(TREF(pipefifo_interrupt))++;
 									REVERT_GTMIO_CH(&io_curr_device, ch_set);
-									outofband_action(FALSE);
-									assertpro(FALSE);	/* Should *never* return from
-											   outofband_action */
+									async_action(FALSE);
+									assertpro(FALSE); /* never returns from async_action */
 									return FALSE;	/* For the compiler.. */
 								}
 								continue; /* for now try and read again if eof or no input
@@ -1447,8 +1446,8 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 							stringpool.free += bytes_count;
 							(TREF(pipefifo_interrupt))++;
 							REVERT_GTMIO_CH(&io_curr_device, ch_set);
-							outofband_action(FALSE);
-							assertpro(FALSE);	/* Should *never* return from outofband_action */
+							async_action(FALSE);
+							assertpro(FALSE);	/* Should *never* return from async_action */
 							return FALSE;	/* For the compiler.. */
 						}
 						if (-1 == status)
@@ -1893,7 +1892,7 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 		{	/* Cancel the timer before taking the error return */
 			if (timed && !out_of_time)
 				cancel_timer(timer_id);
-			io_ptr->dollar.za = 9;
+			io_ptr->dollar.za = ZA_IO_ERR;
 			/* save error in $device */
 			SET_DOLLARDEVICE_ONECOMMA_STRERROR(io_ptr, real_errno);
 			ISSUE_NOPRINCIO_IF_NEEDED(io_ptr, FALSE, FALSE);		/* FALSE, FALSE: READ, not socket*/
@@ -1913,8 +1912,8 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 					save_errno = errno;
 					SET_DOLLARDEVICE_ONECOMMA_STRERROR(io_ptr, save_errno);
 					ISSUE_NOPRINCIO_IF_NEEDED(io_ptr, FALSE, FALSE); /* FALSE, FALSE: READ, not socket*/
-					rts_error_csa(CSA_ARG(NULL) VARLSTCNT(8) ERR_SYSCALL, 5, LEN_AND_LIT("fcntl"),
-						      CALLFROM, save_errno);
+					RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(8) ERR_SYSCALL, 5, LEN_AND_LIT("fcntl"),
+						CALLFROM, save_errno);
 				}
 			}
 			if ((rm_ptr->is_pipe && (0 == status)) || (rm_ptr->fifo && (0 == status || real_errno == EAGAIN)))
@@ -1940,7 +1939,7 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 			return FALSE;
 		}
 		/* on end of file set $za to 9 */
-		io_ptr->dollar.za = 9;
+		io_ptr->dollar.za = ZA_IO_ERR;
 		*dollarx_ptr = 0;
 		(*dollary_ptr)++;
 		if (WBTEST_ENABLED(WBTEST_DOLLARDEVICE_BUFFER))
@@ -1949,10 +1948,10 @@ int	iorm_readfl (mval *v, int4 width, int4 msec_timeout) /* timeout in milliseco
 			SET_DOLLARDEVICE_ERRSTR(io_ptr, ONE_COMMA_DEV_DET_EOF);
 		ISSUE_NOPRINCIO_IF_NEEDED(io_ptr, FALSE, FALSE);	/* FALSE, FALSE: READ, not socket*/
 		if (!prin_dm_io && (TRUE == io_ptr->dollar.zeof) && (RM_READ == saved_lastop))
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_IOEOF);
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_IOEOF);
 		io_ptr->dollar.zeof = TRUE;
 		if (!prin_dm_io && (0 < io_ptr->error_handler.len))
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_IOEOF);
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_IOEOF);
 		if ((pipe_zero_timeout || rm_ptr->fifo) && out_of_time)
 		{
 			ret = TRUE;
