@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -182,14 +182,14 @@ void	iorm_use(io_desc *iod, mval *pp)
 	boolean_t	init_input_encryption, init_output_encryption, reset_input_encryption, reset_output_encryption;
 	boolean_t	seek_specified, ichset_specified, ochset_specified, chset_allowed;
 	unsigned char	c;
-	short		mode, mode1;
+	short		mode = 0, mode1 = 0;
 	int4		length, width, width_bytes, recordsize, recsize_before, padchar;
-	int		fstat_res, save_errno, rv;
+	int		fstat_res, save_errno = 0, rv;
 	d_rm_struct	*rm_ptr;
 	struct stat	statbuf;
 	int		p_offset;
 	mstr		chset_mstr;
-	gtm_chset_t	width_chset, temp_chset;
+	gtm_chset_t	width_chset, temp_chset = CHSET_MAX_IDX_ALL;
 	int		seek_len;
 	char		seek_str[LIMIT_SEEK_STR];
 	char		*seek_ptr;
@@ -201,7 +201,7 @@ void	iorm_use(io_desc *iod, mval *pp)
 	off_t		cur_position;
 	int		bom_size_toread;
 	io_log_name	*dev_name;
-	mstr		input_iv, output_iv, input_key, output_key;
+	mstr		input_iv = {0, 0, NULL}, output_iv = {0, 0, NULL}, input_key = {0, 0, NULL}, output_key = {0, 0, NULL};
 	char		error_str[MAX_ERROR_SIZE];
 	boolean_t	ch_set, def_recsize_before;
 	int		disk_block_multiple;
@@ -324,7 +324,7 @@ void	iorm_use(io_desc *iod, mval *pp)
 			 * side of $PRINCIPAL is equal to io_std_device.in we break if OUTREWIND is the device parameter.
 			 * A similar check is done on the output side if INREWIND or REWIND is the device parameter.
 			 */
-			if ((io_std_device.in == iod))
+			if (io_std_device.in == iod)
 				break;
 			outdevparam = TRUE;
 		case iop_inrewind:
@@ -370,6 +370,14 @@ void	iorm_use(io_desc *iod, mval *pp)
 				rm_ptr->read_occurred = FALSE;
 				if (rm_ptr->input_encrypted)
 					reset_input_encryption = TRUE;
+			} else if (iod->state == dev_open && (rm_ptr->fifo || rm_ptr->is_pipe))
+			{	/* For FIFO or PIPE, just reset ISVs and needed state */
+				iod->dollar.zeof = FALSE;
+				if (io_std_device.in == iod)
+					prin_in_dev_failure = FALSE;
+				iod->dollar.y = 0;
+				iod->dollar.x = 0;
+				rm_ptr->lastop = RM_NOOP;
 			}
 			break;
 		case iop_stream:
@@ -441,8 +449,11 @@ void	iorm_use(io_desc *iod, mval *pp)
 							newfd = dup(rm_ptr->fildes);
 						} while (-1 == newfd && EINTR == errno);
 						if (-1 == newfd)
+						{
+							save_errno = errno;
 							RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(8) ERR_SYSCALL, 5,
 								RTS_ERROR_LITERAL("dup"), CALLFROM, save_errno);
+						}
 						if (TRUE == rm_ptr->read_only)
 						{
 							FDOPEN(newstr,newfd,"r");
@@ -678,7 +689,7 @@ void	iorm_use(io_desc *iod, mval *pp)
 			 * side of $PRINCIPAL is equal to io_std_device.in we break if OUTSEEK is the device parameter.
 			 * A similar check is done on the output side if INSEEK or SEEK is the device parameter.
 			 */
-			if ((io_std_device.in == iod))	/* CAUTION: potential fall-through */
+			if (io_std_device.in == iod)	/* CAUTION: potential fall-through */
 				break;
 			outdevparam = TRUE;
 		case iop_inseek:
@@ -1003,6 +1014,8 @@ void	iorm_use(io_desc *iod, mval *pp)
 		{	/* Input KEY deviceparameter is present. */
 			if (input_key_not_empty)
 			{	/* Input KEY is meaningful. */
+				assert(input_key.addr);
+				assert(input_iv.addr);
 				if (KEY_CHANGED(input, input_key, rm_ptr) || IV_CHANGED(input, input_iv, rm_ptr))
 				{	/* Requested a new IV or KEY; only allow if no reads have happened. */
 					if (rm_ptr->read_occurred)
@@ -1051,6 +1064,8 @@ void	iorm_use(io_desc *iod, mval *pp)
 		{	/* Input KEY deviceparameter is present. */
 			if (output_key_not_empty)
 			{	/* Output KEY is meaningful. */
+				assert(output_key.addr);
+				assert(output_iv.addr);
 				if (KEY_CHANGED(output, output_key, rm_ptr) || IV_CHANGED(output, output_iv, rm_ptr))
 				{	/* Requested a new IV or KEY; only allow if no writes have happened. */
 					if (rm_ptr->write_occurred)
@@ -1112,6 +1127,8 @@ void	iorm_use(io_desc *iod, mval *pp)
 	}
 	if (init_input_encryption)
 	{	/* Get the key handle corresponding to the keyname provided. */
+		assert(input_key.addr);
+		assert(input_iv.addr);
 		INIT_CIPHER_CONTEXT(GTMCRYPT_OP_DECRYPT, input_key, input_iv, rm_ptr->input_cipher_handle, dev_name);
 		rm_ptr->input_encrypted = TRUE;
 		rm_ptr->input_key.addr = input_key.addr;
@@ -1133,6 +1150,8 @@ void	iorm_use(io_desc *iod, mval *pp)
 	}
 	if (init_output_encryption)
 	{	/* Get the key handle corresponding to the keyname provided. */
+		assert(output_key.addr);
+		assert(output_iv.addr);
 		INIT_CIPHER_CONTEXT(GTMCRYPT_OP_ENCRYPT, output_key, output_iv, rm_ptr->output_cipher_handle, dev_name);
 		rm_ptr->output_encrypted = TRUE;
 		rm_ptr->output_key.addr = output_key.addr;
