@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -121,7 +121,7 @@ void iorm_write_utf(mstr *v)
 	wint_t		utf_code;
 	io_desc		*iod;
 	d_rm_struct	*rm_ptr;
-	unsigned char	*inptr, *top, *nextmb, *outptr, *nextoutptr, *outstart, temppad, temppadarray[2];
+	unsigned char	*inptr, *top, *nextmb, *outptr = NULL, *nextoutptr, *outstart, temppad, temppadarray[2];
 	char		*out_ptr;
 	boolean_t	utf8_active = TRUE;		/* needed by GTM_IO_WCWIDTH macro */
 	boolean_t	stream, wrap;
@@ -223,6 +223,7 @@ void iorm_write_utf(mstr *v)
 			}
 			if (CHSET_UTF8 != iod->ochset)
 			{
+				assert(outptr);
 				if (CHSET_UTF16BE == iod->ochset)
 					nextoutptr = UTF16BE_WCTOMB(utf_code, outptr);
 				else
