@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2014-2022 Fidelity National Information	*
+ * Copyright (c) 2014-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -14,11 +14,7 @@
 #ifdef GTM_TLS
 
 #include <errno.h>
-#ifdef USE_POLL
 #include "gtm_poll.h"
-#else
-#include "gtm_select.h"
-#endif
 #include "gtm_socket.h"
 #include "gtm_inet.h"
 #include "gtm_stdio.h"
@@ -93,12 +89,7 @@ void	iosocket_tls(mval *optionmval, int4 msec_timeout, mval *tlsid, mval *passwo
 	tls_option		option;
 	gtm_tls_socket_t	*tlssocket;
 	ABS_TIME		cur_time, end_time;
-#	ifdef USE_POLL
 	struct pollfd		fds;
-#	else
-	fd_set			fds, *readfds, *writefds;
-	struct timeval		*timeout_ptr, timeout_spec;
-#	endif
 	boolean_t		ch_set;
 
 	iod = io_curr_device.out;
@@ -326,35 +317,14 @@ void	iosocket_tls(mval *optionmval, int4 msec_timeout, mval *tlsid, mval *passwo
 			return;
 		}
 		status = 0;
-#		ifndef	USE_POLL
-		if (NO_M_TIMEOUT == msec_timeout)
-			timeout_ptr = NULL;
-		else
-		{
-			timeout_spec.tv_sec = msec_timeout / MILLISECS_IN_SEC;
-			/* remainder in millsecs to microsecs */
-			timeout_spec.tv_usec = (msec_timeout % MILLISECS_IN_SEC) * MICROSECS_IN_MSEC;
-			timeout_ptr = &timeout_spec;
-		}
-#		endif
 		do
 		{
 			status2 = 0;
 			if (0 != status)
 			{
-#				ifdef USE_POLL
 				fds.fd = socketptr->sd;
 				fds.events = (GTMTLS_WANT_READ == status) ? POLLIN : POLLOUT;
-#				else
-				readfds = writefds = NULL;
-				assertpro(FD_SETSIZE > socketptr->sd);
-				FD_ZERO(&fds);
-				FD_SET(socketptr->sd, &fds);
-				writefds = (GTMTLS_WANT_WRITE == status) ? &fds : NULL;
-				readfds = (GTMTLS_WANT_READ == status) ? &fds : NULL;
-#				endif
-				POLL_ONLY(if (-1 == (status2 = poll(&fds, 1, (NO_M_TIMEOUT == msec_timeout) ? -1 : msec_timeout))))
-				SELECT_ONLY(if (-1 == (status2 = select(socketptr->sd + 1, readfds, writefds, NULL, timeout_ptr))))
+				if (-1 == (status2 = poll(&fds, 1, (NO_M_TIMEOUT == msec_timeout) ? -1 : msec_timeout)))
 				{
 					save_errno = errno;
 					if (EAGAIN == save_errno)
@@ -408,14 +378,9 @@ void	iosocket_tls(mval *optionmval, int4 msec_timeout, mval *tlsid, mval *passwo
 						REVERT_GTMIO_CH(&iod->pair, ch_set);
 						return;
 					} else
-					{	/* adjust msec_timeout for poll/select */
-#					ifdef	USE_POLL
+					{	/* adjust msec_timeout for poll */
 						msec_timeout = (cur_time.at_sec * MILLISECS_IN_SEC) +
 							DIVIDE_ROUND_UP(cur_time.at_usec, MICROSECS_IN_MSEC);
-#					else
-						timeout_spec.tv_sec = cur_time.at_sec;
-						timeout_spec.tv_usec = (gtm_tv_usec_t)cur_time.at_usec;
-#					endif
 					}
 				} else if (0 == msec_timeout)
 				{	/* only one chance */
@@ -428,6 +393,81 @@ void	iosocket_tls(mval *optionmval, int4 msec_timeout, mval *tlsid, mval *passwo
 				continue;
 			}
 		} while ((GTMTLS_WANT_READ == status) || (GTMTLS_WANT_WRITE == status));
+		if (tlsopt_server == option)
+		{	/* Servers do post hand-shake auth as needed */
+			status = gtm_tls_do_post_hand_shake((gtm_tls_socket_t *)socketptr->tlssocket);
+			if (0 != status)
+			{	/* Something wrong. Decide if an error occurred in setting PHA or handshake retry needed */
+				if ((GTMTLS_WANT_READ != status) && (GTMTLS_WANT_WRITE != status))
+				{	/* post hand-shake auth failure */
+					errp = gtm_tls_get_error((gtm_tls_socket_t *)socketptr->tlssocket);
+					SET_DOLLARDEVICE_ONECOMMA_ERRSTR(iod, errp, errlen);
+					if (socketptr->ioerror)
+						RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_TLSHANDSHAKE, 0,
+							ERR_TEXT, 2, errlen, errp);
+					if (NO_M_TIMEOUT != msec_timeout)
+						dollar_truth = FALSE;
+					REVERT_GTMIO_CH(&iod->pair, ch_set);
+					return;
+				}
+				/* Need to retry the handshake */
+				fds.fd = socketptr->sd;
+				do
+				{
+					/* Check timeout after each handshake attempt. Note that gtm_tls_do_post_hand_shake()
+					 * includes a hand-shake attempt, hence timeout checks are done first
+					 */
+					if ((0 != msec_timeout) && (NO_M_TIMEOUT != msec_timeout))
+					{
+						sys_get_curr_time(&cur_time);
+						cur_time = sub_abs_time(&end_time, &cur_time);
+						if (0 >= cur_time.at_sec)
+						{	/* no more time */
+							gtm_tls_session_close((gtm_tls_socket_t **)&socketptr->tlssocket);
+							socketptr->tlsenabled = FALSE;
+							dollar_truth = FALSE;
+							REVERT_GTMIO_CH(&iod->pair, ch_set);
+							return;
+						} else
+						{	/* adjust msec_timeout for poll */
+							msec_timeout = (cur_time.at_sec * MILLISECS_IN_SEC) +
+								DIVIDE_ROUND_UP(cur_time.at_usec, MICROSECS_IN_MSEC);
+						}
+					} else if (0 == msec_timeout)
+					{	/* only one chance */
+						gtm_tls_session_close((gtm_tls_socket_t **)&socketptr->tlssocket);
+						socketptr->tlsenabled = FALSE;
+						dollar_truth = FALSE;
+						REVERT_GTMIO_CH(&iod->pair, ch_set);
+						return;
+					}
+					fds.events = (GTMTLS_WANT_READ == status) ? POLLIN : POLLOUT;
+					if (-1 == (status2 = poll(&fds, 1, (NO_M_TIMEOUT == msec_timeout) ? -1 : msec_timeout)))
+					{
+						save_errno = errno;
+						if (EAGAIN == save_errno)
+						{
+							rel_quant();	/* allow resources to become available - likely nanosleep */
+							status2 = 0;	/* treat as timeout */
+						} else if (EINTR == save_errno)
+							status2 = 0;
+					}
+					status = gtm_tls_repeat_hand_shake((gtm_tls_socket_t *)socketptr->tlssocket);
+				} while ((GTMTLS_WANT_READ == status) || (GTMTLS_WANT_WRITE == status));
+				if (0 != status)
+				{	/* post hand-shake auth failure */
+					errp = gtm_tls_get_error((gtm_tls_socket_t *)socketptr->tlssocket);
+					SET_DOLLARDEVICE_ONECOMMA_ERRSTR(iod, errp, errlen);
+					if (socketptr->ioerror)
+						RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_TLSHANDSHAKE, 0,
+							ERR_TEXT, 2, errlen, errp);
+					if (NO_M_TIMEOUT != msec_timeout)
+						dollar_truth = FALSE;
+					REVERT_GTMIO_CH(&iod->pair, ch_set);
+					return;
+				}
+			}
+		}
 		/* turn on output buffering */
 		SOCKET_OBUFFER_INIT(socketptr, socketptr->buffer_size, DEFAULT_WRITE_WAIT, (DEFAULT_WRITE_WAIT * 2));
 		socketptr->obuffer_in_use = TRUE;
@@ -451,7 +491,9 @@ void	iosocket_tls(mval *optionmval, int4 msec_timeout, mval *tlsid, mval *passwo
 			errp = UNREAD_INPUT;
 			SET_DOLLARDEVICE_ONECOMMA_ERRSTR(iod, errp, errlen);
 			if (socketptr->ioerror)
-				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_TLSRENEGOTIATE, 0,
+				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(7) ERR_TLSRENEGOTIATE, 1,
+					((gtm_tls_does_renegotiate((gtm_tls_socket_t *)socketptr->tlssocket)) ?
+						 "renegotiate" : "update TLS session keys"),
 					ERR_TEXT, 2, errlen, errp);
 			if (NO_M_TIMEOUT != msec_timeout)
 				dollar_truth = FALSE;
@@ -470,7 +512,9 @@ void	iosocket_tls(mval *optionmval, int4 msec_timeout, mval *tlsid, mval *passwo
 					errp2 = (char *)STRERROR(socketptr->obuffer_errno);
 				SET_DOLLARDEVICE_ONECOMMA_ERRSTR1_ERRSTR2(iod, errp, errlen, errp2, errlen2);
 				if (socketptr->ioerror)
-					RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(10) ERR_TLSRENEGOTIATE, 0,
+					RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(11) ERR_TLSRENEGOTIATE, 1,
+						((gtm_tls_does_renegotiate((gtm_tls_socket_t *)socketptr->tlssocket)) ?
+						 	"renegotiate" : "update TLS session keys"),
 						ERR_TEXT, 2, errlen, errp, ERR_TEXT, 2, errlen2, errp2);
 				if (NO_M_TIMEOUT != msec_timeout)
 					dollar_truth = FALSE;
@@ -514,7 +558,9 @@ void	iosocket_tls(mval *optionmval, int4 msec_timeout, mval *tlsid, mval *passwo
 				errp = STRERROR(tls_errno);
 			SET_DOLLARDEVICE_ONECOMMA_ERRSTR(iod, errp, errlen);
 			if (socketptr->ioerror)
-				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_TLSRENEGOTIATE, 0,
+				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(7) ERR_TLSRENEGOTIATE, 1,
+					((gtm_tls_does_renegotiate((gtm_tls_socket_t *)socketptr->tlssocket)) ?
+					 	"renegotiate" : "update TLS session keys"),
 					ERR_TEXT, 2, errlen, errp);
 			if (NO_M_TIMEOUT != msec_timeout)
 				dollar_truth = FALSE;
