@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2009 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -16,11 +17,13 @@
 #include "io.h"
 #include "iousdef.h"
 
+error_def(ERR_USRIOINIT);
+
+/* Open a device belonging to the user defined nmemonicspace */
 short ious_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4 timeout)
 {
 	io_desc *iod;
 	dev_dispatch_struct *fgn_driver;
-	error_def(ERR_USRIOINIT);
 
 	iod = dev->iod;
 	if (iod->state == dev_never_opened)
@@ -33,14 +36,20 @@ short ious_open(io_log_name *dev, mval *pp, int file_des, mval *mspace, int4 tim
 	if (iod->state != dev_open)
 	{
 		if (mspace && mspace->str.len)
-		{	fgn_driver = io_get_fgn_driver(&mspace->str);
+		{	/* Currently there is no mechanism implementing a user nmemonicspace device. As a
+			 * result, io_get_fgn_driver() issues an rts_error() which leaves
+			 * (NULL == (d_us_struct*)(iod->dev_sp))->disp) true. If a user nmemonicspace is
+			 * implemented, it must open the device and complete enough setup/configuration to
+			 * avoid a memory access violation.
+			 */
+			fgn_driver = io_get_fgn_driver(&mspace->str);
 			((d_us_struct*)(iod->dev_sp))->disp = fgn_driver;
-		}
-		else if (!(((d_us_struct*)(iod->dev_sp))->disp->open))
-		{	rts_error(VARLSTCNT(1) ERR_USRIOINIT);
+		} else if ((NULL == ((d_us_struct*)(iod->dev_sp))->disp)
+				|| (NULL == (((d_us_struct*)(iod->dev_sp))->disp->open)))
+		{
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_USRIOINIT);
 			return FALSE;
 		}
-
 		((void(*)())(((d_us_struct*)(iod->dev_sp))->disp->open))();
 		iod->state = dev_open;
 	}
