@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2009 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2016 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -10,16 +11,21 @@
  ****************************************************************/
 
 #include "mdef.h"
-#include <errno.h>
-#include <signal.h>
 
+#include <errno.h>
 #ifdef __MVS__
 #include <sys/resource.h>
 #endif
 
+#include "gtm_signal.h"
+
 #include "is_proc_alive.h"
-/*
- * ----------------------------------------------
+
+#ifdef DEBUG
+GBLREF	uint4			process_id;
+#endif
+
+/* ----------------------------------------------
  * Check if process is still alive
  *
  * Arguments:
@@ -38,10 +44,7 @@ bool is_proc_alive(int4 pid, int4 imagecnt)
 	bool		ret;
 
 	if (0 == pid)
-	{
-		assert(FALSE);
 		return FALSE;
-	}
 #	ifdef __MVS__
 	errno = 0;	/* it is possible getpriority returns -1 even in case of success */
 	status = getpriority(PRIO_PROCESS, (id_t)pid);
@@ -52,12 +55,10 @@ bool is_proc_alive(int4 pid, int4 imagecnt)
 #	endif
 	if (status)
 	{
-		assert(status == -1 && (errno == EPERM || errno == ESRCH));
-		if (errno == ESRCH)
-			ret = FALSE;
-		else
-			ret = TRUE;
+		assert((-1 == status) && ((EPERM == errno) || (ESRCH == errno)));
+		ret = (ESRCH != errno);
 	} else
 		ret = TRUE;
+	assert(ret || (process_id != pid));
 	return ret;
 }
