@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2012 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -10,6 +11,6 @@
  ****************************************************************/
 
 #define MLK_LOGIN(x)
-#define BLOCKING_PROC_ALIVE(w,x,y,z) (!is_proc_alive(w->blocked->owner, 0))
-#define PENDING_PROC_ALIVE(w,x,y,z) (!is_proc_alive(w->process_id, 0))
-#define PROC_ALIVE(w,x,y,z) (!is_proc_alive(w->owner, 0))
+#define BLOCKING_PROC_DEAD(w,x,y,z) (!is_proc_alive((w)->blocked->owner, 0))
+#define PENDING_PROC_DEAD(w,x,y,z) (!is_proc_alive((w)->process_id, 0))
+#define PROC_DEAD(w,x,y,z) (!is_proc_alive((w)->owner, 0))
