@@ -1,6 +1,7 @@
 #################################################################
 #								#
-#	Copyright 2001, 2013 Fidelity Information Services, Inc	#
+# Copyright (c) 2001-2022 Fidelity National Information		#
+# Services, Inc. and/or its subsidiaries. All rights reserved.	#
 #								#
 #	This source code contains the intellectual property	#
 #	of its copyright holder(s), and is made available	#
@@ -24,7 +25,7 @@ do
 			dir=`dirname $i`
 			if [ "utf8" = $utf8 ]; then
 				echo $dir/$i "---> "  $newf$ext "-> "../$newf$ext
-				ln -s ../$newf$ext $newf$ext
+				ln -fs ../$newf$ext $newf$ext
 			else
 				echo $dir/$i "---> " $dir/$newf$ext
 				cp -p $i $dir/$newf$ext
