@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2014 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2017 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -22,7 +23,8 @@
  ************************************************************/
 
 static readonly CLI_PARM mumps_parm[] = {
-	{"INFILE", "What file: ", PARM_REQ}
+	{"INFILE", "What file: ", PARM_REQ},
+	{""}
 };
 
 static readonly CLI_ENTRY mumps_qual[] = {
@@ -44,10 +46,10 @@ static readonly CLI_ENTRY mumps_qual[] = {
 { "RUN", 		0, 0, 0, 0, 0, 0, VAL_DISALLOWED, 0, NON_NEG, 	VAL_N_A, 0},
 { "SPACE", 		0, 0, 0, 0, 0, 0, VAL_REQ, 	  1, NON_NEG, 	VAL_NUM, 0},
 { "WARNINGS", 		0, 0, 0, 0, 0, 0, VAL_DISALLOWED, 0, NEG, 	VAL_N_A, 0},
-{ 0 }
+{ "" }
 };
 
 GBLDEF CLI_ENTRY mumps_cmd_ary[] = {
 { "MUMPS", 0, mumps_qual, mumps_parm, 0, 0, 0, VAL_DISALLOWED, 1, 0, VAL_LIST, 0},
-{ 0 }
+{ "" }
 };
