@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2007 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -10,8 +11,8 @@
  ****************************************************************/
 
 #include "mdef.h"
-#include <signal.h>
-#include <time.h>
+#include "gtm_signal.h"
+#include "gtm_time.h"
 #include "mupip_ctrl.h"
 
 GBLDEF bool	mu_ctrly_occurred;
@@ -36,6 +37,5 @@ void mupip_ctrl(int sig)
 	}else
 		mu_ctrlc_occurred = TRUE;
 	prev_time = curr_time;
-	signal(SIGINT, mupip_ctrl);
 	return;
 }
