@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2019 Fidelity National Information	*
+ * Copyright (c) 2001-2022 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -35,11 +35,17 @@
 #include "gtmmsg.h"
 #include "mupip_dump_fhead.h"
 #include "gtm_stdlib.h"
+#include "wcs_flu.h"
+#include "mdq.h"
 
 GBLREF char			gtm_dist[GTM_PATH_MAX];
 GBLREF boolean_t		gtm_dist_ok_to_use;
 GBLREF tp_region		*grlist;
+GBLREF gd_region		*gv_cur_region;
+GBLREF sgmnt_addrs		*cs_addrs;
+GBLREF usr_reg_que		*usr_spec_regions;
 
+error_def(ERR_BUFFLUFAILED);
 error_def(ERR_DBNOREGION);
 error_def(ERR_GTMDISTUNVERIF);
 error_def(ERR_MUNOFINISH);
@@ -56,21 +62,55 @@ void mupip_dump_fhead(void)
 	tp_region	*rptr;
 	unsigned char	file[GTM_PATH_MAX];
 	unsigned short	file_len = GTM_PATH_MAX - 1;
+	usr_reg_que	*region_que_entry;
 	DCL_THREADGBL_ACCESS;
 
 	SETUP_THREADGBL_ACCESS;
 	/* Verify gtm_dist, and make sure there is a parameter. */
 	if (!gtm_dist_ok_to_use)
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(3) ERR_GTMDISTUNVERIF, 4, LEN_AND_STR(gtm_dist));
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(3) ERR_GTMDISTUNVERIF, 4, LEN_AND_STR(gtm_dist));
 	if (CLI_PRESENT == cli_present("REGION"))
 	{	/* region */
 		status = SS_NORMAL;
 		gvinit();
 		mu_getlst("WHAT", SIZEOF(tp_region));
 		if (!grlist)
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(1) ERR_DBNOREGION);
-		for (rptr = grlist; NULL != rptr; rptr = rptr->fPtr)
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(1) ERR_DBNOREGION);
+		dqloop(usr_spec_regions, que, region_que_entry)
 		{
+			for (rptr = grlist; NULL != rptr; rptr = rptr->fPtr)
+			{
+				gv_cur_region = rptr->reg;
+				if ((char *)gv_cur_region->rname == (char *)region_que_entry->usr_reg)
+					break; /* Matching region found. Exit the loop */
+			}
+			if (NULL == rptr)
+				continue; /* continue the dqloop */
+			if (CLI_PRESENT == cli_present("FLUSH"))
+			{
+				gv_init_reg(rptr->reg, NULL);
+				gv_cur_region = rptr->reg; /* required for wcs_flu */
+				cs_addrs = &FILE_INFO(gv_cur_region)->s_addrs;
+				if (TRUE == grab_crit_immediate(gv_cur_region, TRUE, NOT_APPLICABLE))
+				{
+					if (!wcs_flu(WCSFLU_FLUSH_HDR))
+					{
+						rel_crit(gv_cur_region);
+						gtm_putmsg_csa(CSA_ARG(REG2CSA(gv_cur_region)) VARLSTCNT(6)
+								MAKE_MSG_WARNING(ERR_BUFFLUFAILED), 4,
+								LEN_AND_LIT("MUPIP DUMPFHEAD -FLUSH"
+								" while flushing file header elements"),
+								DB_LEN_STR(gv_cur_region));
+					} else
+						rel_crit(gv_cur_region);
+				} else
+				{
+					gtm_putmsg_csa(CSA_ARG(REG2CSA(gv_cur_region)) VARLSTCNT(6)
+							MAKE_MSG_WARNING(ERR_BUFFLUFAILED), 4,
+							LEN_AND_LIT("MUPIP DUMPFHEAD -FLUSH while grabbing critical section"),
+							DB_LEN_STR(gv_cur_region));
+				}
+			}
 			util_out_print("Fileheader dump of region !AD", TRUE, REG_LEN_STR(rptr->reg));
 			util_out_print("Dumping fileheader of !AD", TRUE, DB_LEN_STR(rptr->reg));
 			status |= dumpfhead(DB_LEN_STR(rptr->reg));
