@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2024 Fidelity National Information	*
+ * Copyright (c) 2001-2025 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -140,6 +140,7 @@ void mupip_rundown(void)
 	}
 	TREF(skip_file_corrupt_check) = TRUE;	/* rundown the database even if csd->file_corrupt is TRUE */
 	TREF(ok_to_see_statsdb_regs) = TRUE;
+	TREF(enable_autodelete) = TRUE; /* Fully clean up autodeletable files */
 	/* No need to do the following set (like is done in mupip_integ.c) since we call "mu_rndwn_file" (not "gvcst_init")
 	 *	TREF(statshare_opted_in) = NO_STATS_OPTIN;	// Do not open statsdb automatically when basedb is opened
 	 */
@@ -213,9 +214,7 @@ void mupip_rundown(void)
 					continue;
 				}
 				gv_cur_region = rptr->reg;
-				seg = gv_cur_region->dyn.addr;
-				if (NULL == seg->file_cntl)
-					FILE_CNTL_INIT(seg);
+				FILE_CNTL_INIT_IF_NULL(gv_cur_region);
 			}
 			if (mu_rndwn_file(gv_cur_region, FALSE, FALSE))
 			{
