@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -52,6 +52,7 @@ void ojparams (char *p, job_params_type *job_params)
 	int4			status;
 	mstr_len_t		handle_len;
 	FILE			*curlvn_out;
+	intrpt_state_t		prev_intrpt_state;
 
 		/* Initializations */
 	job_params->params.baspri = 0;
@@ -64,7 +65,7 @@ void ojparams (char *p, job_params_type *job_params)
 	/* job_params->params.routine.len initialized by caller */
 	/* job_params->params.label.len initialized by caller */
 	job_params->cmdline.len = 0;
-	job_params->passcurlvn = FALSE;
+	job_params->xfercurlvn = FALSE;
 
 		/* Process parameter list */
 	while (*p != jp_eol)
@@ -131,8 +132,8 @@ void ojparams (char *p, job_params_type *job_params)
 			}
 			break;
 
-		case jp_passcurlvn:
-			job_params->passcurlvn = TRUE;
+		case jp_xfercurlvn:
+			job_params->xfercurlvn = TRUE;
 			break;
 		case jp_account:
 		case jp_detached:
@@ -272,9 +273,11 @@ void ojparams (char *p, job_params_type *job_params)
 				job_params->params.directory.len, job_params->params.directory.buffer);
 
 	/* Gather local variables to pass */
-	if (job_params->passcurlvn)
+	if (job_params->xfercurlvn)
 	{	/* Create a "memory file" to store the job_set_locals messages for later transmission by the middle child. */
+		DEFER_INTERRUPTS(INTRPT_IN_FUNC_WITH_MALLOC, prev_intrpt_state);
 		curlvn_out = open_memstream(&job_params->curlvn_buffer_ptr, &job_params->curlvn_buffer_size);
+		ENABLE_INTERRUPTS(INTRPT_IN_FUNC_WITH_MALLOC, prev_intrpt_state);
 		local_variable_marshalling(curlvn_out);
 		FCLOSE(curlvn_out, status);	/* Force "written" messages into the buffer */
 	}
