@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2018 Fidelity National Information	*
+ * Copyright (c) 2001-2021 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -52,9 +52,9 @@ void	op_fnzparse (mval *file, mval *field, mval *def1, mval *def2, mval *type, m
 	MV_FORCE_STR(type);
 
 	if (def1->str.len > MAX_FN_LEN)
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(4) ERR_INVSTRLEN, 2, def1->str.len, MAX_FN_LEN);
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(4) ERR_INVSTRLEN, 2, def1->str.len, MAX_FN_LEN);
 	if (def2->str.len > MAX_FN_LEN)
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(4) ERR_INVSTRLEN, 2, def2->str.len, MAX_FN_LEN);
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(4) ERR_INVSTRLEN, 2, def2->str.len, MAX_FN_LEN);
 
 	if (field->str.len == 0)
 	{
@@ -101,7 +101,7 @@ void	op_fnzparse (mval *file, mval *field, mval *def1, mval *def2, mval *type, m
 			}
 		}
 		if (field_type == 0)
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(4) ERR_ZPARSFLDBAD, 2, field->str.len, field->str.addr);
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(4) ERR_ZPARSFLDBAD, 2, field->str.len, field->str.addr);
 	}
 
 	memset(&pblk, 0, SIZEOF(pblk));
@@ -118,7 +118,7 @@ void	op_fnzparse (mval *file, mval *field, mval *def1, mval *def2, mval *type, m
 			/* no meaning on unix */
 		}
 		else
-			rts_error_csa(CSA_ARG(NULL) VARLSTCNT(4) ERR_ZPARSETYPE, 2, type->str.len, type->str.addr);
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(4) ERR_ZPARSETYPE, 2, type->str.len, type->str.addr);
 	}
 
 	pblk.buffer = result;
