@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2013-2024 Fidelity National Information	*
+ * Copyright (c) 2013-2025 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -43,6 +43,7 @@ error_def(ERR_BADZPEEKARG);
 error_def(ERR_BADZPEEKFMT);
 error_def(ERR_BADZPEEKRANGE);
 error_def(ERR_MAXSTRLEN);
+error_def(ERR_NOGTCMDB);
 error_def(ERR_ZPEEKNOJNLINFO);
 error_def(ERR_ZPEEKNORPLINFO);
 
@@ -440,7 +441,7 @@ void	op_fnzpeek(mval *structid, int offset, int len, mval *format, mval *ret)
 	int			errtoraise, rc, rslt;
 	unsigned char		fmtcode;
 	boolean_t		arg_supplied, attach_success;
-	unsigned char		mnemonic[NAME_ENTRY_SZ], *nptr, *cptr, *cptrend, *argptr;
+	unsigned char		mnemonic[NAME_ENTRY_SZ + ARGUMENT_MAX_LEN + 1], *nptr, *cptr, *cptrend, *argptr;
 	int			mnemonic_len, mnemonic_index, mnemonic_opcode, arglen, arryidx = -1;
 	gd_region		*r_top, *r_ptr = NULL;
 	replpool_identifier	replpool_id;
@@ -459,6 +460,8 @@ void	op_fnzpeek(mval *structid, int offset, int len, mval *format, mval *ret)
 	MV_FORCE_STR(structid);
 	MV_FORCE_STR(format);
 	/* Parse and lookup the first arg's mnemonic and arg (if supplied) */
+	if (structid->str.len > (NAME_ENTRY_SZ + ARGUMENT_MAX_LEN + 1))
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(4) ERR_BADZPEEKARG, 2, RTS_ERROR_LITERAL("length"));
 	for (nptr = mnemonic, cptr = (unsigned char *)structid->str.addr, cptrend = cptr + structid->str.len;
 	     cptr < cptrend; ++cptr)
 	{
@@ -466,6 +469,7 @@ void	op_fnzpeek(mval *structid, int offset, int len, mval *format, mval *ret)
 			break;		/* End of mnemonic, start of arg */
 		*nptr++ = *cptr;
 	}
+	assert(nptr <= ARRAYTOP(mnemonic));
 	arg_supplied = (cptr < cptrend);
 	mnemonic_len = INTCAST(nptr - mnemonic);
 	mnemonic_index = namelook(zpeek_index, zpeek_names, (char *)mnemonic, mnemonic_len);
@@ -580,6 +584,10 @@ void	op_fnzpeek(mval *structid, int offset, int len, mval *format, mval *ret)
 			assert(FALSE);		/* Only the above types should ever have an argument */
 		}
 	}
+	if (r_ptr && r_ptr->dyn.addr->acc_meth == dba_cm)
+	{	/* PEEKBYNAME invocation is not supported for the GT.CM database. */
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_NOGTCMDB, 4, LEN_AND_LIT("PEEKBYNAME"), REG_LEN_STR(r_ptr));
+	}
 	/* Figure out the address of each block to return */
 	switch(mnemonic_opcode)
 	{
