@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -21,17 +21,21 @@
 #include <errno.h>
 
 #include "io.h"
+#include "iott_setterm.h"
 #include "parse_file.h"
 #include "zroutines.h"
 #include "eintr_wrappers.h"
 #include "stringpool.h"
-#include "setterm.h"
+#include "tpnotacid_chk_inline.h"
 #include "op.h"
 #include "fork_init.h"
 #include "geteditor.h"
 #include "restrict.h"
 #include "wbox_test_init.h"
 
+
+#define	ZEDITSTR	"ZEDIT"
+
 GBLREF	io_pair		io_std_device;
 GBLREF	mval 		dollar_zsource;
 GBLREF	mstr		editor;
@@ -60,6 +64,8 @@ void op_zedit(mval *v, mval *p)
 	DCL_THREADGBL_ACCESS;
 
 	SETUP_THREADGBL_ACCESS;
+	if (RESTRICTED(zedit_op))
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(3) ERR_RESTRICTEDOP, 1, "ZEDIT");
 	geteditor();
 	if (!editor.len)
 	{
@@ -171,13 +177,10 @@ void op_zedit(mval *v, mval *p)
 			es[ path_len ] = 0;
 		}
 	}
-
-	if (RESTRICTED(zedit_op))
-		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(3) ERR_RESTRICTEDOP, 1, "ZEDIT");
-
+	TPNOTACID_CHECK(ZEDITSTR);
 	flush_pio();
 	if (tt == io_std_device.in->type)
-		resetterm(io_std_device.in);
+		iott_resetterm(io_std_device.in);
 	/* ignore interrupts */
 	sigemptyset(&act.sa_mask);
 	act.sa_flags = 0;
@@ -206,7 +209,7 @@ void op_zedit(mval *v, mval *p)
 		/* restore interrupt handler */
 		sigaction(SIGINT, &intr, 0);
 		if (tt == io_std_device.in->type)
-			setterm(io_std_device.in);
+			iott_setterm(io_std_device.in);
 	} else
 	{
 		if (WBTEST_ENABLED(WBTEST_BADEXEC_OP_ZEDIT))
