@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -160,7 +160,7 @@ void op_zlink (mval *v, mval *quals)
 				obj_file[MAX_FN_LEN + 1],
 				objnamebuf[MAX_FN_LEN + 1],
 				srcnamebuf[MAX_FN_LEN + 1];
-	int			initial_object_file_des, qlf, save_errno, status, tslash;
+	int			initial_object_file_des, qlf, save_errno, status, tslash = 0;
 	linktyp			type;
 	mstr			srcstr, objstr, file;
 	parse_blk		pblk;
@@ -219,8 +219,8 @@ void op_zlink (mval *v, mval *quals)
 		zl_cmd_qlf(&quals->str, &cmd_qlf, srcnamebuf, &srcnamelen, TRUE);
 	objnamelen = MIN(pblk.b_name, MAX_MIDENT_LEN);
 	memcpy(objnamebuf, pblk.l_name, objnamelen);
-	if (!TREF(trigger_compile_and_link) &&
-		(objnamelen - object_name_len) || memcmp(objnamebuf, object_file_name, objnamelen))
+	if ((!TREF(trigger_compile_and_link) && (objnamelen - object_name_len))
+			|| memcmp(objnamebuf, object_file_name, objnamelen))
 	{	/* appear to have an object name that differs from the file name */
 		assert(MAX_MIDENT_LEN >= object_name_len);
 		objnamelen = object_name_len;
@@ -243,7 +243,7 @@ void op_zlink (mval *v, mval *quals)
 				cpy_len = sizeof(objnamebuf) - pblk.b_dir;
 			assert(256 >= cpy_len); /* For Veracode grins */
 			memmove(&objnamebuf[pblk.b_dir], objnamebuf, cpy_len);
-			assert(sizeof(objnamebuf) >= pblk.b_dir);
+			/* assert(sizeof(objnamebuf) >= pblk.b_dir); */		/* Compiler complains that it is always true */
 			memcpy(objnamebuf, file.addr, pblk.b_dir);
 			objnamelen += pblk.b_dir;
 		}
@@ -315,21 +315,27 @@ void op_zlink (mval *v, mval *quals)
 		memcpy(srcnamebuf, pblk.l_name, pblk.b_name);
 		memcpy(&srcnamebuf[pblk.b_name], DOTM, SIZEOF(DOTM));
 		srcnamelen = pblk.b_name + SIZEOF(DOTM) - 1;
-		if ('%' == srcnamebuf[0])
-			srcnamebuf[0] = '_';
+		if (!objnamelen)
+		{
+			objnamelen = pblk.b_name;
+			memcpy(srcnamebuf, pblk.l_name, objnamelen);
+		}
 		assert(MAX_FN_LEN > (objnamelen + SIZEOF(DOTOBJ)));
 		memcpy(&objnamebuf[objnamelen], DOTOBJ, SIZEOF(DOTOBJ));		/* Copies null terminator */
 		objnamelen += (SIZEOF(DOTOBJ) - 1);
+		if ('%' == srcnamebuf[0])
+			srcnamebuf[0] = '_';
 		srcstr.addr = srcnamebuf;
 		srcstr.len = srcnamelen;
 		objstr.addr = objnamebuf;
 		objstr.len = objnamelen;
 		zro_search(&objstr, &objdir, &srcstr, &srcdir, PROBE_SHLIBS);
 		if (NULL == srcdir)
+		{
 			if (NULL == objdir)
 				RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(12) ERR_ZLINKFILE, 2, v->str.len, v->str.addr,
 					ERR_FILENOTFND, 2, srcnamelen, srcnamebuf, ERR_FILENOTFND, 2, objnamelen, objnamebuf);
-		else if (NULL == objdir)
+		} else if (NULL == objdir)
 			type = SRC;
 	}
 	if (OBJ == type)
