@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -48,6 +48,7 @@
 #include "gtmsource.h"
 #include "repl_instance.h"
 #include "util.h"		/* For OUT_BUFF_SIZE */
+#include "hugetlbfs_overrides.h"
 
 GBLREF	jnlpool_addrs_ptr_t	jnlpool;
 GBLREF	jnlpool_addrs_ptr_t	jnlpool_head;
@@ -58,8 +59,6 @@ GBLREF 	gtmrecv_options_t	gtmrecv_options;
 GBLREF	gd_region		*gv_cur_region;
 GBLREF	repl_conn_info_t	*this_side, *remote_side;
 GBLREF	int4			strm_index;
-GBLREF	char			repl_instfilename[MAX_FN_LEN + 1];	/* save first instance */
-GBLREF	char			repl_inst_name[MAX_INSTNAME_LEN];	/* for syslog */
 
 LITREF	char			gtm_release_name[];
 LITREF	int4			gtm_release_name_len;
@@ -140,8 +139,8 @@ void recvpool_init(recvpool_user pool_user, boolean_t gtmrecv_startup)
 	}
 	udi = FILE_INFO(reg);
 	assert((tmp_jnlpool && (recvpool.recvpool_dummy_reg != tmp_jnlpool->jnlpool_dummy_reg))
-		|| (!tmp_jnlpool && (NULL != recvpool.recvpool_dummy_reg)
-		|| ((reg->dyn.addr->fname_len == full_len) && !STRCMP(reg->dyn.addr->fname, instfilename))));
+		|| ((!tmp_jnlpool && (NULL != recvpool.recvpool_dummy_reg))
+			|| ((reg->dyn.addr->fname_len == full_len) && !STRCMP(reg->dyn.addr->fname, instfilename))));
 	if ((NULL == tmp_jnlpool) || (recvpool.recvpool_dummy_reg != tmp_jnlpool->jnlpool_dummy_reg))
 	{	/* Fill in fields only if this is the first time this process is opening the replication instance file */
 		memcpy((char *)reg->dyn.addr->fname, instfilename, full_len);
@@ -309,7 +308,7 @@ void recvpool_init(recvpool_user pool_user, boolean_t gtmrecv_startup)
 	if (new_ipc)
 	{	/* create new shared memory */
 		if (-1 == (udi->shmid = recvpool_shmid =
-				gtm_shmget(IPC_PRIVATE, gtmrecv_options.buffsize, IPC_CREAT | RWDALL, TRUE)))
+				gtm_shmget(IPC_PRIVATE, gtmrecv_options.buffsize, IPC_CREAT | RWDALL, TRUE, JOURNAL_POOL, udi->fn)))
 		{
 			udi->shmid = recvpool_shmid = INVALID_SHMID;
 			save_errno = errno;
@@ -551,10 +550,5 @@ void recvpool_init(recvpool_user pool_user, boolean_t gtmrecv_startup)
 			RTS_ERROR_LITERAL("Error with receive pool options semaphore"), save_errno);
 	}
 	jnlpool = save_jnlpool;
-	if (('\0' == repl_inst_name[0]) && ('\0' != repl_instfilename[0]))
-	{	/* fill in instance name for syslog if right instance file name and first */
-		if (0 == STRCMP(repl_instfilename, instfilename))
-			memcpy(repl_inst_name, repl_instance.inst_info.this_instname, MAX_INSTNAME_LEN);
-	}
 	return;
 }
