@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2010, 2013 Fidelity Information Services, Inc	*
+ * Copyright (c) 2010-2020 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -23,13 +24,12 @@
 #include "mv_stent.h"			/* for COPY_SUBS_TO_GVCURRKEY macro */
 #include "gvsub2str.h"			/* for COPY_SUBS_TO_GVCURRKEY */
 #include "format_targ_key.h"		/* for COPY_SUBS_TO_GVCURRKEY */
-#include "targ_alloc.h"			/* for SET_GVTARGET_TO_HASHT_GBL & SWITCH_TO_DEFAULT_REGION */
+#include "targ_alloc.h"			/* for SET_GVTARGET_TO_HASHT_GBL */
 #include "filestruct.h"			/* for INITIAL_HASHT_ROOT_SEARCH_IF_NEEDED (FILE_INFO) */
 #include "mvalconv.h"
 #include "gdscc.h"			/* needed for tp.h */
 #include "gdskill.h"			/* needed for tp.h */
 #include "buddy_list.h"			/* needed for tp.h */
-#include "hashtab_int4.h"		/* needed for tp.h */
 #include "jnl.h"			/* needed for tp.h */
 #include "tp.h"				/* for sgm_info */
 #include "tp_frame.h"
@@ -42,22 +42,26 @@
 #include "gtmimagename.h"
 #include "trigger_fill_xecute_buffer.h"
 #include "trigger_gbl_fill_xecute_buffer.h"
+#include "gtm_trigger_trc.h"
+#include "repl_msg.h"
+#include "gtmsource.h"			/* for jnlpool_addrs_ptr_t */
 
 GBLREF	sgmnt_data_ptr_t	cs_data;
 GBLREF	sgmnt_addrs		*cs_addrs;
+GBLREF	int4			gtm_trigger_depth;
 GBLREF	gv_key			*gv_currkey;
 GBLREF	gd_region		*gv_cur_region;
-GBLREF	sgm_info		*sgm_info_ptr;
 GBLREF	gv_namehead		*gv_target;
+#ifdef DEBUG
+GBLREF	boolean_t		is_updproc;
+#endif
+GBLREF	jnlpool_addrs_ptr_t	jnlpool;
+GBLREF	sgm_info		*sgm_info_ptr;
 GBLREF	boolean_t		skip_INVOKE_RESTART;
 GBLREF	int			tprestart_state;
-GBLREF	int4			tstart_trigger_depth;
-GBLREF	int4			gtm_trigger_depth;
 GBLREF	tp_frame		*tp_pointer;
+GBLREF	int4			tstart_trigger_depth;
 
-LITREF	mval			literal_hasht;
-
-error_def(ERR_TRIGNAMBAD);
 error_def(ERR_TPRETRY);
 
 STATICFNDCL CONDITION_HANDLER(trigger_fill_xecute_buffer_ch);
@@ -112,10 +116,12 @@ int trigger_fill_xecute_buffer(gv_trigger_t *trigdsc)
 		|| (tp_pointer->implicit_tstart && tp_pointer->implicit_trigger
 		&& (tstart_trigger_depth != gtm_trigger_depth)))	/* Case 3 */
 	{	/* Test for Case 3/4 where we get to do very little: */
+		DBGTRIGR((stderr, "trigger_fill_xecute_buffer: Case 2/3\n"));
 		assert((!tp_pointer->implicit_trigger) || (0 < gtm_trigger_depth));
 		trigger_fill_xecute_buffer_read_trigger_source(trigdsc);
 	} else
 	{	/* Test for Case 1 where we only need a condition handler */
+		DBGTRIGR((stderr, "trigger_fill_xecute_buffer: Case 1\n"));
 		assert(tp_pointer->implicit_tstart && tp_pointer->implicit_trigger);
 		assert(tstart_trigger_depth == gtm_trigger_depth);
 		ESTABLISH_RET(trigger_fill_xecute_buffer_ch, SIGNAL);
@@ -142,15 +148,18 @@ STATICFNDEF void trigger_fill_xecute_buffer_read_trigger_source(gv_trigger_t *tr
 	gv_namehead		*save_gv_target;
 	gd_region		*save_gv_cur_region;
 	sgm_info		*save_sgm_info_ptr;
-	gv_key			save_currkey[DBKEYALLOC(MAX_KEY_SZ)];
+	jnlpool_addrs_ptr_t	save_jnlpool;
+	gv_key_buf		save_currkey;
 
 	assert(0 < dollar_tlevel);
 	assert(NULL != trigdsc);
-	SAVE_TRIGGER_REGION_INFO(save_currkey);
+	SAVE_REGION_INFO(save_currkey, save_gv_target, save_gv_cur_region, save_sgm_info_ptr, save_jnlpool);
 
 	gvt_trigger = trigdsc->gvt_trigger;			/* We now know our base block now */
 	index = trigdsc - gvt_trigger->gv_trig_array + 1;	/* We now know our trigger index value */
 	i2mval(&trig_index, index);
+	DBGTRIGR((stderr, "trigger_fill_xecute_buffer_read_trigger_source: entry $tlevel:%d\tindex:%d of %d\n",
+				dollar_tlevel, index, gvt_trigger->num_gv_triggers));
 	gvt = gv_target = gvt_trigger->gv_target;		/* gv_target contains global name */
 	gbl.addr = gvt->gvname.var_name.addr;
 	gbl.len = gvt->gvname.var_name.len;
@@ -169,14 +178,16 @@ STATICFNDEF void trigger_fill_xecute_buffer_read_trigger_source(gv_trigger_t *tr
 	/* See if we need to reload our triggers */
 	if ((csa->db_trigger_cycle != gvt->db_trigger_cycle)
 	    || (csa->db_dztrigger_cycle && (gvt->db_dztrigger_cycle != csa->db_dztrigger_cycle)))
-	{       /* The process' view of the triggers could be potentially stale. Restart to be safe.
-		 * Triggers can be invoked only by GT.M and Update process. Out of these, we expect only
-		 * GT.M to see restarts due to concurrent trigger changes. Update process is the only
-		 * updater on the secondary so we dont expect it to see any concurrent trigger changes
-		 * Assert accordingly.
+	{       /* The process' view of the triggers is likely stale. Restart to be safe.
+		 * Triggers can be invoked only by GT.M and Update process. We expect to see GT.M processes to
+		 * restart due to concurrent trigger changes. The Update Process should only restart if it is a
+		 * supplementary instance. Assert accordingly. Note similar asserts occur in t_end.c and
+		 * tp_tend.c.
 		 */
+		DBGTRIGR((stderr, "trigger_fill_xecute_buffer_read_trigger_source: stale trigger view\n"));
 		assert(CDB_STAGNATE > t_tries);
-		assert(IS_GTM_IMAGE);
+		assert(!is_updproc || (jnlpool && jnlpool->repl_inst_filehdr->is_supplementary
+					&& !jnlpool->jnlpool_ctl->upd_disabled));
 		t_retry(cdb_sc_triggermod);
 	}
 	SET_GVTARGET_TO_HASHT_GBL(csa);
@@ -185,7 +196,7 @@ STATICFNDEF void trigger_fill_xecute_buffer_read_trigger_source(gv_trigger_t *tr
 	xecute_buff.addr = trigger_gbl_fill_xecute_buffer(gbl.addr, gbl.len, &trig_index, NULL, (int4 *)&xecute_buff.len);
 	trigdsc->xecute_str.str = xecute_buff;
 	/* Restore gv_target/gv_currkey which need to be kept in sync */
-	RESTORE_TRIGGER_REGION_INFO(save_currkey);
+	RESTORE_REGION_INFO(save_currkey, save_gv_target, save_gv_cur_region, save_sgm_info_ptr, save_jnlpool);
 	return;
 }
 #endif /* GTM_TRIGGER */
