@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2011-2018 Fidelity National Information	*
+ * Copyright (c) 2011-2020 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -27,7 +27,6 @@
 #include "gdscc.h"			/* needed for tp.h */
 #include "gdskill.h"			/* needed for tp.h */
 #include "buddy_list.h"			/* needed for tp.h */
-#include "hashtab_int4.h"		/* needed for tp.h */
 #include "jnl.h"			/* needed for tp.h */
 #include "tp.h"
 #include "op.h"
@@ -87,7 +86,7 @@ int trigger_locate_andor_load(mstr *trigname, rhdtyp **rtn_vec)
 	mstr			regname, gbl;
 	mident			rtn_name;
 	gd_region		*save_gv_cur_region;
-	gv_key			save_currkey[DBKEYALLOC(MAX_KEY_SZ)];
+	gv_key_buf		save_currkey;
 	gv_namehead		*gvt;
 	gv_namehead		*save_gv_target;
 	gvnh_reg_t		*gvnh_reg;
