@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2013-2018 Fidelity National Information	*
+ * Copyright (c) 2013-2021 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -55,8 +55,8 @@ void util_help(void)
 	assert(1 >= TREF(parms_cnt));
 	assert(GTM_IMAGE < image_type && UTIL_HELP_IMAGES > image_type);
 	if (!gtm_dist_ok_to_use)
-		rts_error_csa(CSA_ARG(NULL) VARLSTCNT(6) ERR_GTMDISTUNVERIF, 4, LEN_AND_STR(gtm_dist),
-				gtmImageNames[image_type].imageNameLen, gtmImageNames[image_type].imageName);
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(6) ERR_GTMDISTUNVERIF, 4, LEN_AND_STR(gtm_dist),
+			gtmImageNames[image_type].imageNameLen, gtmImageNames[image_type].imageName);
 	if (0 == TREF(parms_cnt))
 		help_option = utilImageGLDs[INVALID_IMAGE];
 	else
@@ -75,4 +75,3 @@ void util_help(void)
 	if (0 != rc)
 		rts_error_csa(NULL, VARLSTCNT(5) ERR_TEXT, 2, RTS_ERROR_TEXT("HELP command error"), rc);
 }
-
