@@ -1,6 +1,6 @@
  /****************************************************************
  *								*
- * Copyright (c) 2001-2022 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -66,8 +66,12 @@ GBLREF	recvpool_addrs		recvpool;
 GBLREF	sigset_t		block_sigsent;
 GBLREF	uint4			is_updhelper, process_id;
 GBLREF	VSIG_ATOMIC_T		forced_exit;
+GBLREF	char			repl_instfilename[MAX_FN_LEN + 1];
+GBLREF	char			repl_inst_name[];
+GBLREF	gd_addr			*repl_inst_from_gld;
 
 error_def(ERR_REPLINSTACC);
+error_def(ERR_SOCKHANGUP);
 error_def(ERR_TERMHANGUP);
 error_def(ERR_TEXT);
 
@@ -182,10 +186,10 @@ caddr_t util_format(caddr_t message, va_list fao, caddr_t buff, ssize_t size, in
 	unsigned char	uchar;
 	short		sshort, *s;
 	unsigned short	ushort;
-	int		i, nexti, length, field_width, repeat_count, int_val, chwidth, orig_chwidth, cwidth;
+	int		i, nexti, length, field_width, repeat_count, int_val = 0, chwidth = -1, orig_chwidth, cwidth;
 	unsigned int	ch;
-	UINTPTR_T	addr_val;
-	ssize_t		chlen;
+	UINTPTR_T	addr_val = 0;
+	ssize_t		chlen = -1;
 	uint4		stringlength;
 	boolean_t	indirect;
 	qw_num_ptr_t	val_ptr;
@@ -213,13 +217,18 @@ caddr_t util_format(caddr_t message, va_list fao, caddr_t buff, ssize_t size, in
 		prefix_len = (NULL == prefix) ? 0 : STRLEN((char *)prefix);
 		line_begin = (TREF(util_outptr) == TREF(util_outbuff_ptr));
 	} else
+	{
 		prefix = NULL;
+		prefix_len = -1;
+		line_begin = FALSE;
+	}
 	outptr = buff;
 	outtop = outptr + size - 5;	/* 5 bytes to prevent writing across border */
 	while (outptr < outtop)
 	{
 		if ((NULL != prefix) && line_begin)
 		{
+			assert(-1 != prefix_len);
 			if ((outptr + prefix_len + 3) >= outtop)
 				break;
 			memcpy(outptr, prefix, prefix_len);
@@ -394,6 +403,7 @@ caddr_t util_format(caddr_t message, va_list fao, caddr_t buff, ssize_t size, in
 				{
 					if (!gtm_utf8_mode)
 					{
+						assert(0 <= chlen);
 						ch = *c;
 						isprintable = ((' ' <= ch) || ('~' >= ch)); /* Ignored in M mode for FAO !AD */
 					} else
@@ -427,7 +437,7 @@ caddr_t util_format(caddr_t message, va_list fao, caddr_t buff, ssize_t size, in
 					 */
 					assert((c + chlen) <= ctop);
 					assert(0 < chlen);
-					assert((0 < chwidth) || (0 == chwidth) && gtm_utf8_mode);
+					assert((0 < chwidth) || ((0 == chwidth) && gtm_utf8_mode));
 					nexti = i + chwidth;
 					if (nexti > cwidth)	/* adding next input char will cross requested width */
 						break;
@@ -680,7 +690,7 @@ void	util_out_send_oper(char *addr, unsigned int len)
 	intrpt_state_t		prev_intrpt_state;
 
 	assert(IS_PTHREAD_LOCKED_AND_HOLDER);
-	if (first_syslog)
+	if (first_syslog)		/* note: utilities may reset this */
 	{
 		first_syslog = FALSE;
 
@@ -732,6 +742,9 @@ void	util_out_send_oper(char *addr, unsigned int len)
 		{	/* Read instace file name from jnlpool */
 			INSERT_MARKER;
 			BUILD_FACILITY((char *)jnlpool->repl_inst_filehdr->inst_info.this_instname);
+			assert((!IS_GTM_IMAGE) || ('\0' == repl_inst_name[0]));
+			memcpy(repl_inst_name, jnlpool->repl_inst_filehdr->inst_info.this_instname, MAX_INSTNAME_LEN);
+			repl_inst_from_gld = (jnlpool->gd_instinfo) ? jnlpool->gd_ptr : NULL;	/* for gtmpcat */
 		} else
 		{	/* Read instance name from instance file */
 			fn_len = &file_name_len;
@@ -753,6 +766,12 @@ void	util_out_send_oper(char *addr, unsigned int len)
 					{
 						INSERT_MARKER;
 						BUILD_FACILITY((char *)replhdr.inst_info.this_instname);
+						assert((!IS_GTM_IMAGE) || ('\0' == repl_inst_name[0]));
+						memcpy(repl_inst_name, replhdr.inst_info.this_instname, MAX_INSTNAME_LEN);
+						if (inst_from_gld)
+							repl_inst_from_gld = gd_header;	/* got from global directory */
+						if ('\0' == repl_instfilename[0])
+							memcpy(repl_instfilename, fn, *fn_len + 1);	/* include null */
 					}
 					CLOSEFILE_RESET(fd, status);
 				}
@@ -967,7 +986,8 @@ void util_cond_flush(void)
 	SETUP_THREADGBL_ACCESS;
 	ASSERT_SAFE_TO_UPDATE_THREAD_GBLS;
 	assert(((int)ERR_TERMHANGUP != SIGNAL) || ((tt == io_std_device.in->type) && prin_in_dev_failure));
-	if ((TREF(util_outptr) != TREF(util_outbuff_ptr)) && ((int)ERR_TERMHANGUP != SIGNAL))	/* if a PRINCIPAL device terminal */
+	if ((TREF(util_outptr) != TREF(util_outbuff_ptr)) && (((int)ERR_TERMHANGUP != SIGNAL) && ((int)ERR_SOCKHANGUP != SIGNAL)))
+						/* if a PRINCIPAL device terminal */
 		util_out_print(NULL, FLUSH);	/* disappeared, sending stuff to it with a PRN_ERROR just complicates things */
 }
 
