@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2001-2021 Fidelity National Information	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -89,75 +89,85 @@ MBSTART {										\
 		INCR_GVSTATS_COUNTER(CSA, CNL, n_jrec_epoch_idle, 1);			\
 } MBEND
 
-#define	WAIT_FOR_CONCURRENT_WRITERS_TO_FINISH(FIX_IN_WTSTART, WAS_CRIT, REG, CSA, CNL)					\
-MBSTART {														\
-	unsigned int		lcnt;											\
-        struct shmid_ds         shm_buf;										\
-	int			save_errno;										\
-															\
-	GTM_WHITE_BOX_TEST(WBTEST_BUFOWNERSTUCK_STACK, (CNL->in_wtstart), 1);						\
-	if (WRITERS_ACTIVE(CNL))											\
-	{														\
-		DEBUG_ONLY(int4	in_wtstart;) 		/* temporary for debugging purposes */				\
-		DEBUG_ONLY(int4	intent_wtstart;) 	/* temporary for debugging purposes */				\
-															\
-		assert(CSA->now_crit);											\
-		SIGNAL_WRITERS_TO_STOP(CNL);		/* to stop all active writers */				\
-		lcnt = 0;												\
-		do													\
-		{													\
-			DEBUG_ONLY(in_wtstart = CNL->in_wtstart;)							\
-			DEBUG_ONLY(intent_wtstart = CNL->intent_wtstart;)						\
-			GTM_WHITE_BOX_TEST(WBTEST_BUFOWNERSTUCK_STACK, lcnt, (MAXGETSPACEWAIT * 2) - 1);		\
-			GTM_WHITE_BOX_TEST(WBTEST_BUFOWNERSTUCK_STACK, CNL->wtstart_pid[0], process_id);		\
-			if (MAXGETSPACEWAIT DEBUG_ONLY( * 2) == ++lcnt)							\
-			{	/* We have noticed the below assert to fail occasionally on some platforms (mostly	\
-				 * AIX and Linux). We suspect it is because of waiting for another writer that is 	\
-				 * in jnl_fsync (as part of flushing a global buffer) which takes more than a minute	\
-				 * to finish. To avoid false failures (where the other writer finishes its job in	\
-				 * a little over a minute) we wait for twice the time in the debug version.		\
-				 */											\
-				GET_C_STACK_MULTIPLE_PIDS("WRITERSTUCK", CNL->wtstart_pid, MAX_WTSTART_PID_SLOTS, 1);	\
-				assert((gtm_white_box_test_case_enabled)						\
-					&& ((WBTEST_BUFOWNERSTUCK_STACK == gtm_white_box_test_case_number)		\
-						|| (WBTEST_SLEEP_IN_WCS_WTSTART == gtm_white_box_test_case_number)	\
-						|| (WBTEST_DB_WRITE_HANG == gtm_white_box_test_case_number)		\
-						|| (WBTEST_EXPECT_IO_HANG == gtm_white_box_test_case_number)));		\
-				CNL->wcsflu_pid = 0;									\
-				SIGNAL_WRITERS_TO_RESUME(CNL);								\
-				if (!WAS_CRIT)										\
-					rel_crit(REG);									\
-				/* Disable white box testing after the first time the					\
-				WBTEST_BUFOWNERSTUCK_STACK mechanism has kicked in. This is because as			\
-				part of the exit handling process, the control once agin comes to wcs_flu		\
-				and at that time we do not want the WBTEST_BUFOWNERSTUCK_STACK white box		\
-				mechanism to kick in.*/									\
-				GTM_WHITE_BOX_TEST(WBTEST_BUFOWNERSTUCK_STACK, gtm_white_box_test_case_enabled, FALSE);	\
-				send_msg_csa(CSA_ARG(CSA) VARLSTCNT(5) ERR_WRITERSTUCK, 3, CNL->in_wtstart,		\
-						DB_LEN_STR(REG));							\
-				return FALSE;										\
-			}												\
-			if (-1 == shmctl(udi->shmid, IPC_STAT, &shm_buf))						\
-			{												\
-				save_errno = errno;									\
-				if (1 == lcnt)										\
-				{											\
-					send_msg_csa(CSA_ARG(CSA) VARLSTCNT(4) ERR_DBFILERR, 2,				\
-							DB_LEN_STR(REG));						\
-					send_msg_csa(CSA_ARG(CSA) VARLSTCNT(8) ERR_SYSCALL, 5,				\
-							RTS_ERROR_LITERAL("shmctl()"), CALLFROM, save_errno);		\
-				} 											\
-			} else if (1 == shm_buf.shm_nattch)								\
-			{												\
-				assert((FALSE == CSA->in_wtstart) && (0 <= CNL->in_wtstart));				\
-				CNL->in_wtstart = 0;	/* fix improper value of in_wtstart if you are standalone */	\
-				FIX_IN_WTSTART = TRUE;									\
-				CNL->intent_wtstart = 0;/* fix improper value of intent_wtstart if standalone */	\
-			} else												\
-				wcs_sleep(lcnt);		/* wait for any in wcs_wtstart to finish */		\
-		} while (WRITERS_ACTIVE(CNL));										\
-		SIGNAL_WRITERS_TO_RESUME(CNL);										\
-	}														\
+#define	WAIT_FOR_CONCURRENT_WRITERS_TO_FINISH(FIX_IN_WTSTART, WAS_CRIT, REG, CSA, CNL)						\
+MBSTART {															\
+	unsigned int		lcnt;												\
+        struct shmid_ds         shm_buf;											\
+	int			i, msgcnt, save_errno;										\
+	pid_t			pid;												\
+																\
+	GTM_WHITE_BOX_TEST(WBTEST_BUFOWNERSTUCK_STACK, (CNL->in_wtstart), 1);							\
+	if (WRITERS_ACTIVE(CNL))												\
+	{															\
+		DEBUG_ONLY(int4	in_wtstart;) 		/* temporary for debugging purposes */					\
+		DEBUG_ONLY(int4	intent_wtstart;) 	/* temporary for debugging purposes */					\
+																\
+		assert(CSA->now_crit);												\
+		SIGNAL_WRITERS_TO_STOP(CNL);		/* to stop all active writers */					\
+		lcnt = 0;													\
+		do														\
+		{														\
+			DEBUG_ONLY(in_wtstart = CNL->in_wtstart;)								\
+			DEBUG_ONLY(intent_wtstart = CNL->intent_wtstart;)							\
+			GTM_WHITE_BOX_TEST(WBTEST_BUFOWNERSTUCK_STACK, lcnt, (MAXGETSPACEWAIT * 2) - 1);			\
+			GTM_WHITE_BOX_TEST(WBTEST_BUFOWNERSTUCK_STACK, CNL->wtstart_pid[0], process_id);			\
+			if (MAXGETSPACEWAIT DEBUG_ONLY( * 2) == ++lcnt)								\
+			{	/* We have noticed the below assert to fail occasionally on some platforms (mostly		\
+				 * AIX and Linux). We suspect it is because of waiting for another writer that is 		\
+				 * in jnl_fsync (as part of flushing a global buffer) which takes more than a minute		\
+				 * to finish. To avoid false failures (where the other writer finishes its job in		\
+				 * a little over a minute) we wait for twice the time in the debug version.			\
+				 */												\
+				GET_C_STACK_MULTIPLE_PIDS("WRITERSTUCK", CNL->wtstart_pid, MAX_WTSTART_PID_SLOTS, 1);		\
+				assert((gtm_white_box_test_case_enabled)							\
+					&& ((WBTEST_BUFOWNERSTUCK_STACK == gtm_white_box_test_case_number)			\
+						|| (WBTEST_SLEEP_IN_WCS_WTSTART == gtm_white_box_test_case_number)		\
+						|| (WBTEST_DB_WRITE_HANG == gtm_white_box_test_case_number)			\
+						|| (WBTEST_EXPECT_IO_HANG == gtm_white_box_test_case_number)));			\
+				CNL->wcsflu_pid = 0;										\
+				SIGNAL_WRITERS_TO_RESUME(CNL);									\
+				if (!WAS_CRIT)											\
+					rel_crit(REG);										\
+				/* Disable white box testing after the first time the						\
+				WBTEST_BUFOWNERSTUCK_STACK mechanism has kicked in. This is because as				\
+				part of the exit handling process, the control once agin comes to wcs_flu			\
+				and at that time we do not want the WBTEST_BUFOWNERSTUCK_STACK white box			\
+				mechanism to kick in.*/										\
+				GTM_WHITE_BOX_TEST(WBTEST_BUFOWNERSTUCK_STACK, gtm_white_box_test_case_enabled, FALSE);		\
+				for (msgcnt = i = 0; (MAX_WTSTART_PID_SLOTS > i) && (CNL->in_wtstart >= msgcnt); i++)		\
+				{												\
+					if (0 == (pid = CNL->wtstart_pid[i]))							\
+						continue;									\
+					send_msg_csa(CSA_ARG(CSA) VARLSTCNT(7) ERR_WRITERSTUCK, 5, pid,	msgcnt + 1,		\
+							CNL->in_wtstart, DB_LEN_STR(REG));					\
+					msgcnt++;										\
+				}												\
+				return FALSE;											\
+			}													\
+			if (-1 == shmctl(udi->shmid, IPC_STAT, &shm_buf))							\
+			{													\
+				save_errno = errno;										\
+				if (1 == lcnt)											\
+				{												\
+					send_msg_csa(CSA_ARG(CSA) VARLSTCNT(4) ERR_DBFILERR, 2,					\
+							DB_LEN_STR(REG));							\
+					send_msg_csa(CSA_ARG(CSA) VARLSTCNT(8) ERR_SYSCALL, 5,					\
+							RTS_ERROR_LITERAL("shmctl()"), CALLFROM, save_errno);			\
+				} 												\
+			} else if (1 == shm_buf.shm_nattch)									\
+			{													\
+				assert((FALSE == CSA->in_wtstart) && (0 <= CNL->in_wtstart));					\
+				CNL->in_wtstart = 0;	/* fix improper value of in_wtstart if you are standalone */		\
+				FIX_IN_WTSTART = TRUE;										\
+				CNL->intent_wtstart = 0;/* fix improper value of intent_wtstart if standalone */		\
+			} else													\
+			{													\
+				INCR_GVSTATS_COUNTER(CSA, CNL, ms_flu_critsleeps, (MAXSLPTIME < lcnt ? MAXSLPTIME : lcnt));	\
+				wcs_sleep(lcnt);		/* wait for any in wcs_wtstart to finish */			\
+			}													\
+		} while (WRITERS_ACTIVE(CNL));											\
+		SIGNAL_WRITERS_TO_RESUME(CNL);											\
+	}															\
 } MBEND
 
 #define REL_CRIT_BEFORE_RETURN(CNL, REG)	\
@@ -211,10 +221,10 @@ boolean_t wcs_flu(uint4 options)
 	boolean_t		latch_salvaged;
 	unsigned int		lcnt, pass;
 	int			n_bts, save_errno, wtstart_or_wtfini_errno;
-	jnl_buffer_ptr_t	jb;
+	jnl_buffer_ptr_t	jb = NULL;
 	jnl_private_control	*jpc;
 	uint4			jnl_status, to_wait, to_msg;
-	unix_db_info    	*udi;
+	unix_db_info		*udi;
 	sgmnt_addrs		*csa;
 	sgmnt_data_ptr_t	csd;
 	node_local_ptr_t	cnl;
@@ -226,7 +236,9 @@ boolean_t wcs_flu(uint4 options)
 #	ifdef DEBUG
 	int			wcs_wip_lvl, wcs_active_lvl, wc_in_free; /* copy of cnl noted down for debugging purposes */
 #	endif
+	DCL_THREADGBL_ACCESS;
 
+	SETUP_THREADGBL_ACCESS;
 	jnl_status = 0;
 	flush_hdr = options & WCSFLU_FLUSH_HDR;
 	write_epoch = options & WCSFLU_WRITE_EPOCH;
@@ -347,9 +359,10 @@ boolean_t wcs_flu(uint4 options)
 	if (jnl_enabled)
 	{
 		assert(SS_NORMAL == jnl_status);
+		assert(jb);
 		cnl->doing_epoch = sync_epoch || write_epoch;
 		epoch_already_current = (!force_epoch && (jb->post_epoch_freeaddr == jb->rsrv_freeaddr));
-		if (return_early = (speedup_nobefore && !csd->jnl_before_image))
+		if ((return_early = (speedup_nobefore && !csd->jnl_before_image)))
 		{	/* Finish easiest option first. This database has NOBEFORE image journaling and caller has asked for
 			 * processing to be speeded up in that case. Write only an epoch record, don't do heavyweight flush or fsync
 			 * of db.This will avoid bunching of IO at the epoch time like is the case with before-image journaling
@@ -403,7 +416,8 @@ boolean_t wcs_flu(uint4 options)
 			REL_CRIT_BEFORE_RETURN(cnl, reg);
 			return TRUE;
 		}
-	}
+	} else
+		epoch_already_current = FALSE;
 	BG_TRACE_ANY(csa, total_buffer_flush);
 	INCR_GVSTATS_COUNTER(csa, cnl, n_db_flush, 1);
 	cnl->wcsflu_pid = process_id;
@@ -589,6 +603,7 @@ boolean_t wcs_flu(uint4 options)
 						case WBTEST_BG_UPDATE_DBCSHGETN_INVALID2:
 						case WBTEST_BG_UPDATE_PHASE2FAIL:
 						case WBTEST_CRASH_SHUTDOWN_EXPECTED:
+						case WBTEST_EXPECT_IO_HANG:
 						case WBTEST_FORCE_WCS_GET_SPACE_CACHEVRFY:
 						case WBTEST_MURUNDOWN_KILLCMT06:
 						case WBTEST_WCS_FLU_IOERR:
@@ -621,7 +636,7 @@ boolean_t wcs_flu(uint4 options)
 						send_msg_csa(CSA_ARG(csa) VARLSTCNT(5) ERR_WCSFLUFAIL, 3, CALLFROM);
 						return FALSE;
 					}
-					assert(!jnl_enabled || jb->fsync_dskaddr == jb->rsrv_freeaddr);
+					assert(!jnl_enabled || (jb && (jb->fsync_dskaddr == jb->rsrv_freeaddr)));
 					assert(0 == wtstart_or_wtfini_errno);
 					wcs_recover(reg);
 					if (jnl_enabled)
@@ -693,6 +708,7 @@ boolean_t wcs_flu(uint4 options)
 		 * The next call to jnl_qio_start will do the fsync of the db before doing any jnl qio.
 		 * The basic requirement is that we shouldn't write the epoch out until we have synced the database.
 		 */
+		assert(jb);
 #		ifdef DEBUG
 		if (!gtm_white_box_test_case_enabled || (WBTEST_JNL_FILE_LOST_DSKADDR != gtm_white_box_test_case_number))
 		{
@@ -730,6 +746,8 @@ boolean_t wcs_flu(uint4 options)
 				}
 			}
 		}
+		if (1 < lcnt)
+			INCR_GVSTATS_COUNTER(csa, cnl, ms_flu_critsleeps, ((lcnt - 1) * SLEEP_JNLQIOLOCKWAIT));
 		if (csd->jnl_before_image && !epoch_already_current)
 			jb->need_db_fsync = TRUE;	/* for comments on need_db_fsync, see jnl_output_sp.c */
 		/* else the journal files do not support before images and hence can only be used for forward recovery. So skip
