@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- * Copyright (c) 2007-2020 Fidelity National Information	*
+ * Copyright (c) 2007-2024 Fidelity National Information	*
  * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
@@ -52,11 +52,12 @@ GBLREF	int			num_additional_processors;
 GBLREF	uint4			process_id;
 GBLREF	boolean_t		multi_proc_in_use;
 
-error_def(ERR_DBFILERR);
-error_def(ERR_WAITDSKSPACE);
-error_def(ERR_GBLOFLOW);
 error_def(ERR_BUFSPCDELAY);
 error_def(ERR_BUFOWNERSTUCK);
+error_def(ERR_DBFILERR);
+error_def(ERR_GBLOFLOW);
+error_def(ERR_SPCFCBUFDELAY);
+error_def(ERR_WAITDSKSPACE);
 
 #define	WCS_CONFLICT_TRACE_ARRAYSIZE	64
 #define	LCNT_INTERVAL			DIVIDE_ROUND_UP(UNIX_GETSPACEWAIT, WCS_CONFLICT_TRACE_ARRAYSIZE)
@@ -74,8 +75,8 @@ error_def(ERR_BUFOWNERSTUCK);
 	if (TREF(gtm_environment_init) DEBUG_ONLY(&& !(gtm_white_box_test_case_enabled					\
 				&& ((WBTEST_JNL_FILE_LOST_DSKADDR == gtm_white_box_test_case_number)			\
 					|| (WBTEST_DB_WRITE_HANG == gtm_white_box_test_case_number)			\
-					|| (WBTEST_EXPECT_IO_HANG == gtm_white_box_test_case_number))			\
-					|| (WBTEST_FORCE_WCS_GET_SPACE_CACHEVRFY == gtm_white_box_test_case_number))))	\
+					|| (WBTEST_EXPECT_IO_HANG == gtm_white_box_test_case_number)			\
+					|| (WBTEST_FORCE_WCS_GET_SPACE_CACHEVRFY == gtm_white_box_test_case_number)))))	\
 		gtm_fork_n_core();	/* take a snapshot in case running in-house */					\
 	return FALSE;													\
 }
@@ -104,13 +105,13 @@ error_def(ERR_BUFOWNERSTUCK);
 /* go after a specific number of buffers or a particular buffer */
 boolean_t wcs_get_space(gd_region *reg, int needed, cache_rec_ptr_t cr)
 {
+	static wcs_conflict_trace_t	wcs_conflict_trace[WCS_CONFLICT_TRACE_ARRAYSIZE];
 	sgmnt_addrs		*csa;
 	sgmnt_data_ptr_t	csd;
-	node_local_ptr_t        cnl;
+	node_local_ptr_t	cnl;
 	cache_que_head_ptr_t	q0, base, crwipq = NULL;
 	int4			count, dummy_errno, flsh_trigger, i, k, max_count, n, save_errno = 0;
-	uint4			lcnt, size, to_wait, to_msg, this_idx;
-	wcs_conflict_trace_t	wcs_conflict_trace[WCS_CONFLICT_TRACE_ARRAYSIZE];
+	uint4			lcnt, size, to_wait = 0, to_msg, this_idx;
 	cache_rec		cr_contents;
 	boolean_t		asyncio, ret;
 	int			curr_wc_in_free;
@@ -214,7 +215,12 @@ boolean_t wcs_get_space(gd_region *reg, int needed, cache_rec_ptr_t cr)
 		for (lcnt = 1; 0 != cr->dirty; ++lcnt)
 		{
 			if (0 == (lcnt % UNIX_GETSPACEWAIT))
-				send_msg_csa(CSA_ARG(csa) VARLSTCNT(5) ERR_BUFSPCDELAY, 3, needed, REG_LEN_STR(reg));
+			{
+				send_msg_csa(CSA_ARG(csa) VARLSTCNT(6) ERR_SPCFCBUFDELAY, 4, &(cr->blk), DB_LEN_STR(reg), cr->epid);
+				if (cr->dirty && cr->epid && !is_proc_alive(cr->epid, 0))
+					return FALSE;
+				INVOKE_C_STACK_APPROPRIATE(cr, csa, lcnt);
+			}
 			if (0 == (lcnt % LCNT_INTERVAL))
 			{
 				this_idx = (lcnt / LCNT_INTERVAL);
