@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -28,8 +29,7 @@ static char rcsid[] = "$Header:$";
 
 
 int
-gtcm_term(sig)
-    int		 sig;
+gtcm_term(int sig)
 {
     extern int	 omi_exitp;
 
