@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2014 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -181,7 +182,7 @@ int omi_prc_conn(omi_conn *cptr, char *xend, char *buff, char *bend)
 	struct spwd *spass, *getspnam();
 	struct stat buf;
 #		endif
-	struct passwd *pass;
+	struct passwd *uinfo;
 	char *pw, *syspw;
 
 	/* lowercase agent name */
@@ -205,21 +206,21 @@ int omi_prc_conn(omi_conn *cptr, char *xend, char *buff, char *bend)
 		    return -OMI_ER_DB_USERNOAUTH;
 		}
 		syspw = spass->sp_pwdp;
-	} else if ((pass = getpwnam(ag_name)) == NULL)
+	} else if ((uinfo = getpwnam(ag_name)) == NULL)
 	{
 		OMI_DBG((omi_debug, "%s:  user %s not found in /etc/passwd\n",
 			SRVR_NAME, ag_name));
 		return -OMI_ER_DB_USERNOAUTH;
 	} else
-		syspw = pass->pw_passwd;
+		syspw = uinfo->pw_passwd;
 #	else    /* ndef SHADOWPW */
-	if ((pass = getpwnam(ag_name)) == NULL)
+	if ((uinfo = getpwnam(ag_name)) == NULL)
 	{
 		    OMI_DBG((omi_debug, "%s:  user %s not found in /etc/passwd\n",
 			     SRVR_NAME, ag_name));
 		    return -OMI_ER_DB_USERNOAUTH;
 	    } else
-		syspw = pass->pw_passwd;
+		syspw = uinfo->pw_passwd;
 #	endif   /* SHADOWPW */
 	pw = (char *) crypt(ag_pass, syspw);
 	if (strcmp(pw, syspw) != 0)
