@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2013 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2020 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -110,7 +111,7 @@ int omi_prc_ordr(omi_conn *cptr, char *xend, char *buff, char *bend)
 					REVERT
 					return -OMI_ER_DB_UNRECOVER;
 				}
-				memcpy(gv_currkey, gv_altkey, gv_altkey->end + SIZEOF(gv_key));
+				memcpy(gv_currkey, gv_altkey, gv_altkey->end + SIZEOF(gv_key) + 1);
 				TREF(gv_last_subsc_null) = FALSE;
 			}
 
