@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001 Sanchez Computer Associates, Inc.	*
+ * Copyright (c) 2001-2024 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -25,11 +26,7 @@ static char rcsid[] = "$Header:$";
 
 
 int
-omi_prc_stat(cptr, xend, buff, bend)
-    omi_conn	*cptr;
-    char	*xend;
-    char	*buff;
-    char	*bend;
+omi_prc_stat(omi_conn *cptr, char *xend, char *buff, char *bend)
 {
 
 /*  Keep a status in the omi_conn structure? */
