@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2013 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -16,11 +17,15 @@
  *
  * return -1 (if no bits set) or fd
  */
+
+error_def(ERR_FDSIZELMT);
+
 int cmj_firstone(fd_set *s, int n)
 {
 	int i;
 
-	assertpro(FD_SETSIZE >= n);
+	if (FD_SETSIZE < n)
+		RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(3) ERR_FDSIZELMT, 1, n);
 	for (i = 0; i < n; i++) {
 		if (FD_ISSET(i, s)) {
 			FD_CLR(i, s);
