@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2013 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2023 Fidelity National Information	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -21,6 +22,9 @@
 #include "gtmio.h"
 #include "relqop.h"
 #include "gtm_string.h" /* for memcpy */
+#include "eintr_wrappers.h"
+
+error_def(ERR_FDSIZELMT);
 
 void cmj_incoming_call(struct NTD *tsk)
 {
@@ -30,8 +34,7 @@ void cmj_incoming_call(struct NTD *tsk)
 	GTM_SOCKLEN_TYPE sz = SIZEOF(struct sockaddr);
 	cmi_status_t status;
 
-	while ((-1 == (rval = ACCEPT(tsk->listen_fd, (struct sockaddr *)&sas, (GTM_SOCKLEN_TYPE *)&sz))) && EINTR == errno)
-		;
+	ACCEPT_SOCKET(tsk->listen_fd, (struct sockaddr *)&sas, (GTM_SOCKLEN_TYPE *)&sz, rval);
 	while (rval >= 0)
 	{
 		status = cmj_setupfd(rval);
@@ -65,12 +68,12 @@ void cmj_incoming_call(struct NTD *tsk)
 		lnk->peer_ai.ai_addrlen = sz;
 		insqh(&lnk->cqe, &tsk->cqh);
 		lnk->ntd = tsk;
-		assertpro(FD_SETSIZE > rval);
+		if (FD_SETSIZE <= rval)
+			RTS_ERROR_CSA_ABT(NULL, VARLSTCNT(3) ERR_FDSIZELMT, 1, rval);
 		FD_SET(rval, &tsk->es);
 		/* setup for callback processing */
 		lnk->deferred_event = TRUE;
 		lnk->deferred_reason = CMI_REASON_CONNECT;
-		while ((-1 == (rval = ACCEPT(tsk->listen_fd, (struct sockaddr *)&sas, (GTM_SOCKLEN_TYPE *)&sz)))
-			 && EINTR == errno);
+		ACCEPT_SOCKET(tsk->listen_fd, (struct sockaddr *)&sas, (GTM_SOCKLEN_TYPE *)&sz, rval);
 	}
 }
