@@ -1,6 +1,6 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2004 Sanchez Computer Associates, Inc.	*
+ *	Copyright 2001, 2014 Fidelity Information Services, Inc	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -12,14 +12,8 @@
 #ifndef OBJ_FILESP_INCLUDED
 #define OBJ_FILESP_INCLUDED
 
-#ifdef __sparc
-	void emit_addr(int4 refaddr_upper, int4 refaddr_lower, int4 offset, int4 *result_upper, int4 *result_lower);
-	void emit_reference(uint4 refaddr_upper, uint4 refaddr_lower, mstr *name, uint4 *result_upper,   uint4 *result_lower);
-#else
-	void emit_addr(int4 refaddr, int4 offset, int4 *result);
-	void emit_reference(uint4 refaddr, mstr *name, uint4 *result);
-#endif
-
+void emit_addr(int4 refaddr, int4 offset, int4 *result);
+void emit_reference(uint4 refaddr, mstr *name, uint4 *result);
 struct sym_table *define_symbol(unsigned char psect, mstr *name, int4 value);
 void emit_pidr(int4 refoffset, int4 data_offset, int4 *result);
 void buff_emit(void);
