@@ -1,6 +1,7 @@
 /****************************************************************
  *								*
- *	Copyright 2001, 2014 Fidelity Information Services, Inc	*
+ * Copyright (c) 2001-2015 Fidelity National Information 	*
+ * Services, Inc. and/or its subsidiaries. All rights reserved.	*
  *								*
  *	This source code contains the intellectual property	*
  *	of its copyright holder(s), and is made available	*
@@ -73,6 +74,7 @@ typedef struct
 	int4 		lab_ln_ptr;		/* Offset of the lnrtab entry from the routine header */
 	boolean_t	has_parms;		/* Flag to indicate whether the callee has a formallist */
 } lab_tabent_proxy;
+#define TABENT_PROXY TREF(lab_proxy)
 
 typedef struct	rhead_struct
 {
@@ -95,7 +97,7 @@ typedef struct	rhead_struct
 #	ifdef GTM_TRIGGER
 	void_ptr_t	trigr_handle;		/* Type is void to avoid needing gv_trigger.h to define gv_trigger_t addr */
 #	endif
-	unsigned char	checksum_md5[16];	/* 16-byte MD5 checksum of routine source code */
+	unsigned char	checksum_128[16];	/* 16-byte MurmurHash3 checksum of routine source code */
 	routine_source	*source_code;		/* source code used by $TEXT */
 	uint4		routine_source_offset;	/* (updated) when compiled with EMBED_SOURCE: offset of M source within literal text
 						 * pool; becomes absolute address in incr_link
@@ -144,7 +146,7 @@ typedef struct
 #define VERIFY		TRUE
 #define NOVERIFY	FALSE
 
-int get_src_line(mval *routine, mval *label, int offset, mstr **srcret, boolean_t verifytrig);
+int get_src_line(mval *routine, mval *label, int offset, mstr **srcret, rhdtyp **rtn_vec);
 void free_src_tbl(rhdtyp *rtn_vector);
 unsigned char *find_line_start(unsigned char *in_addr, rhdtyp *routine);
 int4 *find_line_addr(rhdtyp *routine, mstr *label, int4 offset, mident **lent_name);
